(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     43738,       1203]*)
(*NotebookOutlinePosition[     47879,       1322]*)
(*  CellTagsIndexPosition[     47770,       1315]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Tensorial Analysis and Continuum Mechanics", "Title"],

Cell[TextData[{
  StyleBox["Jean-Fran\[CCedilla]ois Gouyet", "Subexercise",
    FontFamily->"Helvetica",
    FontSize->14],
  "\n",
  StyleBox["Ecole Polytechnique\nPalaiseau, France, 2003", "Address",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}]
}], "Subsubtitle"],

Cell[TextData[{
  "\n",
  StyleBox["This first chapter is intended for recalling some general \
features of Tensors and Vectors, in the spirit of the present notebook on \
Continuum Mechanics, and of the notebook for tensor calculus \"Tensorial\".", 
    "Address",
    FontSize->12,
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n", "Address",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontVariations->{"CompatibilityType"->0}]
}], "Subsubtitle"],

Cell[CellGroupData[{

Cell[TextData[{
  "Initial rules and definitions",
  StyleBox[" (Automatically Initialized)",
    FontColor->GrayLevel[0.666667]]
}], "Section",
  InitializationCell->True],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(\(\(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)\(\
\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(numequ = 1;\)\), "\[IndentingNewLine]", 
    \(ResultFrame[i_] := 
      StyleForm[
        SequenceForm["\<      \>", 
          i, "\<      (1.\>", \(numequ++\), "\<)\>"], 
        Background -> RGBColor[0, 1, 0], Magnification -> 1.2]\)}], "Input",
  InitializationCell->True],

Cell["\<\
The flavors allow to distinguish between various basis.
The change of  flavor is given by ToFlavor[new, old]. ToFlavor[bar]  is \
equivalent to  ToFlavor[bar, Identity]. \
\>", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}, {green, ForestGreen}, {star, 
        SuperStar}, {blue, Blue}, {hat, OverHat}, {tilde, Overtilde}, {bar, 
        OverBar}]\), "\[IndentingNewLine]", 
    \(\(black = Identity;\)\), "\[IndentingNewLine]", 
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\n", 
    \(\({NDim, BaseIndices};\)\)}], "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.   Vector and Tensors", "Title"],

Cell[CellGroupData[{

Cell["Dot Product, Vector Components", "Section",
  CellTags->"DotProduct"],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], u, v, w, x}, 
          1}, {{g, \[Delta], \[Beta]}, 2}];\)\)], "Input"],

Cell[CellGroupData[{

Cell["Canonical basis", "Subsection"],

Cell[TextData[{
  "The commonly used basis is the orthonormal basis. In the following, we \
will generally use black indices with base indices ",
  StyleBox["{1,2,3}",
    FontWeight->"Bold"],
  " defined in the initial rules. The dimension of the considered space is ",
  StyleBox["NDim",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
    \({NDim, BaseIndices}\)], "Input"],

Cell[TextData[{
  "The geometry of the vector space is completely defined for a set of  ",
  StyleBox["basis vectors",
    FontWeight->"Bold"],
  " (",
  StyleBox["\[DoubleStruckE]",
    FontSize->16],
  ") and the corresponding ",
  StyleBox["metric tensor",
    FontWeight->"Bold"],
  " (",
  StyleBox["g",
    FontWeight->"Bold"],
  "), we define the values of the ",
  StyleBox["metric tensor",
    FontWeight->"Bold"],
  ". The basis vectors of the orthonormal basis are"
}], "Text"],

Cell[BoxData[
    \(\[DoubleStruckE]d[i]\)], "Input"],

Cell[TextData[{
  "The ",
  StyleBox["metric tensor",
    FontWeight->"Bold"],
  ", whose components are the scalar product of the basis vectors :"
}], "Text"],

Cell[BoxData[
    \(\[DoubleStruckE]d[i] . \[DoubleStruckE]d[j] // 
      EvaluateDotProducts[\[DoubleStruckE], \ g]\)], "Input"],

Cell["and for an orthonormal basis :", "Text"],

Cell[BoxData[
    \(SetMetricValues[g, IdentityMatrix[3]]\)], "Input"],

Cell[BoxData[
    \(\((\[DoubleStruckE]d[i] . \[DoubleStruckE]d[
              j] \[Equal] \((\[DoubleStruckE]d[i] . \[DoubleStruckE]d[j] // 
              EvaluateDotProducts[\[DoubleStruckE], \ g])\))\) // 
      ArrayExpansion[i, j]\)], "Input"],

Cell["\<\
If we consider now a new basis, characterized by a red flavor :\
\>", "Text"],

Cell[BoxData[
    \(\[DoubleStruckE]d[red@i]\)], "Input"],

Cell[TextData[{
  "again, the characteristics of this red basis is completely determined by \
its metric tensor ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox["g", 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                FormBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"]}],
              SequenceForm[ 
                red[ i], 
                red[ j]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                StyleForm[ 
                  red[ j], ShowContents -> False]],
              Editable->False]],
          FontFamily->"Courier"], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
    \(\(\[DoubleStruckE]d[i] . \[DoubleStruckE]d[j] // ToFlavor[red]\) // 
      EvaluateDotProducts[\[DoubleStruckE], \ g]\)], "Input"],

Cell[TextData[{
  "There are many ways to build ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox["g", 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                FormBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"]}],
              SequenceForm[ 
                red[ i], 
                red[ j]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                StyleForm[ 
                  red[ j], ShowContents -> False]],
              Editable->False]],
          FontFamily->"Courier"], TraditionalForm]]],
  ". Here we start from the components of ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckE]", 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False], 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckE], 
                  SequenceForm[ 
                    red[ i]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " in the canonical ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckE]", 
                  InterpretationBox["i",
                    SequenceForm[ i],
                    Editable->False], 
                  InterpretationBox[
                    TagBox[
                      StyleBox["i",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ i, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckE], 
                  SequenceForm[ i], 
                  SequenceForm[ 
                    StyleForm[ i, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " (black) basis"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"RedBasisVectors", "=", 
        RowBox[{"(", GridBox[{
              {"1", "1", "0"},
              {"0", "1", "2"},
              {"1", "0", "1"}
              }], ")"}]}], 
      ";"}], "\[IndentingNewLine]", \(SetTensorValueRules[\[DoubleStruckE]d[
        red@i], RedBasisVectors]\)}], "Input"],

Cell["\<\
which corresponds equivalently to the rules (see below \"Basis Change\" )\
\>", "Text"],

Cell[BoxData[
    \(MixedBasisInnerProductsRule\  = \ 
      MapThread[
          Rule, {Table[\[DoubleStruckE]u[j] . \[DoubleStruckE]d[red@i], {i, 
                1, 3}, {j, 1, 3}]\ , \ \ RedBasisVectors\ }, 2] // 
        Flatten\)], "Input"],

Cell["\<\
The corresponding values (RedMetric) for the metric tensor are obtained \
either directly from the components of the red basis,\
\>", "Text"],

Cell[BoxData[
    \(\((\((\((\[DoubleStruckE]d[red@i] . \[DoubleStruckE]d[red@j] // 
                    EvaluateDotProducts[\[DoubleStruckE], \ 
                      g])\) -> \((\[DoubleStruckE]d[
                      red@i] . \[DoubleStruckE]d[red@j])\))\) // 
            ArrayExpansion[red@i, red@j])\) /. 
        TensorValueRules[\[DoubleStruckE]] // Flatten\)], "Input"],

Cell[BoxData[{
    \(RedMetric = \((gdd[red@i, red@j] // 
            ArrayExpansion[red@i, red@j])\) /. %\), "\[IndentingNewLine]", 
    \(SetMetricValueRules[g, RedMetric, red]\)}], "Input"],

Cell[TextData[{
  "or using the basis change ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[DoubleStruckE]", 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["j_",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ 
                          Pattern[ j, 
                            Blank[ ]]]],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j_",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ 
                            Pattern[ j, 
                              Blank[ ]]], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[DoubleStruckE], 
                    SequenceForm[ 
                      red[ 
                        Pattern[ j, 
                          Blank[ ]]]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 
                          Pattern[ j, 
                            Blank[ ]]], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"], "\[Rule]", 
              RowBox[{
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          SequenceForm[ 
                            red[ j]],
                          Editable->False], 
                        InterpretationBox[
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ j], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          red[ j]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], ".", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[DoubleStruckE]", 
                        InterpretationBox[
                          TagBox[
                            StyleBox["k",
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)],
                          SequenceForm[ 
                            StyleForm[ k, ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox["k",
                          SequenceForm[ k],
                          Editable->False]],
                      Subsuperscript[ \[DoubleStruckE], 
                        SequenceForm[ 
                          StyleForm[ k, ShowContents -> False]], 
                        SequenceForm[ k]],
                      Editable->False],
                    "TraditionalForm"]}], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox["k",
                        SequenceForm[ k],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox["k",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ k, ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ k], 
                      SequenceForm[ 
                        StyleForm[ k, ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " which is more in the tensor spirit (see below)."
}], "Text"],

Cell[BoxData[
    \(TensorValueRules[\[DoubleStruckE], g]\)], "Input"],

Cell[TextData[{
  "There is an easy way to calculate the red reciprocal basis vectors. Just \
take the rows of ",
  Cell[BoxData[
      \(Transpose[Inverse[RedBasisVectors]]\)]],
  ": "
}], "Text",
  ParagraphSpacing->{0, 0}],

Cell[BoxData[
    \(Transpose[Inverse[RedBasisVectors]]\)], "Input"],

Cell[TextData[{
  "However, let's work by more formal tensor methods.  This gives us some \
practice in performing tensor manipulations with Tensorial and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". What we want to calculate are the components of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[DoubleStruckE]", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]],
    FontFamily->"Courier New",
    FontSize->16],
  " the black basis.\nThe components of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[DoubleStruckE]", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]],
    FontFamily->"Courier New",
    FontSize->16],
  " are then"
}], "Text"],

Cell[BoxData[
    \(components = \[DoubleStruckE]u[red@i] . \[DoubleStruckE]d[k] // 
        ArrayExpansion[k]\)], "Input"],

Cell[TextData[{
  "using the fact that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            SubsuperscriptBox["\[DoubleStruckE]", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ i]],
                Editable->False]], ".", 
            TagBox[
              StyleBox[
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[DoubleStruckE]", 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ j]],
                        Editable->False], 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[DoubleStruckE], 
                      SequenceForm[ 
                        red[ j]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"],
                FontFamily->"Courier",
                FontSize->16],
              (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)]}], 
          "}"}], TraditionalForm]],
    FontFamily->"Courier New",
    FontSize->16],
  " is the identity matrix"
}], "Text"],

Cell[BoxData[{
    \(\(SetTensorValues[\[Delta]ud[red@i, red@j], 
        IdentityMatrix[3]];\)\), "\[IndentingNewLine]", 
    \(\((components . \[DoubleStruckE]d[red@j] \[Equal] \[Delta]ud[red@i, 
            red@j])\) // 
      ArrayExpansion[red@i, red@j]\), "\[IndentingNewLine]", 
    \(% /. TensorValueRules[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(\[DoubleStruckE]sols = \(Solve[
          Flatten[%]]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\), "\
\[IndentingNewLine]", 
    \(\((components // 
          ArrayExpansion[red@i])\) /. \[DoubleStruckE]sols\)}], "Input"],

Cell["This confirms the preceding result. To summarize,", "Text"],

Cell[BoxData[{
    \(SetTensorValueRules[\[DoubleStruckE]u[red@i], %]\), "\n", 
    \(TensorValueRules[g, \[DoubleStruckE]]\)}], "Input"],

Cell["\<\
The red basis will be used as numerical example in the following \
developments.\
\>", "Text"],

Cell[BoxData[{
    \(\[DoubleStruckU] = 
      uu[red@i] \[DoubleStruckE]d[red@i] // 
        EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\[DoubleStruckV] = 
      vu[red@i] \[DoubleStruckE]d[red@i] // 
        EinsteinSum[]\), "\[IndentingNewLine]", 
    \(\[DoubleStruckCapitalW] = 
      wd[red@i] \[DoubleStruckE]u[red@i] // EinsteinSum[]\)}], "Input"],

Cell[BoxData[
    \(\[DoubleStruckU] . \[DoubleStruckCapitalW]\)], "Input"],

Cell["\<\
The scalar products can of course be calculated following various ways.\
\>", "Text"],

Cell[TextData[{
  "We can expand the above using ",
  Cell[BoxData[
      \(LinearBreakout\)]],
  "."
}], "Text",
  Background->RGBColor[1, 0.893996, 0.882002]],

Cell[BoxData[{
    \(% // \(LinearBreakout[
          Dot]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]]\), "\
\[IndentingNewLine]", 
    \(% /. TensorValueRules[\[DoubleStruckE]]\)}], "Input"],

Cell[TextData[{
  StyleBox["EvaluateDotProducts",
    FontWeight->"Bold"],
  " evaluates the dot product without references to the tensor values of ",
  StyleBox["\[DoubleStruckE]",
    FontFamily->"Courier New",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Courier New",
    FontSize->16]
}], "Text"],

Cell[BoxData[
    \(\[DoubleStruckU] . \[DoubleStruckCapitalW] // 
      EvaluateDotProducts[\ \[DoubleStruckE], g]\)], "Input"],

Cell[BoxData[{
    \(\[DoubleStruckU] . \[DoubleStruckV]\), "\[IndentingNewLine]", 
    \(% // EvaluateDotProducts[\ \[DoubleStruckE], g]\)}], "Input"],

Cell[BoxData[{
    \(\[DoubleStruckU] . \[DoubleStruckU]\), "\[IndentingNewLine]", 
    \(% /. TensorValueRules[\[DoubleStruckE], g]\)}], "Input"],

Cell[BoxData[{
    \(\[DoubleStruckV] . \[DoubleStruckCapitalW]\), "\[IndentingNewLine]", 
    \(% /. TensorValueRules[\[DoubleStruckE], g]\), "\[IndentingNewLine]", 
    \(% // Simplify\)}], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basis change", "Section",
  CellTags->"BasisChange"],

Cell[TextData[{
  "Change from black basis to red basis will be defined by a basis change \
denoted (for instance) ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Beta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "j"}],
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], j],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["j",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ j, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Beta], 
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], j], 
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " or ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Beta]", 
                  InterpretationBox[
                    RowBox[{"j", "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ j, 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["j",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)]}],
                    SequenceForm[ 
                      StyleForm[ j, ShowContents -> False], 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                    Editable->False]],
                Subsuperscript[ \[Beta], 
                  SequenceForm[ j, 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]], 
                  SequenceForm[ 
                    StyleForm[ j, ShowContents -> False], 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  ". Due to the symmetry between red and black, it is conventional in ",
  StyleBox["Tensorial",
    FontSlant->"Italic"],
  " to use the notation ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Beta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", "j"}],
                    SequenceForm[ 
                      StyleForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        ShowContents -> False], j],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox["j",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      StyleForm[ j, ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Beta], 
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], j], 
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The operation ",
  StyleBox["KroneckerAbsorb[\[Beta]]",
    FontWeight->"Bold"],
  " is appropriate here to show the basis change"
}], "Text"],

Cell[BoxData[{
    \(\[DoubleStruckE]d[red@i] . \[DoubleStruckE]u[j] // 
      EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]]\), \
"\[IndentingNewLine]", 
    \(\[DoubleStruckE]d[
        red@i] == \((\[DoubleStruckE]d[j] % // 
          SymmetricStandardOrder[\[Beta]])\)\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Beta]]\)}], "Input"],

Cell[TextData[{
  "The coordinate transformation ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Beta]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["j",
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ j, ShowContents -> False], 
              red[ i]],
            Editable->False], 
          InterpretationBox[
            RowBox[{"j", "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ j, 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " from black to red basis are now completely defined :"
}], "Text"],

Cell[BoxData[
    \(SetTensorValueRules[\[Beta]ud[j, 
        red@i], \((\[DoubleStruckE]d[red@i] // ArrayExpansion[red@i])\) /. 
        TensorValueRules[\[DoubleStruckE], g]]\)], "Input"],

Cell[BoxData[
    \(TensorValueRules[\[Beta]]\)], "Input"],

Cell[TextData[{
  "The above basis change is precisely the one considered above in the rule \
",
  StyleBox["MixedBasisInnerProductsRule.",
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  "It can be shown easily that ",
  Cell[BoxData[
      SubsuperscriptBox["\[Beta]", 
        InterpretationBox[
          RowBox[{
            TagBox[
              StyleBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]", 
            "j"}],
          SequenceForm[ 
            StyleForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              ShowContents -> False], j],
          Editable->False], 
        InterpretationBox[
          RowBox[{
            TagBox[
              StyleBox["i",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
            "\[InvisibleSpace]", 
            TagBox[
              StyleBox["j",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)]}],
          SequenceForm[ 
            StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
            StyleForm[ j, ShowContents -> False]],
          Editable->False]]]],
  " is also given by   ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[PartialD]", " ", 
          SuperscriptBox["x", 
            StyleBox["i",
              FontColor->RGBColor[1, 0, 0]]]}], 
        "/", \(\[PartialD]\ x\^j\)}]]],
  "which is of course ",
  StyleBox["not a delta function",
    FontColor->RGBColor[0, 0, 1]],
  ". \nThe present formulation leads to"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      StyleBox[\(PartialD[xu[i_], j_] -> \[Beta]ud[i, j]\),
        FontColor->RGBColor[0, 0, 1]], 
      ";"}], "\[IndentingNewLine]", \(\[DoubleStruckE]d[red@i] == 
      PartialD[xu[j], red@i] \[DoubleStruckE]d[
          j]\), "\[IndentingNewLine]", \(% /. %%\), "\[IndentingNewLine]", \
\((% // KroneckerAbsorb[\[Beta]])\)}], "Input"],

Cell[TextData[{
  "We can also build the following ",
  StyleBox["TensorValueRules[x]",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[{
    \(\(\(SetTensorValueRules[
      PartialD[xu[j], 
        red@i], \((\[DoubleStruckE]d[red@i] // ArrayExpansion[red@i])\) /. 
        TensorValueRules[\[DoubleStruckE], g]]\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(TensorValueRules[x]\)}], "Input"],

Cell["Finally notice the possibilities of successive basis changes", "Text"],

Cell[BoxData[
    RowBox[{\((\((\[DoubleStruckE]u[red@i] . \[DoubleStruckE]d[j] // 
              EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]])\) \((\
\[DoubleStruckE]u[j] . \[DoubleStruckE]d[blue@k] // 
              EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]])\))\), "==", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(", 
        RowBox[{\((\((\[DoubleStruckE]u[red@i] . \[DoubleStruckE]d[j] // 
                  EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]])\) \((\
\[DoubleStruckE]u[j] . \[DoubleStruckE]d[blue@k] // 
                  EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]])\))\), "//",
           
          StyleBox[\(KroneckerAbsorb[\[Beta]]\),
            FontColor->RGBColor[0, 0, 1]]}], ")"}]}]], "Input"],

Cell[BoxData[
    \(\(ClearTensorShortcuts[{{\[DoubleStruckE], u, v, w, x}, 
          1}, {{g, \[Delta], \[Beta]}, 2}];\)\)], "Input"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{955, 641},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"], None, Cell[ 
      "J.-F. Gouyet", "Header"]}, {
    Cell[ "Continuum Mechanics", "Header"], None, Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "DotProduct"->{
    Cell[4172, 129, 75, 1, 61, "Section",
      CellTags->"DotProduct"]},
  "BasisChange"->{
    Cell[30417, 855, 58, 1, 41, "Section",
      CellTags->"BasisChange"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"DotProduct", 47576, 1305},
  {"BasisChange", 47669, 1308}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 59, 0, 76, "Title"],
Cell[1838, 55, 291, 8, 79, "Subsubtitle"],
Cell[2132, 65, 516, 14, 94, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2673, 83, 172, 5, 61, "Section",
  InitializationCell->True],
Cell[2848, 90, 484, 11, 146, "Input",
  InitializationCell->True],
Cell[3335, 103, 222, 5, 54, "Text",
  InitializationCell->True],
Cell[3560, 110, 498, 9, 166, "Input",
  InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[4107, 125, 40, 0, 76, "Title"],

Cell[CellGroupData[{
Cell[4172, 129, 75, 1, 61, "Section",
  CellTags->"DotProduct"],
Cell[4250, 132, 136, 2, 46, "Input"],

Cell[CellGroupData[{
Cell[4411, 138, 37, 0, 49, "Subsection"],
Cell[4451, 140, 325, 8, 56, "Text"],
Cell[4779, 150, 52, 1, 46, "Input"],
Cell[4834, 153, 488, 17, 58, "Text"],
Cell[5325, 172, 53, 1, 46, "Input"],
Cell[5381, 175, 159, 5, 35, "Text"],
Cell[5543, 182, 129, 2, 46, "Input"],
Cell[5675, 186, 46, 0, 34, "Text"],
Cell[5724, 188, 70, 1, 46, "Input"],
Cell[5797, 191, 248, 4, 46, "Input"],
Cell[6048, 197, 87, 2, 34, "Text"],
Cell[6138, 201, 57, 1, 46, "Input"],
Cell[6198, 204, 2247, 59, 34, "Text"],
Cell[8448, 265, 150, 2, 46, "Input"],
Cell[8601, 269, 5172, 137, 34, "Text"],
Cell[13776, 408, 341, 9, 96, "Input"],
Cell[14120, 419, 97, 2, 34, "Text"],
Cell[14220, 423, 245, 5, 66, "Input"],
Cell[14468, 430, 151, 3, 34, "Text"],
Cell[14622, 435, 379, 6, 66, "Input"],
Cell[15004, 443, 192, 3, 66, "Input"],
Cell[15199, 448, 6153, 142, 37, "Text"],
Cell[21355, 592, 70, 1, 46, "Input"],
Cell[21428, 595, 225, 7, 34, "Text"],
Cell[21656, 604, 68, 1, 46, "Input"],
Cell[21727, 607, 2420, 68, 74, "Text"],
Cell[24150, 677, 123, 2, 46, "Input"],
Cell[24276, 681, 3317, 83, 35, "Text"],
Cell[27596, 766, 588, 11, 126, "Input"],
Cell[28187, 779, 65, 0, 34, "Text"],
Cell[28255, 781, 137, 2, 66, "Input"],
Cell[28395, 785, 104, 3, 34, "Text"],
Cell[28502, 790, 359, 8, 86, "Input"],
Cell[28864, 800, 75, 1, 46, "Input"],
Cell[28942, 803, 95, 2, 34, "Text"],
Cell[29040, 807, 160, 6, 50, "Text"],
Cell[29203, 815, 193, 4, 66, "Input"],
Cell[29399, 821, 332, 11, 37, "Text"],
Cell[29734, 834, 128, 2, 46, "Input"],
Cell[29865, 838, 151, 2, 66, "Input"],
Cell[30019, 842, 146, 2, 66, "Input"],
Cell[30168, 846, 200, 3, 86, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[30417, 855, 58, 1, 41, "Section",
  CellTags->"BasisChange"],
Cell[30478, 858, 7372, 174, 56, "Text"],
Cell[37853, 1034, 161, 5, 35, "Text"],
Cell[38017, 1041, 351, 7, 86, "Input"],
Cell[38371, 1050, 1497, 41, 35, "Text"],
Cell[39871, 1093, 189, 3, 46, "Input"],
Cell[40063, 1098, 58, 1, 46, "Input"],
Cell[40124, 1101, 175, 5, 35, "Text"],
Cell[40302, 1108, 1652, 47, 54, "Text"],
Cell[41957, 1157, 367, 7, 106, "Input"],
Cell[42327, 1166, 123, 4, 35, "Text"],
Cell[42453, 1172, 273, 6, 86, "Input"],
Cell[42729, 1180, 76, 0, 34, "Text"],
Cell[42808, 1182, 764, 13, 106, "Input"],
Cell[43575, 1197, 135, 2, 46, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

