(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    136623,       3573]*)
(*NotebookOutlinePosition[    140774,       3692]*)
(*  CellTagsIndexPosition[    140660,       3685]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["2.   The Strain Tensor", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  "Initial rules and definitions",
  StyleBox[" (Automatically Initialized)",
    FontColor->GrayLevel[0.666667]]
}], "Section",
  InitializationCell->True],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(\(\(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)\(\n\)
    \)\), "\n", 
    \(\(numequ\  = \ 1;\)\), "\n", 
    \(ResultFrame[i_]\  := \ \n\ \ StyleForm[
        SequenceForm["\<      \>", \ 
          i, \ "\<      (2.\>", \ \(numequ++\), \ "\<)\>"], \ \n\ \ \ \ \
Background\  -> \ RGBColor[0, \ 1, \ 0], \ 
        Magnification\  -> \ 1.2]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}, {green, ForestGreen}, {star, 
        SuperStar}, {blue, Blue}, {hat, OverHat}, {tilde, Overtilde}, {bar, 
        OverBar}]\), "\[IndentingNewLine]", 
    \(\(black = Identity;\)\), "\[IndentingNewLine]", 
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\n", 
    \(\({NDim, BaseIndices};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], \[EHat], u, dx}, 
          1}, {{g, \[ScriptG], \[Gamma], \[Zeta], \ \[InvisibleSpace]\
\[ScriptCapitalE], \ \[InvisibleSpace]\[ScriptCapitalE]\[Section]}, 
          2}];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Black, Red or Blue Basis", "Section",
  CellTags->"ColoredBasis"],

Cell[TextData[{
  "We consider a body with a system of coordinates ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["x", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]]],
  " ",
  StyleBox["attached permanently to each point",
    FontVariations->{"Underline"->True}],
  " of it. So these coordinates are conserved during the deformation of the \
body. These coordinates are called particle coordinates or ",
  StyleBox["convected coordinates",
    FontColor->RGBColor[0, 0, 1]],
  ".\nA line element of a given body before deformation in the red basis ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox["\[DoubleStruckE]", 
            InterpretationBox[
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"],
              SequenceForm[ 
                red[ i]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]],
              Editable->False]],
          FontFamily->"Courier New",
          FontSize->16], TraditionalForm]]],
  " is given by :"
}], "Text"],

Cell[BoxData[
    \(d\[DoubleStruckA] = 
      dxu[i] \[DoubleStruckE]d[i] // ToFlavor[red]\)], "Input"],

Cell["with the square of its length :", "Text"],

Cell[BoxData[
    \(d\[DoubleStruckA]2 = 
      d\[DoubleStruckA] . \((d\[DoubleStruckA] /. i -> j)\) // 
        EvaluateDotProducts[\ \[DoubleStruckE], g, False]\)], "Input"],

Cell[TextData[{
  "After deformation, the line element ",
  Cell[BoxData[
      \(d\[AHat]\)]],
  " connecting the same material points is different in length and direction \
and may be written, where {",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox["\[EHat]", 
            InterpretationBox[
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"],
              SequenceForm[ 
                red[ i]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]],
              Editable->False]],
          FontFamily->"Courier New",
          FontSize->16], TraditionalForm]]],
  "} are the vectors into which the original basis {",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[DoubleStruckE]", 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ i]],
                Editable->False], 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]],
                Editable->False]],
            Subsuperscript[ \[DoubleStruckE], 
              SequenceForm[ 
                red[ i]], 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]],
    FontFamily->"Courier New",
    FontSize->16],
  "} is deformed"
}], "Text"],

Cell[BoxData[
    \(d\[AHat] = dxu[i] \[EHat]d[i] // ToFlavor[red]\)], "Input"],

Cell[BoxData[
    \(d\[AHat]2 = 
      d\[AHat] . \((d\[AHat] /. i -> j)\) // 
        EvaluateDotProducts[\ \[EHat], \[ScriptG], False]\)], "Input"],

Cell[TextData[{
  "The deformation is then characterized by  the quantities ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[Gamma]dd[red@i, 
            red@j] -> \((d\[AHat]2 - d\[DoubleStruckA]2)\)/\((dxu[red@i] 
                dxu[red@j])\) // Simplify\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  StyleBox["Question",
    FontColor->RGBColor[0, 0, 1]],
  " : is ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " a tensor ? To check this we have to perfom a basis change. We write ",
  StyleBox["d\[DoubleStruckA]",
    FontWeight->"Bold"],
  " and ",
  StyleBox["d\[AHat]",
    FontWeight->"Bold"],
  " in a new \"",
  StyleBox["blue",
    FontColor->RGBColor[0, 0, 1]],
  "\" basis."
}], "Text"],

Cell[BoxData[{
    RowBox[{
      StyleBox["d\[DoubleStruckA]",
        FontWeight->"Bold"], 
      "=", \(dxu[i] \[DoubleStruckE]d[i] // 
        ToFlavor[blue]\)}], "\[IndentingNewLine]", \(d\[AHat] = 
      dxu[i] \[EHat]d[i] // ToFlavor[blue]\)}], "Input"],

Cell[TextData[{
  "Of course the basis change is common to both systems ",
  StyleBox["\[DoubleStruckE]",
    FontFamily->"Courier New",
    FontSize->16,
    FontWeight->"Bold"],
  " and ",
  StyleBox["\[EHat]",
    FontFamily->"Courier New",
    FontSize->16,
    FontWeight->"Bold"],
  " because we are using convected coordinates (there are no difference \
between ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["x", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox[
          StyleBox[
            OverscriptBox[
              StyleBox["x",
                FontFamily->"Times",
                FontSize->14], "^"],
            FontFamily->"Courier",
            FontSize->16], 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]]],
  "):"
}], "Text"],

Cell[BoxData[
    FormBox[
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox[\(\[Beta]\&^\), 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.0, 1.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      blue[ i]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0.0, 0.0, 1.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ j], 
                      StyleForm[ 
                        blue[ i], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ 
                  OverHat[ \[Beta]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    blue[ i]], 
                  SequenceForm[ 
                    red[ j], 
                    StyleForm[ 
                      blue[ i], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["x", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        InterpretationBox[
                          RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0.0, 0.0, 1.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ ",", 
                            blue[ i]],
                          Editable->False],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      Dif[ 
                        blue[ i]]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0.0, 0.0, 1.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ",", 
                                blue[ i]],
                              Editable->False],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ j], 
                      StyleForm[ 
                        Dif[ 
                          blue[ i]], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ x, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    Dif[ 
                      blue[ i]]], 
                  SequenceForm[ 
                    red[ j], 
                    StyleForm[ 
                      Dif[ 
                        blue[ i]], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Beta]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[0, 0, 1]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            0.0, 0.0, 1.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      blue[ i]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0.0, 0.0, 1.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ j], 
                      StyleForm[ 
                        blue[ i], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Beta], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    blue[ i]], 
                  SequenceForm[ 
                    red[ j], 
                    StyleForm[ 
                      blue[ i], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
      TraditionalForm]], "Text",
  TextAlignment->Center,
  TextJustification->0],

Cell[BoxData[{
    \(\(\[DoubleStruckE]u[red@j] . \[DoubleStruckE]d[blue@i] // 
        EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]];\)\), "\
\[IndentingNewLine]", 
    \(\[DoubleStruckE]d[
        blue@i] == \[DoubleStruckE]d[red@j] %\), "\[IndentingNewLine]", 
    \(\(\[EHat]u[red@j] . \[EHat]d[blue@i] // 
        EvaluateDotProducts[\ \[EHat], \[Beta]];\)\), "\[IndentingNewLine]", 
    \(\[EHat]d[blue@i] == \[EHat]d[red@j] %\)}], "Input"],

Cell[TextData[{
  "Therefore by the basis change ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Beta]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[0, 0, 1]],
                  (StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ j], ShowContents -> False], 
              blue[ i]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[0, 0, 1]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 0.0, 0.0, 1.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ j], 
              StyleForm[ 
                blue[ i], ShowContents -> False]],
            Editable->False]], TraditionalForm]],
    TextAlignment->Center,
    TextJustification->0],
  " , ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Gamma]", 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[Gamma], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  " ",
  StyleBox["transforms like a tensor",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  "."
}], "Text"],

Cell[BoxData[{
    \(\[DoubleStruckE]u[red@i] . \[DoubleStruckE]d[blue@i] // 
      EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]]\), \
"\[IndentingNewLine]", 
    \(\[DoubleStruckE]u[red@j] . \[DoubleStruckE]d[blue@j] // 
      EvaluateDotProducts[\ \[DoubleStruckE], \[Beta]]\), \
"\[IndentingNewLine]", 
    \(\[Gamma]dd[blue@i, 
        blue@j] == \[Gamma]dd[red@i, red@j] %\ %%\), "\[IndentingNewLine]", 
    \(% // KroneckerAbsorb[\[Beta]]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Strain Tensor (\[Gamma] or \[ScriptCapitalE])", "Section",
  CellTags->"StrainTensor"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["The",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[" ",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox["strain",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[" ",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox["tensor",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[" ",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox["is",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[" ",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox["defined",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[" ",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox["by",
            FontFamily->"Times",
            FontWeight->"Plain",
            FontVariations->{"CompatibilityType"->0}], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontFamily->"Times"], "   \[InvisibleSpace]"}]], 
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Gamma]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Gamma], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontSize->16]}], 
        StyleBox["=",
          FontSize->16], 
        RowBox[{
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[ScriptG]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptG], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontSize->16], 
          StyleBox["-",
            FontSize->16], 
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["g", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ g, 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontSize->16], "\[InvisibleSpace]"}]}]]],
  " \nwhich corresponds to the degree of deformation :  (",
  Cell[BoxData[
      \(d\[AHat] . d\[AHat]\)]],
  " \[Dash] ",
  StyleBox["d\[DoubleStruckA].d\[DoubleStruckA]",
    FontWeight->"Bold"],
  ") ",
  StyleBox["= ",
    FontSize->16],
  Cell[BoxData[
      RowBox[{
        SubsuperscriptBox["\[Gamma]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
            SequenceForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]],
            Editable->False]], 
        StyleBox[
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dx", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False]],
              Subsuperscript[ dx, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i]]],
              Editable->False],
            "TraditionalForm"],
          FontSize->14], 
        StyleBox[" ",
          FontSize->14], 
        StyleBox[
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dx", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ dx, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"],
          FontSize->14]}]],
    FontSize->16]
}], "Text"],

Cell[BoxData[
    \(straindd[i_, 
        j_] := \((\[EHat]d[i] . \[EHat]d[j] /. 
            BasisDotProductRules[\[EHat], \[ScriptG]])\) - \
\((\[DoubleStruckE]d[i] . \[DoubleStruckE]d[j] /. 
            BasisDotProductRules[\[DoubleStruckE], g])\)\)], "Input"],

Cell[BoxData[
    \(straindd[red@i, red@j]\)], "Input"],

Cell["The strain is a symmetric tensor like the metric.", "Text"],

Cell["\<\
Now, we want to calculate the strain tensor from the covariant components of \
the metric tensor :\
\>", "Text"],

Cell[BoxData[
    \(strainuu[i_, 
        j_] := \((\[EHat]u[i] . \[EHat]u[j] /. 
            BasisDotProductRules[\[EHat], \[ScriptG]])\) - \
\((\[DoubleStruckE]u[i] . \[DoubleStruckE]u[j] /. 
            BasisDotProductRules[\[DoubleStruckE], g])\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(\[Zeta]uu[i, j] == strainuu[i, j]\), "//", 
      RowBox[{
        StyleBox["ToFlavor",
          FontColor->GrayLevel[0]], "[", "red", "]"}]}]], "Input"],

Cell[TextData[{
  "Using the fact that ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptG]", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["i",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["j",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ i, ShowContents -> False], 
                        StyleForm[ j, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[\(i\[InvisibleSpace]j\),
                      SequenceForm[ i, j],
                      Editable->False]],
                  Subsuperscript[ \[ScriptG], 
                    SequenceForm[ 
                      StyleForm[ i, ShowContents -> False], 
                      StyleForm[ j, ShowContents -> False]], 
                    SequenceForm[ i, j]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["\[ScriptG]", 
                    InterpretationBox[\(j\[InvisibleSpace]k\),
                      SequenceForm[ j, k],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox["j",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox["k",
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ j, ShowContents -> False], 
                        StyleForm[ k, ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ \[ScriptG], 
                    SequenceForm[ j, k], 
                    SequenceForm[ 
                      StyleForm[ j, ShowContents -> False], 
                      StyleForm[ k, ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "= ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox["\[ScriptG]", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox["i",
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", "k"}],
              SequenceForm[ 
                StyleForm[ i, ShowContents -> False], k],
              Editable->False], 
            InterpretationBox[
              RowBox[{"i", "\[InvisibleSpace]", 
                TagBox[
                  StyleBox["k",
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ i, 
                StyleForm[ k, ShowContents -> False]],
              Editable->False]],
          FontColor->RGBColor[0, 0.4, 0.0313725]], TraditionalForm]],
    GeneratedCell->False,
    CellAutoOverwrite->False],
  "  is a Kronecker \[Delta] ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["i",
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               "k"}],
            SequenceForm[ 
              StyleForm[ i, ShowContents -> False], k],
            Editable->False], 
          InterpretationBox[
            RowBox[{"i", "\[InvisibleSpace]", 
              TagBox[
                StyleBox["k",
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ i, 
              StyleForm[ k, ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ", we can calculate ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Zeta]", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"], "\[InvisibleSpace]", 
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"]}],
                SequenceForm[ 
                  red[ i], 
                  red[ j]],
                Editable->False]],
            Subsuperscript[ \[Zeta], 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                StyleForm[ 
                  red[ j], ShowContents -> False]], 
              SequenceForm[ 
                red[ i], 
                red[ j]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  ". From the definitions of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Zeta]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Gamma]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ","
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\((\(\((guu[red@i, red@j] + \[Zeta]uu[red@i, red@j])\) \((gdd[
                      red@j, red@k] + \[Gamma]dd[red@j, red@k])\) // 
              Expand\) // MetricSimplify[g])\), 
        StyleBox["-",
          FontColor->RGBColor[0, 0.4, 0.0333104]], 
        StyleBox[\(gud[red@i, red@k]\),
          FontColor->RGBColor[0, 0.4, 0.0333104]]}], 
      StyleBox["==",
        FontColor->RGBColor[0, 0.4, 0.0333104]], 
      StyleBox["0",
        FontColor->RGBColor[0, 0.4, 0.0333104]]}]], "Input"],

Cell[TextData[{
  StyleBox["Neglecting the second order term",
    FontColor->RGBColor[0, 0, 1],
    Background->None,
    FontVariations->{"Underline"->True}],
  "   ",
  Cell[BoxData[
      RowBox[{
        InterpretationBox[
          SubsuperscriptBox["\[Gamma]", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox["k",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
              SequenceForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["k",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False], 
                StyleForm[ 
                  StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]],
              Editable->False]],
          Subsuperscript[ \[Gamma], 
            SequenceForm[ 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ k, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]]],
          Editable->False], " ", 
        InterpretationBox[
          SubsuperscriptBox["\[Zeta]", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False], 
                StyleForm[ 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
              SequenceForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
              Editable->False]],
          Subsuperscript[ \[Zeta], 
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]], 
            SequenceForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
          Editable->False]}]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(% /. \[Zeta]uu[red@i, red@j] \[Gamma]dd[red@j, red@k] -> 0\)], "Input"],

Cell["\<\
Both \[Gamma] and \[Zeta] are tensors, so that we have the relation :\
\>", "Text"],

Cell[BoxData[
    \(\((\(%[\([1]\)] guu[red@k, red@j] // Expand\) // MetricSimplify[g])\) == 
      0\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \(-\[Gamma]uu[red@i, red@j]\)\  \[Equal] \ \[ScriptG]uu[
            red@i, red@j]\  - \ 
          guu[red@i, red@j]\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      SubsuperscriptBox["\[Gamma]", 
        InterpretationBox[
          RowBox[{
            TagBox[
              StyleBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]", 
            TagBox[
              StyleBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)]}],
          SequenceForm[ 
            StyleForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              ShowContents -> False], 
            StyleForm[ 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              ShowContents -> False]],
          Editable->False], 
        InterpretationBox[
          RowBox[{
            TagBox[
              StyleBox["i",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
            "\[InvisibleSpace]", 
            TagBox[
              StyleBox["j",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
          SequenceForm[ 
            StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
            StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
          Editable->False]], " ", "do", " ", "not", " ", "correspond", " ", 
      "to", " ", "raising", " ", "the", " ", "indices", " ", 
      TagBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["g", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False], 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ k], 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ g, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ k], 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["g", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ l], 
                      red[ j]],
                    Editable->False]],
                Subsuperscript[ g, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ l], 
                    red[ j]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Gamma]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ k], 
                      red[ l]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False], 
                      StyleForm[ 
                        red[ l], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Gamma], 
                  SequenceForm[ 
                    red[ k], 
                    red[ l]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      red[ l], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16],
        (StyleForm[ #, FontSize -> 16, FontFamily -> 
          "Courier"]&)], \((but\ to\ its\ opposite)\)}]], "Text",
  Editable->False,
  TextAlignment->Center,
  TextJustification->0,
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Relation",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["between",
        "Subsubsection"], 
      StyleBox["  ",
        "Subsubsection"], 
      StyleBox[Cell[BoxData[
            FormBox[
              StyleBox[
                SubsuperscriptBox["\[Gamma]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                FontSize->14], TraditionalForm]], "Subsubsection"],
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["and",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["the",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["displacement",
        "Subsubsection"], 
      StyleBox["   ",
        "Subsubsection"], 
      StyleBox["\[DoubleStruckU]",
        "Subsubsection",
        FontSize->14], 
      StyleBox["  ",
        "Subsubsection"], 
      StyleBox["of",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["each",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["point",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["of",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["the",
        "Subsubsection"], 
      StyleBox[" ",
        "Subsubsection"], 
      StyleBox["body",
        "Subsubsection"]}]], "Subsubsection"],

Cell[TextData[{
  "The deformation tensor ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubsuperscriptBox["\[Gamma]", 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                FormBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"]}],
              SequenceForm[ 
                red[ i], 
                red[ j]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                StyleForm[ 
                  red[ j], ShowContents -> False]],
              Editable->False]],
          FontSize->16], TraditionalForm]]],
  " is completely described when, for each point ",
  StyleBox["s",
    FontWeight->"Bold"],
  " of the body, we know the displacement vector ",
  StyleBox["u",
    FontWeight->"Bold"],
  ", which extend from the position before deformation to that occupied by \
the same material point after deformation."
}], "Text"],

Cell["The displacement can be written :", "Text"],

Cell[BoxData[
    \(\[DoubleStruckU] = \[DoubleStruckE]u[red@i] ud[red@i]\)], "Input"],

Cell[TextData[{
  StyleBox["To simplify the problem in a first approch, we consider \
rectilinear coordinate systems ",
    Background->None],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["x", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]]],
  StyleBox[", in which the basis vectors are constant  (and for that we \
define ",
    Background->None],
  StyleBox["ConstantBasisRules[\[DoubleStruckE]_]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[")",
    Background->None]
}], "Text",
  Background->None],

Cell[BoxData[
    \(\(ConstantBasisRules[\[DoubleStruckE]_] := {PartialD[
              Tensor[\[DoubleStruckE], {i_}, {Void}], j_] :> 0, \n
          PartialD[Tensor[\[DoubleStruckE], {Void}, {i_}], j_] :> 
            0};\)\)], "Input"],

Cell[BoxData[
    \(PartialD[\[DoubleStruckE]u[red@i], red@j] /. 
      ConstantBasisRules[\[DoubleStruckE]]\)], "Input"],

Cell[BoxData[{
    \(d\[DoubleStruckU] := 
      PartialD[\[DoubleStruckU], red@j] dxu[red@j] /. 
        ConstantBasisRules[\[DoubleStruckE]]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckU]\)}], "Input"],

Cell[BoxData[{
    \(d\[DoubleStruckA] =. ; d\[AHat] =. \), "\[IndentingNewLine]", 
    \(\(\[DoubleStruckU] + d\[AHat] == 
        d\[DoubleStruckA] + \[DoubleStruckU] + 
          d\[DoubleStruckU];\)\), "\[IndentingNewLine]", 
    \(ruled\[AHat] = \(Solve[%, d\[AHat]]\)[\([1]\)]\)}], "Input"],

Cell[BoxData[
    \(d\[DoubleStruckA] = \[DoubleStruckE]d[red@k] dxu[red@k]\)], "Input"],

Cell[BoxData[{
    \(d\[AHat]1 = d\[AHat] /. ruled\[AHat]\), "\[IndentingNewLine]", 
    \(d\[AHat]2 = d\[AHat]1 /. {i -> h, j -> l, k -> m}\)}], "Input"],

Cell[BoxData[
    \(d\[AHat]1 . d\[AHat]2 // 
      EvaluateDotProducts[\ \[DoubleStruckE], g, False]\)], "Input"],

Cell[BoxData[
    \(\(% // IndexChange[{{k, i1}, {l, j1}, {j, i1}, {m, j1}}]\) // 
      Factor\)], "Input"],

Cell[BoxData[
    \(d\[AHat]u2 = \(% // MetricSimplify[g]\) // 
        IndexChange[{{i, k}, {i1, i}, {j1, j}}]\)], "Input"],

Cell[TextData[{
  "Now using the definition of the strain tensor ",
  Cell[BoxData[
      SubsuperscriptBox["\[Gamma]", 
        InterpretationBox[
          RowBox[{
            TagBox[
              StyleBox["i",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
            "\[InvisibleSpace]", 
            TagBox[
              StyleBox["j",
                FontColor->RGBColor[1, 0, 0]],
              (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
          SequenceForm[ 
            StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
            StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
          Editable->False], 
        InterpretationBox[
          RowBox[{
            TagBox[
              StyleBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]", 
            TagBox[
              StyleBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)]}],
          SequenceForm[ 
            StyleForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              ShowContents -> False], 
            StyleForm[ 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              ShowContents -> False]],
          Editable->False]]]],
  Cell[BoxData[
      RowBox[{
        InterpretationBox[
          SubsuperscriptBox["dx", 
            InterpretationBox[
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              SequenceForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
              Editable->False]],
          Subsuperscript[ dx, 
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]], 
            SequenceForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
          Editable->False], " ", 
        InterpretationBox[
          SubsuperscriptBox["dx", 
            InterpretationBox[
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]],
              Editable->False], 
            InterpretationBox[
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              SequenceForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
              Editable->False]],
          Subsuperscript[ dx, 
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]], 
            SequenceForm[ 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
          Editable->False]}]]],
  "= ",
  Cell[BoxData[
      \(d\[AHat] . d\[AHat]\)]],
  " \[Dash]  ",
  StyleBox["d\[DoubleStruckA].d\[DoubleStruckA] ",
    FontWeight->"Bold"],
  "= ",
  Cell[BoxData[
      \(d\[AHat]u2\)]],
  StyleBox[" \[Dash] d\[DoubleStruckA]2",
    FontWeight->"Bold"]
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[Gamma]dd[red@i, 
          red@j]\  == \((\((d\[AHat]u2 - d\[DoubleStruckA]2)\) // 
              Factor)\)/\((dxu[red@i] 
              dxu[red@j])\)\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  "which has the correct ",
  StyleBox["i\[DoubleLeftRightArrow]j",
    FontWeight->"Bold"],
  " symmetry ( as ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["u", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        InterpretationBox[
                          RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ ",", 
                            red[ i]],
                          Editable->False],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ k], 
                      Dif[ 
                        red[ i]]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ",", 
                                red[ i]],
                              Editable->False],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False], 
                      StyleForm[ 
                        Dif[ 
                          red[ i]], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ u, 
                  SequenceForm[ 
                    red[ k], 
                    Dif[ 
                      red[ i]]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      Dif[ 
                        red[ i]], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["u", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        InterpretationBox[
                          RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ ",", 
                            red[ j]],
                          Editable->False],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False], 
                      Dif[ 
                        red[ j]]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ",", 
                                red[ j]],
                              Editable->False],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ k], 
                      StyleForm[ 
                        Dif[ 
                          red[ j]], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ u, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    Dif[ 
                      red[ j]]], 
                  SequenceForm[ 
                    red[ k], 
                    StyleForm[ 
                      Dif[ 
                        red[ j]], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}],
          FontFamily->"Courier",
          FontSize->16], TraditionalForm]]],
  "\[Congruent]",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            InterpretationBox[
              SubsuperscriptBox["u", 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ",", 
                          red[ j]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ k], 
                    Dif[ 
                      red[ j]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ",", 
                              red[ j]],
                            Editable->False],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    StyleForm[ 
                      Dif[ 
                        red[ j]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ u, 
                SequenceForm[ 
                  red[ k], 
                  Dif[ 
                    red[ j]]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ k], ShowContents -> False], 
                  StyleForm[ 
                    Dif[ 
                      red[ j]], ShowContents -> False]]],
              Editable->False], " ", 
            InterpretationBox[
              SubsuperscriptBox["u", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ",", 
                          red[ i]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ k], ShowContents -> False], 
                    Dif[ 
                      red[ i]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\",\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ",", 
                              red[ i]],
                            Editable->False],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    red[ k], 
                    StyleForm[ 
                      Dif[ 
                        red[ i]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ u, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ k], ShowContents -> False], 
                  Dif[ 
                    red[ i]]], 
                SequenceForm[ 
                  red[ k], 
                  StyleForm[ 
                    Dif[ 
                      red[ i]], ShowContents -> False]]],
              Editable->False]}],
          FontFamily->"Courier",
          FontSize->16], TraditionalForm]]],
  "). The last term which is quadratic in the displacement can be neglected \
for sufficiently small displacement. Then we have simply"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[Gamma]dd[red@i, red@j]\  == 
        PartialD[ud[red@i], red@j] + 
          PartialD[ud[red@j], red@i]\[IndentingNewLine]]\)], "Input"],

Cell[TextData[Cell[BoxData[
    RowBox[{
      RowBox[{
        StyleBox["In",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["practice",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["we",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["shall",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["prefer",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["in",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["the",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["following",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["as",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["a",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["measure",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["of",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["the",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["strain",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["the",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox[" ",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], 
        StyleBox["tensor",
          FontWeight->"Plain",
          FontSlant->"Plain",
          FontTracking->"Plain",
          FontVariations->{"Underline"->False,
          "Outline"->False,
          "Shadow"->False,
          "StrikeThrough"->False,
          "Masked"->False,
          "CompatibilityType"->0,
          "RotationAngle"->0}], "   ", 
        TagBox[
          StyleBox[
            InterpretationBox[
              SubsuperscriptBox["\[ScriptCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                     "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 
                        1.0, 0.0, 0.0]]&)]}],
                  SequenceForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False], 
                    StyleForm[ 
                      StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                      ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[ScriptCapitalE], 
                SequenceForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
                SequenceForm[ 
                  StyleForm[ 
                    StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False], 
                  StyleForm[ 
                    StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                    ShowContents -> False]]],
              Editable->False],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)]}], "=", 
      " ", 
      RowBox[{
        SubsuperscriptBox["\[Gamma]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
              "\[InvisibleSpace]", 
              TagBox[
                StyleBox["j",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
            SequenceForm[ 
              StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
              StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  TagBox[
                    StyleBox["j",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False], 
              StyleForm[ 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                ShowContents -> False]],
            Editable->False]], "/", "2"}]}]],
  FontFamily->"Times",
  FontSize->14]], "Text",
  FontSize->12,
  Background->RGBColor[1, 0.700008, 0.700008],
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[{
    \(\(\(Tensor[\[ScriptCapitalE]\[Section], {Void, Void}, {i_, 
          j_}] := \((PartialD[ud[red@i], red@j] + 
            PartialD[ud[red@j], red@i])\)/2\)\(\n\)
    \)\), "\n", 
    \(ResultFrame[\[ScriptCapitalE]dd[red@i, 
          red@j] == \[ScriptCapitalE]\[Section]dd[red@i, red@j]]\)}], "Input"],

Cell[BoxData[
    RowBox[{\(We\ can\ easily\ define\ other\ kind\ of\ strain\ components\ \
\[ScriptCapitalE]\), ",", 
      RowBox[{"and", " ", "indeed", " ", "we", " ", "have", 
        RowBox[{
          TagBox[
            StyleBox[
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            StyleForm[ 
                            i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False], 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          StyleForm[ 
                            StyleForm[ 
                            j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False], 
                        StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                       
                      SequenceForm[ 
                        StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                        
                        StyleForm[ 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "==", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["\[ScriptCapitalE]", 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)], "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                            i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            StyleForm[ 
                              StyleForm[ 
                              j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                              ShowContents -> False]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              StyleForm[ 
                              i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                              ShowContents -> False], 
                            StyleForm[ 
                            j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                          Editable->False]],
                      Subsuperscript[ \[ScriptCapitalE], 
                        SequenceForm[ 
                          StyleForm[ 
                          i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                          StyleForm[ 
                            StyleForm[ 
                            j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False]], 
                        SequenceForm[ 
                          StyleForm[ 
                            StyleForm[ 
                            i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                            ShowContents -> False], 
                          StyleForm[ 
                          j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                      Editable->False],
                    "TraditionalForm"], 
                  RowBox[{"(", 
                    RowBox[{
                    "some", " ", "authors", " ", "use", " ", "then", "  ", 
                      FormBox[
                        InterpretationBox[
                          SubsuperscriptBox["\[ScriptCapitalE]", 
                            InterpretationBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              SequenceForm[ 
                                StyleForm[ 
                                j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                              Editable->False], 
                            InterpretationBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              SequenceForm[ 
                                StyleForm[ 
                                i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
                              Editable->False]],
                          Subsuperscript[ \[ScriptCapitalE], 
                            SequenceForm[ 
                              StyleForm[ 
                              j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]], 
                            SequenceForm[ 
                              StyleForm[ 
                              i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]]],
                          Editable->False],
                        "TraditionalForm"]}], ")"}]}]}],
              FontFamily->"Courier",
              FontSize->16],
            (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], ".", 
          " ", 
          SubsuperscriptBox["\[ScriptCapitalE]", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)]}],
              SequenceForm[ 
                StyleForm[ 
                  StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False], 
                StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)], 
                "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                StyleForm[ i, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                StyleForm[ 
                  StyleForm[ j, FontColor -> RGBColor[ 1.0, 0.0, 0.0]], 
                  ShowContents -> False]],
              Editable->False]]}], " ", "will", " ", "here", " ", "be", " ", 
        "the", " ", "standard", " ", \(\(notation\)\(.\)\)}]}]], "Text"],

Cell[BoxData[
    \(\(ClearTensorShortcuts[{{\[DoubleStruckE], \[EHat], u, dx}, 
          1}, {{g, \[ScriptG], \[Gamma], \[Zeta], \ \[InvisibleSpace]\
\[ScriptCapitalE], \ \[InvisibleSpace]\[ScriptCapitalE]\[Section]}, 
          2}];\)\)], "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{962, 654},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"], None, Cell[ 
      "J.-F. Gouyet", "Header"]}, {
    Cell[ "Continuum Mechanics", "Header"], None, Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ColoredBasis"->{
    Cell[3309, 97, 71, 1, 41, "Section",
      CellTags->"ColoredBasis"]},
  "StrainTensor"->{
    Cell[33036, 899, 96, 1, 41, "Section",
      CellTags->"StrainTensor"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ColoredBasis", 140463, 3675},
  {"StrainTensor", 140558, 3678}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 39, 0, 76, "Title"],

Cell[CellGroupData[{
Cell[1840, 57, 172, 5, 61, "Section",
  InitializationCell->True],
Cell[2015, 64, 474, 10, 166, "Input",
  InitializationCell->True],
Cell[2492, 76, 498, 9, 166, "Input",
  InitializationCell->True],
Cell[2993, 87, 279, 5, 46, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3309, 97, 71, 1, 41, "Section",
  CellTags->"ColoredBasis"],
Cell[3383, 100, 2634, 72, 74, "Text"],
Cell[6020, 174, 104, 2, 46, "Input"],
Cell[6127, 178, 47, 0, 34, "Text"],
Cell[6177, 180, 176, 3, 46, "Input"],
Cell[6356, 185, 2968, 83, 54, "Text"],
Cell[9327, 270, 79, 1, 46, "Input"],
Cell[9409, 273, 149, 3, 46, "Input"],
Cell[9561, 278, 2054, 56, 35, "Text"],
Cell[11618, 336, 218, 3, 86, "Input"],
Cell[11839, 341, 2339, 68, 36, "Text"],
Cell[14181, 411, 260, 6, 66, "Input"],
Cell[14444, 419, 2566, 78, 36, "Text"],
Cell[17013, 499, 9976, 236, 40, "Text"],
Cell[26992, 737, 449, 8, 106, "Input"],
Cell[27444, 747, 5091, 136, 35, "Text"],
Cell[32538, 885, 461, 9, 106, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[33036, 899, 96, 1, 41, "Section",
  CellTags->"StrainTensor"],
Cell[33135, 902, 16101, 412, 58, "Text"],
Cell[49239, 1316, 263, 5, 46, "Input"],
Cell[49505, 1323, 55, 1, 46, "Input"],
Cell[49563, 1326, 65, 0, 34, "Text"],
Cell[49631, 1328, 122, 3, 34, "Text"],
Cell[49756, 1333, 263, 5, 46, "Input"],
Cell[50022, 1340, 182, 4, 46, "Input"],
Cell[50207, 1346, 11330, 300, 35, "Text"],
Cell[61540, 1648, 542, 12, 66, "Input"],
Cell[62085, 1662, 5240, 129, 34, "Text"],
Cell[67328, 1793, 91, 1, 46, "Input"],
Cell[67422, 1796, 93, 2, 34, "Text"],
Cell[67518, 1800, 114, 2, 46, "Input"],
Cell[67635, 1804, 259, 4, 86, "Input"],
Cell[67897, 1810, 10883, 262, 53, "Text"],

Cell[CellGroupData[{
Cell[78805, 2076, 3875, 111, 49, "Subsubsection"],
Cell[82683, 2189, 2483, 66, 57, "Text"],
Cell[85169, 2257, 49, 0, 34, "Text"],
Cell[85221, 2259, 86, 1, 46, "Input"],
Cell[85310, 2262, 1402, 41, 55, "Text"],
Cell[86715, 2305, 238, 4, 66, "Input"],
Cell[86956, 2311, 121, 2, 46, "Input"],
Cell[87080, 2315, 207, 4, 66, "Input"],
Cell[87290, 2321, 296, 5, 86, "Input"],
Cell[87589, 2328, 88, 1, 46, "Input"],
Cell[87680, 2331, 154, 2, 66, "Input"],
Cell[87837, 2335, 114, 2, 46, "Input"],
Cell[87954, 2339, 108, 2, 46, "Input"],
Cell[88065, 2343, 124, 2, 46, "Input"],
Cell[88192, 2347, 4667, 122, 35, "Text"],
Cell[92862, 2471, 236, 4, 86, "Input"],
Cell[93101, 2477, 15301, 364, 56, "Text"],
Cell[108405, 2843, 189, 3, 86, "Input"],
Cell[108597, 2848, 15828, 461, 51, "Text"],
Cell[124428, 3311, 325, 6, 86, "Input"],
Cell[124756, 3319, 11574, 243, 58, "Text"],
Cell[136333, 3564, 250, 4, 46, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

