(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    506986,       9974]*)
(*NotebookOutlinePosition[    511864,      10109]*)
(*  CellTagsIndexPosition[    511547,      10098]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
6. The Fundamental Equations 
of Continuum Mechanics\
\>", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  InitializationCell->True],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(\(\(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)\(\n\)
    \)\), "\n", 
    \(\(numequ = 1;\)\), "\[IndentingNewLine]", 
    \(ResultFrame[i_] := 
      StyleForm[
        SequenceForm["\<      \>", 
          i, "\<      (6.\>", \(numequ++\), "\<)\>"], 
        Background -> RGBColor[0, 1, 0], Magnification -> 1.2]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}, {green, ForestGreen}, {star, 
        SuperStar}, {blue, Blue}, {hat, OverHat}, {tilde, Overtilde}, {bar, 
        OverBar}]\), "\[IndentingNewLine]", 
    \(\(black = Identity;\)\), "\[IndentingNewLine]", 
    \(\(DeclareBaseIndices[{1, 2, 3}];\)\), "\n", 
    \(\({NDim, BaseIndices};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], x, y, u, 
            v, \[Omega], \[ScriptCapitalE], dr, ds, dt, dA, X, a, A, 
            f, \[CapitalPhi], \[CapitalOmega], p, n}, 
          1}, {{g, \[ScriptCapitalE], \[Gamma], \[Sigma], \[Delta], u, v, s, 
            e, \[CapitalPhi], k}, 2}, {{e, \[Sigma], \[Epsilon], u, v}, 
          3}, {{\[DoubleStruckCapitalE]}, 4}];\)\)], "Input",
  InitializationCell->True],

Cell["\<\
The following values are taken as an example of a (red) basis frame :\
\>", "Text"],

Cell[BoxData[{\(SetMetricValues[g, 
      IdentityMatrix[3]]\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"RedBasisVectors", "=", 
        RowBox[{"(", GridBox[{
              {"1", "1", "0"},
              {"0", "1", "2"},
              {"1", "0", "1"}
              }], ")"}]}], ";", 
      RowBox[{"RedMetric", "=", 
        StyleBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"2", "1", "1"},
                {"1", "5", "2"},
                {"1", "2", "2"}
                },
              ColumnAlignments->{Decimal}], "\[NoBreak]", ")"}],
          FontFamily->"Courier",
          FontSize->12]}], 
      StyleBox[";",
        FontFamily->"Courier",
        FontSize->
          12]}], "\[IndentingNewLine]", \
\(SetTensorValueRules[\[DoubleStruckE]d[red@i], 
      RedBasisVectors]\), "\[IndentingNewLine]", \(SetTensorValueRules[\
\[DoubleStruckE]u[red@i], 
      Inverse[RedBasisVectors // 
          Transpose]]\), "\[IndentingNewLine]", \(SetMetricValueRules[g, 
      RedMetric, red]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(g[Identity] = 1; g[red] = 9;\)], "Input"],

Cell[BoxData[{
    \(d\[DoubleStruckR] := 
      dru[red@i]\ \[DoubleStruckE]d[red@i]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckS] := 
      dsu[red@j] \[DoubleStruckE]d[red@j]\), "\[IndentingNewLine]", 
    \(d\[DoubleStruckT] := dtu[red@k]\ \[DoubleStruckE]d[red@k]\)}], "Input"],

Cell["and from equation (2.5) :", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(Tensor[\[ScriptCapitalE]\[Section], {Void, Void}, {i_, 
          j_}] := \((PartialD[ud[red@i], red@j] + 
            PartialD[ud[red@j], red@i])\)/2\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\[DoubleStruckU] = uu[red@i] \[DoubleStruckE]d[red@i];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Kinematic Relations", "Section",
  CellTags->"Kinematic Relations"],

Cell[TextData[{
  "The kinematic equation have been presented in the section ",
  StyleBox["Strain Tensor",
    FontWeight->"Bold"],
  " of Chapter 2, in a non tensorial form, involving partial derivatives. \
Using the results of Chapter 5 on the covariant derivatives, and the fact \
that we have tensors, it can be easily shown that we can identify in \
cartesian coordinates the partial derivatives with the covariant derivatives \
and then see that the kinematic equations take the form"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[ScriptCapitalE]dd[red@i, 
          red@j]\  == \(1\/2\) \((CovariantD[ud[red@i], red@j] + 
              CovariantD[ud[red@j], red@i] + 
              CovariantD[uu[red@k], red@i] 
                CovariantD[ud[red@k], 
                  red@j])\)\[IndentingNewLine]]\)], "Input"],

Cell["\<\
and the linear version of the kinematic equation may be written,\
\>", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\[ScriptCapitalE]dd[red@i, 
          red@j]\  \[Equal] \((\[ScriptCapitalE]\[Section]dd[red@i_, 
              red@j_] = \(1\/2\) \((CovariantD[ud[red@i], red@j] + 
                  CovariantD[ud[red@j], 
                    red@i])\))\)\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  "This equation is now valid in any coordinate system. The above equation is \
symmetrical in its indices, but what is the meaning of the antisymmetric \
expression ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{\(1\/2\), " ", 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["u", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ j]],
                                  Editable->False],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ i], 
                              Cov[ 
                                red[ j]]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    InterpretationBox[
                                      
                                      RowBox[{"\<\";\"\>", 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                      SequenceForm[ ";", 
                                        red[ j]],
                                      Editable->False],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              StyleForm[ 
                                Cov[ 
                                  red[ j]], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ u, 
                          SequenceForm[ 
                            red[ i], 
                            Cov[ 
                              red[ j]]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ j]], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "-", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["u", 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ i]],
                                  Editable->False],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              red[ j], 
                              Cov[ 
                                red[ i]]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    InterpretationBox[
                                      
                                      RowBox[{"\<\";\"\>", 
                                        "\[InvisibleSpace]", 
                                        FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                      SequenceForm[ ";", 
                                        red[ i]],
                                      Editable->False],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ j], ShowContents -> False], 
                              StyleForm[ 
                                Cov[ 
                                  red[ i]], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ u, 
                          SequenceForm[ 
                            red[ j], 
                            Cov[ 
                              red[ i]]], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ j], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ i]], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"]}], ")"}], "."}]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " Consider the tensor "
}], "Text"],

Cell[BoxData[
    \(\[Omega]u[k_] := \(-\(1\/2\)\) CovariantD[ud[i], j] 
        euuu[i, j, k]\)], "Input"],

Cell["and we have the identity :", "Text"],

Cell[BoxData[
    \(\((\[Omega]u[k] // ToFlavor[red])\) \[DoubleStruckE]d[
          red@k] == \(1\/2\) \(TCurl[\[DoubleStruckE], g, red /@ {j, i, k}, 
            e]\)[\[DoubleStruckU]]\)], "Input"],

Cell["that is to say,", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]Tensor[\[Omega], {red@
                i}, {Void}] \[DoubleStruckE]d[red@i] == \(1\/2\) 
          curl[\[DoubleStruckU]]\[IndentingNewLine]]\)], "Input"],

Cell["In cartesian coordinates,", "Text"],

Cell[BoxData[
    \(\(\((\(\[Omega]u[3] // SumExpansion[{i, j}]\) // 
              LeviCivitaSimplify[e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[
            g, black]\) /. PermutationSymbolRule[\[Epsilon]] // 
      Factor\)], "Input"],

Cell[TextData[{
  "In this expression, ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Omega]", 
                  InterpretationBox[
                    TagBox[
                      StyleBox["3",
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 3, ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox["3",
                    SequenceForm[ 3],
                    Editable->False]],
                Subsuperscript[ \[Omega], 
                  SequenceForm[ 
                    StyleForm[ 3, ShowContents -> False]], 
                  SequenceForm[ 3]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "is the average rotation of a deformable volume element in the plane \
{1,2}."
}], "Text"],

Cell[CellGroupData[{

Cell["Compatibility conditions", "Subsection"],

Cell[TextData[{
  "There are three displacements ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["u", 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False], 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ u, 
                  SequenceForm[ 
                    red[ i]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  ", but six different strain components ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ". In fact if we calculate the second derivatives of ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ", and there combination"
}], "Text"],

Cell[BoxData[{
    \(CovariantD[\[ScriptCapitalE]dd[red@i, red@j], {red@k, red@l}] 
      euuu[red@i, red@k, red@m] 
      euuu[red@j, red@l, red@n]\), "\[IndentingNewLine]", 
    \(% /. {CovariantD[\[ScriptCapitalE]dd[red@i, red@j], {l1_, l2_}] :> 
          CovariantD[\((\(1\/2\) \((CovariantD[ud[red@i], red@j] + 
                    CovariantD[ud[red@j], red@i])\))\), {l1, 
              l2}]}\), "\[IndentingNewLine]", 
    \(\(\(\((\(\(% // SumExpansion[red@i, red@j, red@k, red@l]\) // 
                  ArrayExpansion[red@m, red@n]\) // 
                LeviCivitaSimplify[e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[
              g, red]\) /. PermutationSymbolRule[\[Epsilon]] // 
        SymmetricStandardOrder[u, {2, 4}]\) // Simplify\)}], "Input"],

Cell[TextData[{
  "The above matrix {m,n} is symmetrical and the six equations corresponding \
to {m,n}={1,1},{2,2},{3,3},{1,2},{2,3},{3,1} give ",
  StyleBox["zero",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[{
    \(\(CovariantD[\[ScriptCapitalE]dd[red@i, red@j], {red@k, red@l}] 
        euuu[red@i, red@k, red@m] euuu[red@j, red@l, red@n];\)\), "\n", 
    \(\(\(res = \(\(\(\((\(\(9  % // 
                          SumExpansion[red@i, red@j, red@k, red@l]\) // 
                        ArrayExpansion[red@m, red@n]\) // 
                      LeviCivitaSimplify[e])\) /. \(LeviCivitaRule[
                      e, \[Epsilon]]\)[g, red]\) /. 
                PermutationSymbolRule[\[Epsilon]] // 
              SymmetricStandardOrder[\[ScriptCapitalE], {1, 2}]\) // 
            SymmetricStandardOrder[\[ScriptCapitalE], {3, 4}]\) // 
          Simplify;\)\(\n\)
    \)\), "\n", 
    \(restable = \[IndentingNewLine]{res[\([1, 1]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([2, 2]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([3, 3]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([1, 2]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([2, 3]\)] \[Equal] 
            0, \[IndentingNewLine]res[\([3, 1]\)] \[Equal] 0} // 
        TableForm\)}], "Input"],

Cell[TextData[{
  StyleBox["In cartesian coordinates the compatibility equations are",
    FontVariations->{"Underline"->True}],
  " (the covariant derivatives being then identical to partial derivatives):"
}], "Text"],

Cell[BoxData[
    \(\(\((\(\(restable /. Cov \[Rule] Dif // ToFlavor[black, red]\) // 
                DifToPartialD[{x, \[Delta], g, \[CapitalGamma]}]\) // 
              UseCoordinates[{x, y, z}])\) /. {\[ScriptCapitalE]dd[1, 
                1] -> \[ScriptCapitalE]d[x], \[ScriptCapitalE]dd[2, 
                2] -> \[ScriptCapitalE]d[y], \[ScriptCapitalE]dd[3, 
                3] -> \[ScriptCapitalE]d[z], \[ScriptCapitalE]dd[1, 
                2] \[Rule] \(1\/2\) \[Gamma]dd[x, y], \[ScriptCapitalE]dd[2, 
                3] \[Rule] \(1\/2\) \[Gamma]dd[y, z], \[ScriptCapitalE]dd[1, 
                3] \[Rule] \(1\/2\) \[Gamma]dd[x, z]} // FullSimplify\) // 
      TableForm\)], "Input"],

Cell["In the covariant form we would have written :", "Text"],

Cell[BoxData[
    \(\(\(\((\(\(restable // ToFlavor[black, red]\) // 
                  TensorNesting[\[ScriptCapitalE]]\) // 
                TensorNesting[\[ScriptCapitalE]])\) /. {\[ScriptCapitalE]dd[
                  1, 1] -> \[ScriptCapitalE]d[x], \[ScriptCapitalE]dd[2, 
                  2] -> \[ScriptCapitalE]d[y], \[ScriptCapitalE]dd[3, 
                  3] -> \[ScriptCapitalE]d[z], \[ScriptCapitalE]dd[1, 
                  2] \[Rule] \(1\/2\) \[Gamma]dd[x, y], \[ScriptCapitalE]dd[
                  2, 3] \[Rule] \(1\/2\) \[Gamma]dd[y, 
                    z], \[ScriptCapitalE]dd[1, 
                  3] \[Rule] \(1\/2\) \[Gamma]dd[x, z], 
              Cov[1] \[Rule] Cov[x], Cov[2] \[Rule] Cov[y], 
              Cov[3] \[Rule] Cov[z]} // TensorUnNesting[\[ScriptCapitalE]]\) // 
        TensorUnNesting[\[Gamma]]\) // FullSimplify\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Condition of Equilibrium and Equation of Motion", "Section",
  CellTags->"Condition of Equilibrium and Equation of Motion"],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
3g[ooooo07D0`00A0_l<0?ooooooo`00ool000300000M@000000002Q0<03NBE@
Kg=dDf=bJG1d84QQHf/PHWTPCFU[IB12LVmbLb0a<Rlg;cT`3Bm4JG=QHVaUCVEh
M5=UM597@T=_K6mb3@Uk3@UeLfEbI6USM21RIFMYKPd9;g=UM79WHV=_K6mb80d9
2G/=2@U`Kg0=2@U`Kg0=2@U`Kg0=2@UeLfEbI6USM21RIFMYKPd92BmcIGAbIf9S
Kfa_LR1cNG=dIFeTJF=d82mcIGAbIf9SKfa_LR1WIG@PI6EV3@T9IFiT3@T9OB1T
IFH=2FE^I0em869YKV@PI6EV3BmRHf5bLV5i87MXIG9U87/=2G1_L0d9HV=QLW9Q
NB0b87/=2@T_I64P=21`Lb1TJGHPI6EV3@T9I6HPLfEdIVm^M21WLf5fIB1SLb1g
J@d92C4PJFiTIGPP<21^IG]UN6=X86AQ865TI21UN6=XOFUV86MbIG=dKg9U87=U
M6=XHG9gJFAdJ0d92F=c830P<21cKF<PI64P<21cKF<PI64PI64PLfeS830PI64P
LfeS86<=2@UWLV5i3@T9Nb1WK7d=2@Uk<B1cIGAWLV5iOFUVIFacI@d92FAQ838^
86AYMR1TMG0PKFmfIGA_87=XKgL=2GeRJFiT871eM0em86UV3BD=9B1ELfET87A_
87=^HG0PM6lPI6EfJF=U871YN6E/Lb`P<BldM6PPKfHPM6QU871YN6E/86U^;Pd_
LgA`87/P82DPN21i821`K20PN21i820P820P820P820P820P82DPDfiQL21DKb1@
JGQUK2`PL6UhIF`P82QQMGA_87=dLVm[IB1QI6YeLg@Y3@UdLV5^LfI_LVd=2C0^
<SDPLgER879_MFiT830^<SDPHFAT86EhHfP=2C0^<SDPLgER879_MFiT830^<SDP
HFAT86EhHfP=2FUdLV5^LfI_LVd=OB1RJFiT86AUIPd=;g=^HG1]KgIUM6lPNb0U
87PPNB0PKB0P;B0P820P820P820P820U86e_MVEdKb`PHGEdKb1cM79_JfDPHFAZ
MG=d3@UcM70P86e_MVEdK`em869YKV@PI6EV3@d_LfiQL6aYKVEdKb1k82DPN21i
821/820]820P820P820P820P82DPK6U^IGA_;21QMGA_87=dLVm[IB1QI6YeLg@=
2G=dL21/JFiUM6l=OB1RJFiT86AUIPd00:00S00N00402_ooool0M@3000L00000
00P02P0S0000X02<00`00?oQ00402_oPool0EP3002<0002P08`03?oool<00@0:
oj?ooP0I0;l08`000:00X02Q0:@00@8000402P000000000002801@1c00008oH4
02<0000S1?`08`0002?lo00S00008`X402<0000100[oXoon01T0_`2400X00000
0000002P0:<0X02n00P0201a01h0001X00P0LP040780201X00@0K00006P0101b
028000000000X02o0:00X@0S0000X@2f00@00@010:00X02Q0:@00@4000402P00
0000000000L00@0102801@1c00008oH402<0000S1?`08`0002?lo00S00008`X4
02<0002P0:<0X02n00402_nSooh06@2o00L0000002<0002Q0;H0100100408P04
0780002Q0;H0100100401`010040L00N0000J0080780101b00P0J00406`0001X
00@0LP2P0;l0X02Q00L0000002<0002Q0;H0100100401`0200808P02001[0@2P
08d0X02<00`00@0m00402_oPool0EP3000L00000028000000000X02P0:40Y001
0P000@0:0000000000008P0101h0000S00/08`0002?nn`0S00008oX202<0000S
2?P08`0000402_oPool0EP3008@02P00000000000:00X`2P0;h0L@0N00005@0;
01d0000M00/07@0601/0200E00007@0R000000000:00_`2P0:408`000:40]P04
00400@2P0:00X@2T0041000100X000000000000700400@0R00407P0002<02`0S
00008okk02<0000SnP808`0002<8n00S0000X02S0:00_P0100[oh?oo05H0`007
0000000S0000X@2f00@00@010280000M0000X@2f00@00@0100L00@0107007P00
01D02`0M00007@0;01d01P0K00P05@0001d0X02o0:00X@070000000S0000X@2f
00@00@0100L00P020280@0006/D0X02=0:00S00<003og@0100[o_Ooo03<0`007
0000000R000000000:00X02Q0:@00@8000402P000000000002800@0a00008oX9
02<0000S0OX08`0002?jo`0S00008`_n02<0000100[o_Ooo03<0`02400X00000
0000002P0:<0X02n07407P0002D02@0`0000<00902X00`0[00809@0003008P00
0000002P0;l0X02Q02<0002Q0;H010010040X02P0:40Y0010@000@0:00000000
00001`0100408P010340000SnPT08`0002<1nP0S00008o[o02<0000S2oh08`00
0:00X`2P0;h00@0:okgoo`0c0<001`0000008`000:40]P0400400@0R0000<000
0:40]P0400400@0700400@1`01h0000U00T0<00003002@0Z00<0:`0202D0000`
0:00_`2P0:401`0000008`000:40]P0400400@0S0000X@2f00@00@010:40f004
0020002Q0=H01000P000X03G0:40]00500022@T000L00P0200P05`0R01h00B[U
0:00]@2Q0=H01000P000X03G0:00f@070000000800P08`000:40]P0400400@2Q
0=H01000P000X@3H00@008000:00_P2P0=T0L@0N01P0000O00X07@0001P0200J
00X07`0201d0001a01h03P0?01D06@0C00l03P0G01006@0E01404`0?07407P05
01h0300X00X07P0502H01`0X00`0800:01h0X@3H00@008000:00_`2P0=T0X03G
0:00S@2P08d0X02<00co]@1200402_oook@0M@1e0280000000008`000:40]P04
00400@0700400@0SL@401`0000008`000:40]P0400400@0700400@0R0440EQbo
00L0000002<0002Q0;H0100100401`0100408P0N04<_hP2P08d0301;00000@0:
ooooo`1e0<001`0000008`000:40]P0400400@2P0:00X@2T0041000100X00000
0000000700400@0R0040C@0002?@7`0S00008g4002<0000Si4008`0002<_hP0S
0000X02S0:00_P0100[ooooo07D0`0070000000S0000X@2f00@00@010280@@2P
0000X@2f00@00@0100L00@0107007P0001`0G`2P0000C00O01`07`2=05l0L@11
0:00X02o0:00X@070000000S0000X@2f00@00@0102<0002Q0;H010010040X@3H
00@008000:40eP040020002P0=L0X@2d00D000892@001`010040200G0280@00^
7L00X02e0:40eP040020002P0=L0X03I00L0000000P0200S0000X@2f00@00@01
0:40eP040020002Q0=P01000P000X02n0:00f@0700400@0R0400;PCh0280<00e
1?L08P0O03d4n00R00l0A0Ch0:40f0040020002P0;l0X03I0:00e`2P08`03?oA
ol<00@0:ol;od00h09401`0000008P000000002P0:00X@2T0042000100X00000
0000000R00D0M00002?h100S00008`?l02<0000SoO`08`0002<8100S00000@0:
ol;od00h0940Q00:000000000000X02S0:00_P1a01h0001[00P0L`0407<0201[
00@0KP0006/0101c028000000000X02o0:00X@0S0000X@2f00@00@010:00X02Q
0:@00@4000402P000000000000L00@0102801@1d00008oP402<0000S0o`08`00
02?mo00S00008`P402<0002P0:<0X02n00402_o2om00>02A00L0000002<0002Q
0;H0100100408P0407<0002Q0;H0100100401`010040L00N0000J`0807<0101c
00P0J`0406h0001[00@0L`2P0;l0X02Q00L0000002<0002Q0;H0100100408`00
0:40]P0400400@2Q0=P01000P000X@3F00@008000:00e`2Q0;@01@000PT90007
00400@0801L08P03001]002P0;D0X@3F00@008000:00e`2P0=T01`0000002008
02<0002Q0;H010010040X@3F00@008000:40f0040020002P0;h0X03I00L00@01
02800`0020008P030188000R00<090P002800`0f20008P0304P8000R00<0FPP0
02800`1/0000X@3H00@008000:00_`2P0=T0X03G0:00S@2Q09H0304000020000
0000000<om;og`0100X0000001D04`070000000R000000000:00V02Q09X02?o`
J80006J002`04POJ3eAYKFEc84iUMb1BKfeQKP031mX0108000d04P0^00@00?l0
02X@0F@000@3000Y2@5b002P09T0X02G02<0002Q09H03040000200000000000<
02h0800100X0000001D04P0S0000X02H0:40VP08oo18P000>000108002P04000
0F@010<002T90G<00:00V@2P09L08`000:40UP0<0@0000800000000000`0;@0[
00402P0000005@0A02<0002P09P0X@2J00Sol1f0000:P0040P00:00@0001I004
0`00:@T1M000X02I0:00U`0S0000X02=0?l\>"], "Graphics",
  Editable->False,
  ImageSize->{193, 118},
  ImageMargins->{{264, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000AM00@0005P0000=00003@0005X1002Y0000
00000000001H9@00KQ<00215CDH00040@1L108`0000500000000000000000@0000@00003000>0@00
b`0004H00034PP00]X8004M4BD<1002000<00=PMfZd00000WX8000402@000dm100070>Xj000000D0
000;0_ooool5000030:>0101100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700<0000N00D2003g0003007oool000100000P0000?l0
0200000P@0008800023o00100000@40004200010o`00H0000610001PP000H?l008000020@000P800
083o002P0000X4000:20002Po`00`0000<100030P000`?l00?l0003o@000oh000?oo0200000P0400
80200200o`0P80008210020PP00P8?l084000210@00P@800843o021P000PH4008620021Po`0PP000
88100220P00PP?l08:00022P@00PX8008:3o0230000P`4008<200230o`0Po`008?m0023oP00Pool0
@0000400@0100800@03o040P00108400@220040Po`10@000@4100410P010@?l0@600041P@010H800
@63o04200010P400@8200420o`10X000@:10042PP010X?l0@<000430@010`800@<3o043o0010od00
@?n0043oo`1P0000H0100600P01P0?l0H200060P@01P8800H23o0610001P@400H4200610o`1PH000
H610061PP01PH?l0H8000620@01PP800H83o062P001PX400H:20062Po`1P`000H<100630P01P`?l0
H?l0063o@01Poh00H?oo080000200400P0200800o`208000P210080PP0208?l0P4000810@020@800
P43o081P0020H400P620081Po`20P000P8100820P020P?l0P:00082P@020X800P:3o08300020`400
P<200830o`20o`00P?m0083oP020ool0X0000:00@02P0800X03o0:0P002P8400X2200:0Po`2P@000
X4100:10P02P@?l0X6000:1P@02PH800X63o0:20002PP400X8200:20o`2PX000X:100:2PP02PX?l0
X<000:30@02P`800X<3o0:3o002Pod00X?n00:3oo`300000`0100<00P0300?l0`2000<0P@0308800
`23o0<100030@400`4200<10o`30H000`6100<1PP030H?l0`8000<20@030P800`83o0<2P0030X400
`:200<2Po`30`000`<100<30P030`?l0`?l00<3o@030oh00`?oo0?l0003o0400o`200?l0o`3o8000
ob100?lPP03o8?l0od000?m0@03o@800od3o0?mP003oH400of200?mPo`3oP000oh100?n0P03oP?l0
oj000?nP@03oX800oj3o0?o0003o`400ol200?o0o`3oo`00oom00?ooP0000000100003@21P030000
=@0400001`430>Xj00133b00c00004l0KP4000004`1502H0_P0X0000KP4004l0000100P00000091a
000000000000000000000000oooo040000200000o`00000P00108000P2000?lP0000@000@4000810
003o@0000600041P0020H000of0000200010P000P8000?n00000X000@:00082P003oX0000<000430
0020`000ol00003o0010o`00P?l00?oo00000200@00P0800803o0200020P040P80208200ob0P0010
8010@200P40P0?m08000H200@60P081P803oH200080P04208020P200oh0P002P8010X200P:0P0?nP
8000`200@<0P0830803o`2000?lP043o8020ob00oolP0000@0100400P0100?l0@0008400@210080P
@03o840004100410@020@400od10001P@010H400P6100?mP@000P400@8100820@03oP4000:10042P
@020X400oj100030@010`400P<100?o0@000od00@?m0083o@03ood00001P0400H0200600o`1P000P
H0108600P21P0?lPH000@600@41P0810H03o@600061P041PH020H600of1P0020H010P600P81P0?n0
H000X600@:1P082PH03oX6000<1P0430H020`600ol1P003oH010of00P?mP0?ooH0000800@0200800
P03o08000220040PP0208800ob200010P010@800P4200?m0P000H800@620081PP03oH80008200420
P020P800oh20002PP010X800P:200?nPP000`800@<200830P03o`8000?n0043oP020oh00oon00000
X0100:00P02P0?l0X0008:00@22P080PX03o8:00042P0410X020@:00od2P001PX010H:00P62P0?mP
X000P:00@82P0820X03oP:000:2P042PX020X:00oj2P0030X010`:00P<2P0?o0X000oj00@?nP083o
X03ooj0000300400`0200<00o`30000P`0108<00P2300?lP`000@<00@4300810`03o@<000630041P
`020H<00of300020`010P<00P8300?n0`000X<00@:30082P`03oX<000<300430`020`<00ol30003o
`010ol00P?o00?oo`0000?l0@03o0800o`3o0?l0023o040Po`208?l0ob3o0010o`10@?l0P43o0?m0
o`00H?l0@63o081Po`3oH?l0083o0420o`20P?l0oh3o002Po`10X?l0P:3o0?nPo`00`?l0@<3o0830
o`3o`?l00?oo043oo`20ool000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3P0000h>3P
h>3Ph>00003Ph>3Ph>3Ph00000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>3Ph>3P
h>3Ph03Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3P000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>3Ph000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P
00000000h>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P0000
0000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003Ph>3Ph0000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000h>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003Ph>3Ph0000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P0000
0000h>3Ph>0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000>3Ph>3P00000000000000000000000000000000000000000000
000000000000000000000?ooooooooooool000000000000000000000000000000>3Ph>3P00000000
h>3Ph>3P0000003Ph>3Ph000000000000000000000000000000000000000000000000000oooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooool0000000000000003o
ooooooooooooooooool000000000000000000000h>3Ph>0000000000000000000000000000000000
0000000000000000000000000000ooooooooooooooooooooool0000000000000000000000000h>3P
h>3Ph000003Ph>3Ph>3P00000>3Ph>3P000000000000000000000000000000000000000000000000
oooooooooooooooooooo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooooooooooooooooooool0oooooooooooooooooooooooooooooooooooooooo0000
00000000oooooooooooooooooooooooo0000000000000000003Ph>3Ph00000000000000000000000
000000000000000000000000000000000000ooooooooooooooooooooooooooooo`00000000000000
003Ph>3Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000h>3Ph>3P000000000000000000000000000000000000
00000000ooooooooooooooooooooooooool000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000003ooooooooooooooooooooooooo0000000000000000003Ph>3Ph00000000000
000000000000000000000000000000000000000000000?oooooooooo00000000003ooooooooooooo
000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000
00000000000000000?ooooooooooooooooooooooooooool000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0000000000?ooooooooooooooooooooooool000000000000000000>3Ph>3P
0000000000000000000000000000000000000000000000000000003ooooooooo0000000000000000
003oooooooooool00000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000000000000000
0000000000000000000000000000oooooooooooooooooooooooooooooooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000ooooooooooooooooooooooooo`00000000000000
0000h>3Ph>0000000000000000000000000000000000000000000000000000000?oooooooooo0000
0000000000000000003oooooo`0000000>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000
0000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooo0000
000000000000003Ph>3Ph000000000000000000000000000000000000000000000000000003ooooo
ooooool0000000000000000000000000ool000000000003Ph>3Ph>3Ph000h>3Ph>3Ph000h>3Ph>3P
h>3P00000000000000000000000000000000000000000000ooooooooooooo`0000000000oooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000ooooooooooooool000000000
003oooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooooooooooo
ooooo`0000000000000000000>3Ph>3P000000000000000000000000000000000000000000000000
00000?ooool0ooooo`000000000000000000000000000000000000000000000000000000h>3Ph>00
00000>3Ph>3Ph0000000000000000000000000000000000000000000003oooooooooo`0000000000
0000003oooooooooo`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003oooooooooool0
0000000000000000oooooooooooooooo00000000003oooooooooo`00000000000000000000000000
ooooooooool00000000000000000000000000>3Ph>3P000000000000000000000000000000000000
000000000000003oooooo`3oooooo`00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?ooooooool0
0000000000000000003oooooooooo`00000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooooooo000000000000000000000?ooooooooooool0000000000?oooooooooo0000000000000000
00000000003ooooooooo0000000000000000000000000000h>3Ph>00000000000000000000000000
0000000000000000000000000?oooooo003ooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
oooooooo000000000000000000000000ooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003oooooooooo`00000000000000000000000?ooooooooooo`00000000000?oooooooooo0000
000000000000000000000?ooooooool0000000000000000000000000003Ph>3Ph000000000000000
000000000000000000000000000000000000ooooo`000?ooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooool0000000000000000000000000ooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?ooooooool00000000000000000000000000?oooooooooo0000000000000?oo
oooooooo000000000000000000000000ooooooooo`000000000000000000000000000>3Ph>3P0000
00000000000000000000000000000000000000000000003ooooo0000ooooool00000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooooooo`00000000000000000000000000oooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000ooooooooo`000000000000000000000000000?oooooooooo0000
00000000ooooooooool000000000000000000000003ooooooooo0000000000000000003Ph>3Ph>3P
h>3Ph>000000000000000000000000000000000000000000000000000?ooool00000ooooo`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooo0000000000000000000000000000oooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooo00000000000000000000000000000?oo
ooooool0000000000000ooooooooooooooooooooooooooooooooooooooooool00000000000000000
h>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000000000000000000000000000ooooo`00003o
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooool00000000000000000000000000000
oooooooo000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?ooooooool000000000000000000000
00000000ooooooooo`00000000000000oooooooooooooooooooooooooooooooooooooooo00000000
00000000003Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000000000000000
ooooo`000?oooooo0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003oooooool00000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000ooooooooo`0000000000
0000000000000000003ooooooooo000000000000003ooooooooooooooooooooooooooooooooooooo
ool000000000000000000>3Ph>3Ph>3Ph>3Ph>3P0000000000000000000000000000000000000000
00000000003ooooo00000?ooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooo`000000
00000000000000000000003oooooool0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000oooooooo
0000000000000000000000000000003oooooool0000000000000003ooooooooooooooooooooooooo
ooooooooooooo`000000000000000000003Ph>3Ph>3Ph>3Ph>000000000000000000000000000000
000000000000000000000?ooool00000ooooooooooooooooooooooooooooooooool0000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooo00000000000000000000000000000?ooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003ooooooooo00000000000000000000000000000?ooooooool00000000000000?oooooooooooooo
oooooooooooooooooooooooo00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool0003oooooooooooooooooooooooooooooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000oooooooo0000000000000000000000000000oooooooo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?ooooooool00000000000000000000000000000ooooooooo`000000000000000?oo
ooooooooooooooooooooooooooooooooool000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000ooooo`00003ooooooooooooooooooooooooo
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003oooooool00000000000000000000000000000oooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooool0000000000000000000000000003ooooooooo00000000
000000000?oooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000oooo00000?ooool000000000
0000000000000000oooo000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooool0000000000000000000000000003oooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000ooooooooool0000000000000000000000000oooooooo
ool00000000000000000ooooooooool00000000000000?ooooooool0000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003ooooo0000oooo
ool000000000000000000000003ooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000?ooooooool00000000000000000000000000?oo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000ooooooooo`0000000000000000000000
003oooooooooool00000000000000000ooooooooool0000000000000ooooooooo`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
oooo0000ooooo`00000000000000000000000?ooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?ooooooool00000000000000000
00000000oooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003oooooooooo`0000000000
000000000000ooooooooooooo`000000000000000000ooooooooool000000000003ooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oool0003ooooo000000000000000000000000ooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooool00000
0000000000000000003oooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
ool00000000000000000003ooooooooooooo0000000000000000003oooooooooo`0000000000oooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooool00?oooooo00000000000000000000003ooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000?oo
ooooool0000000000000000000000?ooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003oooooooooool0000000000000003oooooooooooooool00000000000000000003oooooooooo`00
0000003ooooooooo0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool00?ooool000000000000000000000ooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooool00000000000000000003ooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?ooooooooooooooo`000000003oooooooooooooooooool00000000000000000003o
oooooooo000000000?ooooooool00000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooool0ooooo`000000000000000000003o
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooooooo00000000000000000?ooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooooooooooooooooooooooooooooooooooo`0000000000
000000000?oooooooooo00000000ooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003oooooooooo`0000000000
00000000ooooool00000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooooooooooool0000000000?ooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
000000000000000000000?oooooooooo0000003ooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
0000000000000000oooooooo00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooo
ooooooooool000000000000000000000ooooooooool00000ooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003oooooooooo`0000000000ooooooooo`0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000?oooooooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003ooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000ooooooooool0003ooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000ooooooooooooooooooooooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
ooooooooooooooooooooooooooooooooo`000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000003P
h>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>3Ph00000000000000000000000000000000000oooo
ooooooooooooooooooooo`00ooooooooo`0000000000000000000000ooooooooool00?ooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000?ooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000oooooooooooooooooooooooooooooooooooooooo00000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph000h>3Ph>3Ph>3Ph>3Ph03Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00000000000000000000000000
000000000?ooooooooooooooooooo`00003ooooooooo00000000000000000000003oooooooooo`00
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooo0000003Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000000000000000
0000000000000000000000000?oooooooooo000000000?ooooooool000000000000000000000003o
ooooooooo`3ooooooooo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooooooooooooooooooooooooooooooool000000>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P0000
00000000000000000000000000000000000000000000000000000000ooooooooo`00000000000000
00000000003oooooooooooooooooool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000003Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3P
h>3Ph00000000000000000000000000000000000000000000000000000000000003oooooooooo`00
000000000000000000000?oooooooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph000
00000>3Ph>3P0000000000000000000000000000000000000000000000000000000000000000003o
oooooooo0000000000000?ooooooooooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph0000000
0>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000000000000000
000000000?ooooooool000000000003oooooooooooooooooooooooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000003P
h>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000ooooooooo`00000000000?oooooooooooooooooooooooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000>3Ph>3P000000000000
000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000003oooooooooooooooooo`0000000000oooooooooooooooooooooooooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000h>3Ph>00
00000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooo00000000003ooooooooooooooooo
oooooooooooo00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003Ph>3Ph0000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>00000000000000
0000000000000000000000000000000000000000003oooooooooooooooooool000000000003ooooo
ooooooooooooooooooooool000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3P000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph000
00000000000000000000000000000000000000000000000000000?ooooooooooooooooooo`000000
00000000ooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>00000000000000000000000>3Ph>3P00000000h>3Ph>000000
003Ph>3Ph0000000000000000000000000000000000000000000000000000000oooooooooooooooo
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003P
h>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000000000000000oooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3P
h00000000>3Ph>3P00000000h>3Ph>00000000000000000000000000000000000000000000000000
000000000?ooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000>3Ph>3P0000000000000000
00000>3Ph>3P00000000h>3Ph>3P0000003Ph>3Ph000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
0000000000000000h>3Ph>3Ph000003Ph>3Ph>3P00000>3Ph>3P0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph000000000000000003Ph>3Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000h>3Ph>3P0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph000000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3P0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000h>3Ph>000000000000000>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003Ph>3Ph000000000000000003Ph>3Ph>3Ph000
h>3Ph>3Ph000h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000
000000000000h>3Ph>0000000>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003Ph>3Ph0000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000h>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3P000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000100002L1
ool40000l04600@000040@d0100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000@0
000]0@@010000?010@070000o0800000000000@0000]0@403P0002@31@1l06T0LP1]07D0J@1b06D0
O01Y00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<507`0J@1b06d0
M@1Y0780I@1l06T0100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80
2P1X07D0J@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@0V02P0
9P0c02<0;P0N03009P0X00@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<502H0:00V03<08`0^01h0<00V02P0100002d10`040000l04000P0003j0P000P02000000840000
;@4000P0000U0`802P1Y02<0;P040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00
3P0002@31@0i04/0<`1D03<0C`0^04d0>@1;00@0000]0@<010000?0100080000nP8000400@000002
100002d1000>00009@<503T0B`0c05@0<`1?02h0C@0i04/0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000h0000T0`D02@1Y0140I00C06D02`1Z00T0J@0>000090<501P0G`0P05/0
8P1L01X0H00H05l03P0002@31@0W05H0;`1A0340DP0Y05L09`1F00@0000]0@<010000?0100080000
nP8000400@000002100002d1000800009@<205<02P3500X0200002D30P2Y04X0a@0:00P0000U0`80
UP0X0<D02P0>00009@<505D02@0T02T0U@0X07X0J02Y04X0200002D30P1D00X0D00B00P0000U0`80
C@0J04T08`0800009@<204H0:`1203<0200002D30P0n03/0>`1400P0000U0`80>@1:0440BP080000
9@<204/0BP1C04X0200002D30P1M04X0I@1:00P0000U0`80K`1:07L0BP0800009@<20840BP2904X0
200002D30P2C04X0V`1:00P0000U0`80Y@1:0:T0BP0500002@800002100002h100040000;@4500@0
003`0@8070000?/2k_l00000002@0@400000000bE6U]IG<PCVEg859_KF5^00000000000000000000
00040000;@4200L0000Q1@40I?mZ06H01@0000T200000P@0000^0@00100002d11@040000l04201`0
003k0^ko00000000_08100000000<UAYKFEc84iUMb1BKfeQKP0000000000000000000000100002d1
0P0700008@D107;oJP1_00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`00
000009010@000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`000245
0@1TodX0>00500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002l0P40
0000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40Lom:0440
1@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T04100000000<UAY
KFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D106Co7P0;00D000090P00
00840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`20@000000039DJFeULb1>IGLP
DVm]HFh00000000000000000000000@0000]0@801`0002450@1doah050040000;@4300@0003`0@00
20000?X21@000000oooo0P@0000]0@003P0002@31@3@01h0b@0V0<X08@3501l0d00N00@0000]0@<0
10000?0100080000nP8000400@000002100002d1000>00009@<50=007P3902H0bP0Q0<D07`3@01h0
100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80X`0g0<X08@040000
9`7oo`@0003`0@0010000?010@040000l04200@0003`0@<010000?0110040000l04500<000000=co
4@0000`0000800002`000100001[0@00_00000T0000@0000J`400;`0000:000040000?oooooooooo
2@000100000@0@00SP000180000<00000@00024000080000500000`0000700009P0001`000010000
000000400001000000000RD0000<00000@0002D0000<00000000P580001<0@000P00000000000000
00000000001N0@00000000000B000<M5j000j@@0001VodGX3km5j0noC@`k`@n=C@000:6l0[013km=
j8]E20noC8X2:l431K@2/04?_dgXR`000014RP:Q^0:`0@noCNR;E@P?_`b::l431K02/04?_dgXReD8
IXT4R^VOoooojBh0003Y:@000>TT0000PggH0`n76P0008]5f?lTQEBU[`4VY:l1M:B_0GVT[`75Y:l1
jM82000?_`G20[01RDGDjAX1001VadGX003Y100006H00>P?_dGX3km=33_13he=0000XK`2/04?_dgX
ReD83km<RP8[`@<5]0:`0@noCNR;E@QVRDB:0Z6h0[013km=00000000000000000000000000000000
0@410@410@410@009@0000`0000200008@0000P0000a000040@000<000000`01oooo0000@0000800
003o000P000084000220000Po`00@00004100010P000@?l00600001P@000H800063o00200000P400
08200020o`00X0000:10002PP000X?l00<000030@000`8000<3o003o0000od000?n0003oo`0P0000
80100200P00P0?l08200020P@00P8800823o0210000P@40084200210o`0PH0008610021PP00PH?l0
88000220@00PP800883o022P000PX4008:20022Po`0P`0008<100230P00P`?l08?l0023o@00Poh00
8?oo040000100400@0200400o`108000@210040PP0108?l0@4000410@010@800@43o041P0010H400
@620041Po`10P000@8100420P010P?l0@:00042P@010X800@:3o04300010`400@<200430o`10o`00
@?m0043oP010ool0H0000600@01P0800H03o060P001P8400H220060Po`1P@000H4100610P01P@?l0
H600061P@01PH800H63o0620001PP400H8200620o`1PX000H:10062PP01PX?l0H<000630@01P`800
H<3o063o001Pod00H?n0063oo`200000P0100800P0200?l0P200080P@0208800P23o08100020@400
P4200810o`20H000P610081PP020H?l0P8000820@020P800P83o082P0020X400P:20082Po`20`000
P<100830P020`?l0P?l0083o@020oh00P?oo0:00002P0400X0200:00o`2P8000X2100:0PP02P8?l0
X4000:10@02P@800X43o0:1P002PH400X6200:1Po`2PP000X8100:20P02PP?l0X:000:2P@02PX800
X:3o0:30002P`400X<200:30o`2Po`00X?m00:3oP02Pool0`0000<00@0300800`03o0<0P00308400
`2200<0Po`30@000`4100<10P030@?l0`6000<1P@030H800`63o0<200030P400`8200<20o`30X000
`:100<2PP030X?l0`<000<30@030`800`<3o0<3o0030od00`?n00<3oo`3o0000o`100?l0P03o0?l0
ob000?lP@03o8800ob3o0?m0003o@400od200?m0o`3oH000of100?mPP03oH?l0oh000?n0@03oP800
oh3o0?nP003oX400oj200?nPo`3o`000ol100?o0P03o`?l0ool00?oo@03ooh0000000300000<0000
0`0003@0000800005@0000`000030000D@0000ag003o0000=00005X1001<0000_P0002H000000000
000006h1001?0000D00002`5001l1@00T7400000000P0<`0A@0001<0000X0000KP4004l0000100P0
0000091a000000000000000000000000oooo040000200000o`00000P00108000P2000?lP0000@000
@4000810003o@0000600041P0020H000of0000200010P000P8000?n00000X000@:00082P003oX000
0<0004300020`000ol00003o0010o`00P?l00?oo00000200@00P0800803o0200020P040P80208200
ob0P00108010@200P40P0?m08000H200@60P081P803oH200080P04208020P200oh0P002P8010X200
P:0P0?nP8000`200@<0P0830803o`2000?lP043o8020ob00oolP0000@0100400P0100?l0@0008400
@210080P@03o840004100410@020@400od10001P@010H400P6100?mP@000P400@8100820@03oP400
0:10042P@020X400oj100030@010`400P<100?o0@000od00@?m0083o@03ood00001P0400H0200600
o`1P000PH0108600P21P0?lPH000@600@41P0810H03o@600061P041PH020H600of1P0020H010P600
P81P0?n0H000X600@:1P082PH03oX6000<1P0430H020`600ol1P003oH010of00P?mP0?ooH0000800
@0200800P03o08000220040PP0208800ob200010P010@800P4200?m0P000H800@620081PP03oH800
08200420P020P800oh20002PP010X800P:200?nPP000`800@<200830P03o`8000?n0043oP020oh00
oon00000X0100:00P02P0?l0X0008:00@22P080PX03o8:00042P0410X020@:00od2P001PX010H:00
P62P0?mPX000P:00@82P0820X03oP:000:2P042PX020X:00oj2P0030X010`:00P<2P0?o0X000oj00
@?nP083oX03ooj0000300400`0200<00o`30000P`0108<00P2300?lP`000@<00@4300810`03o@<00
0630041P`020H<00of300020`010P<00P8300?n0`000X<00@:30082P`03oX<000<300430`020`<00
ol30003o`010ol00P?o00?oo`0000?l0@03o0800o`3o0?l0023o040Po`208?l0ob3o0010o`10@?l0
P43o0?m0o`00H?l0@63o081Po`3oH?l0083o0420o`20P?l0oh3o002Po`10X?l0P:3o0?nPo`00`?l0
@<3o0830o`3o`?l00?oo043oo`20ool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P003P
h>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>00003Ph>3P
h>3Ph0000>3Ph>3Ph>3P000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph000
00000>3Ph>3P00000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0>3Ph>3P00000000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3P0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3P
h0000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph000
00000>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
003Ph>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003Ph>3Ph0000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000ooooooooooooo`00000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000h>3Ph>0000000000
00000000000000000000000000000000000000000000000000000000ooooooooooooo`0000000000
00000000000000000000h>3Ph>000000003Ph>3Ph>0000000>3Ph>3P000000000000000000000000
000000000000000000000000003ooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003ooooooooooooooooooooo0000oooooooooooooooooooo
ooooooooooooooooo`000000000000000?ooooooooooooooooooo`000000000000000000003Ph>3P
h00000000000000000000000000000000000000000000000000000000000003ooooooooooooooooo
ooooo`0000000000000000000000003Ph>3Ph>3P00000>3Ph>3Ph>000000h>3Ph>00000000000000
00000000000000000000000000000000003oooooooooooooooooool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooooooooooooooooooooooo`3ooooooooo
ooooooooooooooooooooooooooooool000000000003oooooooooooooooooooooool0000000000000
00000>3Ph>3P00000000000000000000000000000000000000000000000000000000003ooooooooo
oooooooooooooooooooo00000000000000000>3Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>00
0000000000000000000000000000000000000000003oooooooooooooooooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000?ooooooooooooooooooooooool0
00000000000000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
ooooooooool0000000000?ooooooooooool000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph0000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
o`000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000oooooooooooooooo
ooooooooo`000000000000000000h>3Ph>0000000000000000000000000000000000000000000000
000000000?ooooooool000000000000000000?ooooooooooo`0000000>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000003ooooooooooooooooo
ooooooooooooool00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000003ooooo
oooooooooooooooooooo0000000000000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000ooooooooool0000000000000000000000?oooooo00000000h>3Ph>3Ph>3P
h03Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph0000000000000000000000000000000000000000000oooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
0000003oooooooooooooooooooooool000000000000000000>3Ph>3P000000000000000000000000
00000000000000000000000000000?ooooooooooo`0000000000000000000000003oo`0000000000
0>3Ph>3Ph>3P003Ph>3Ph>3P003Ph>3Ph>3Ph>000000000000000000000000000000000000000000
003ooooooooooooo00000000003ooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooo
oooo0000000000000000oooooooooooooooooooo00000000000000000000h>3Ph>00000000000000
0000000000000000000000000000000000000000ooooo`3ooooo0000000000000000000000000000
000000000000000000000000003Ph>3Ph0000000h>3Ph>3P00000000000000000000000000000000
0000000000000?oooooooooo00000000000000000?oooooooooo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooooooooooo`00000000000000003oooooooooooooool0000000000?oo
oooooooo000000000000000000000000003oooooooooo`00000000000000000000000000h>3Ph>00
0000000000000000000000000000000000000000000000000?oooooo0?oooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000ooooooooo`0000000000000000000?oooooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooooooool000000000000000000000ooooooooooooo`00
00000000ooooooooool00000000000000000000000000?ooooooool0000000000000000000000000
003Ph>3Ph000000000000000000000000000000000000000000000000000ooooool00?ooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003oooooool000000000000000000000003ooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000?oooooooooo000000000000000000000000oooo
oooooooo000000000000ooooooooool0000000000000000000000000ooooooooo`00000000000000
0000000000000>3Ph>3P000000000000000000000000000000000000000000000000003ooooo0000
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooooooo`0000000000000000000000003o
oooooooo000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000ooooooooo`000000000000000000
00000000ooooooooool0000000000000ooooooooool000000000000000000000003ooooooooo0000
000000000000000000000000h>3Ph>00000000000000000000000000000000000000000000000000
0?ooool0003oooooo`00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000oooooooo0000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003ooooooooo00000000
00000000000000000000ooooooooool000000000003oooooooooo`00000000000000000000000?oo
ooooool000000000000000000>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000
000000000000ooooo`00003ooooo0000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003oooooool00000
00000000000000000000003oooooool0000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ool00000000000000000000000000000ooooooooo`0000000000003ooooooooooooooooooooooooo
ooooooooooooooooo`00000000000000003Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000
00000000000000000000003ooooo00000?ooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000?oo
ooooo`00000000000000000000000000003oooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000ooooooooo`00000000000000000000000000003ooooooooo000000000000003ooooooooooooo
ooooooooooooooooooooooooool000000000000000000>3Ph>3Ph>3Ph>3Ph>3P0000000000000000
00000000000000000000000000000000003ooooo0000ooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000?ooooooo`000000000000000000000000000?ooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003ooooooooo00000000000000000000000000000?ooooooool00000000000000?oo
ooooooooooooooooooooooooooooooooooooo`000000000000000000h>3Ph>3Ph>3Ph>3Ph>000000
000000000000000000000000000000000000000000000?ooool00000ooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooo00000000000000000000000000000?ooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003oooooool000000000000000000000000000000?ooooooo`000000
000000000?oooooooooooooooooooooooooooooooooooooo000000000000000000000>3Ph>3Ph>3P
h>3Ph000000000000000000000000000000000000000000000000000ooooo`00003ooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooool00000000000000000000000000000oooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?ooooooool00000000000000000000000000000oooo
ooooo`00000000000000ooooooooooooooooooooooooooooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000ooooo`000?oo
ooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooool0000000000000000000000000003o
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000ooooooooo`0000000000000000000000
0000003ooooooooo0000000000000000ooooooooooooooooooooooooooooooooooooo`0000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
oooo00000?oooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?ooooooo`000000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000ooooooooo`0000000000
00000000000000000?ooooooool00000000000000000ooooooooooooooooooooooooooooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oool00000ooooo`0000000000000000000000003oool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooo`000000
000000000000000000000?ooooooo`00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
o`0000000000000000000000003oooooooooo`00000000000000003oooooooooo`00000000000000
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooool0003oooooo`00000000000000000000000?ooool0000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
ooooo`00000000000000000000000000oooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003ooooooooo0000000000000000000000000?ooooooooooo`00000000000000003oooooooooo`00
00000000003ooooooooo000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool0003ooooo000000000000000000000000ooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooo`0000000000000000000000003oooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooooooo00000000000000000000003ooooooooooooo0000000000000000003o
ooooooooo`00000000000?ooooooool0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooo`000?ooool000000000000000000000
003ooooo000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000ooooooooo`00000000000000000000000?ooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooo`0000000000000000000?ooooooooooool000000000
000000000?oooooooooo00000000003oooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000ooooo`00ooooool000000000
0000000000000?ooool0000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000ooooooooo`0000000000000000000000oooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?ooooooooooo`000000000000000?oooooooooooooo
o`0000000000000000000?oooooooooo000000000?ooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000ooooo`00oooo
o`000000000000000000003oooooo`00000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooooooo`0000000000000000000?oooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000oooooooooooooooo000000000?oooooo
ooooooooooooo`0000000000000000000?ooooooool000000000ooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooo`3ooooo000000000000000000000?ooool00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003oooooooooool0000000000000
0000ooooooooo`000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooo00000000000000000000ooooooooool00000003ooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooooooo0000000000000000003oooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
o`0000000000oooooooooooo00000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooooooooooooooooooooooooooooooool000000000000000000000ooooooooool000000?oooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooool0000000000000003oooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?ooooooooooooooooooooooooooooooooooooooo`000000000000000000003oooooooooo`00
003oooooooooo`000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?oooooooooo00000000003ooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooo00000000000000000000003o
ooooooooo`000?ooooooool000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000003oooooooooooooooooooooooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo000000000>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>0000000>3Ph>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000
0000000000000000000000000000003ooooooooooooooooooooooooo003ooooooooo000000000000
00000000003oooooooooo`00ooooooooo`0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000oooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003oooooooooooooooooooooooooooooooooooooool0
0000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00h>3P
h>3Ph>3Ph00000000000000000000000000000000000oooooooooooooooooooo00000?ooooooool0
000000000000000000000?oooooooooo003ooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooo`000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
ooooooooool000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3P
h>3Ph000h>3Ph>3Ph>3P0000000000000000000000000000000000000000ooooooooool000000000
ooooooooo`00000000000000000000000?oooooooooo0?ooooooool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
ooooooooooooooooooooo`000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph000h>3Ph>3Ph>3Ph>3P
h000h>3Ph>3Ph>3P003Ph>3Ph>3Ph>00000000000000000000000000000000000000000000000000
00000000003ooooooooo0000000000000000000000000?ooooooooooooooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>0000000>3P
h>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000000000000000000000000000000000000000
000000000000000000000?oooooooooo000000000000000000000000ooooooooooooooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph00000000000
00000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000
000000000000000000000000000000000?ooooooool0000000000000oooooooooooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P
000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000ooooooooo`00000000000?oooooooooooooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000h>3Ph>00000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000
0000000000000000000000000000000000000000000000000000003ooooooooo000000000000oooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P
000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo0000
0000003oooooooooooooooooooooooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph00000000>3Ph>3P0000
0000h>3Ph>000000000000000000000000000000000000000000000000000000003ooooooooooooo
ooooool0000000000?ooooooooooooooooooooooooooool000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000>3Ph>3P000000000000000000000>3Ph>3P00000000
h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000000000000000000000000?oo
ooooooooooooooooo`00000000000?ooooooooooooooooooooooooooo`0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000h>3Ph>0000000000000000000000h>3P
h>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000000000000000000000000000
00000000oooooooooooooooooooo000000000000003ooooooooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph000000000000000
00000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000000000000000
0000000000000000003oooooooooooooooooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph000
0000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>00000000000000000000000000
0000000000000000000000000000003oooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0>3Ph>3P000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph000000000000000
00000000000000000000000000000000000000000000ooooooooooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph>0000000>3Ph>3P0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph>3P00000>3Ph>3Ph>000000
h>3Ph>00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P00000000000000000>3Ph>3Ph>3Ph>3P0000h>3P
h>3Ph>00003Ph>3Ph>00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P000000000000003Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000000000000>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph0000000
00000000h>3Ph>3Ph>3Ph03Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph0000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000>3P
h>3P00000000000000000>3Ph>3Ph>3P003Ph>3Ph>3P003Ph>3Ph>3Ph>0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000h>3Ph>000000000000000000000000000000003Ph>3Ph0000000h>3Ph>3P000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000>3Ph>3P00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000h>3Ph>0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3P
h0000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P
h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000h>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000>3Ph>3Ph>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000R000030000?oooolX0000300000<0000D0000300000d0000V0000
700000<00005000000000000003oool29@0000`0000300009@0000`000040020EP000300002I0000
Q`000:L0002B00001@0007`0J@1b06d0M@1Y0780I@1l06T09@0000`000010000:00000`000030000
9P0001`000030000000000400001000000000RD0000<00000`0005L0000`0000V@0008L0002W0000
TP0000D0001l06T0LP1]07D0J@1b06D0O01Y02D0000<00000@0002P0000<00000`0002H0000L0000
0`000000000200000P000000008U0000300000<0001G0000900000h0002:0000WP0008d000020000
2P1X07D0J@0U000030000040000X0000300000<0000V0000700000<00005000000000000003oool2
9@0000`000030000EP000300000Y0000=P0003@0001500001@0002H0:00V03<08`0^01h0<00V02P0
9@0000`000010000:00000`0000300009P0001`000030000000000400001000000000RD0000<0000
0`0005L0000`0000:@0003H0000d0000A@0000D0000V02P09P0c02<0;P0N03009P0X02D0000<0000
0@0002P0000<00000`0002H0000L00000`000000000200000P000000008U0000300000<0001G0000
900000h0000m0000<@0008d0000200002P1Y02<0;P0U000030000040000X0000300000<0000V0000
700000<00005000000000000003oool29@0000`000030000EP000300000o0000I@0004d0001a0000
1@0003T0B`0c05@0<`1?02h0C@0i04/09@0000`000010000:00000`0000300009P0001`000030000
000000400001000000000RD0000<00000`0005L0000`0000?`0006D0001=0000L@0000D0000i04/0
<`1D03<0C`0^04d0>@1;02D0000<00000@0002P0000<00000`0002H0000L00000`0000D000000000
00000?ooo`8U0000300000<0001F0000<00000d0002600006`0008h0000500002@1Y0140I00C06D0
2`1Z00T0J@1F0000<0000240001j0000;`00080000050000601O0200F`0R05`06P1P01P0G`1F0000
<00003D0001]0000@`0007D0000500009`1F02l0D@0a0580:@1G02L0EP0U000030000040000X0000
300000<0000V0000700000<0000000000@000040000000029@0000`000030000E`0002@0001`0000
3`0000P1000?00000P0005<02P3500X0E`0002@0003S00003`0000P1001S00000P000:T0BP3500X0
E`0002@0003:00003`0000P1000f00000P0009H0:03500X0E`000300000a00003@000><0002;0000
1@0005D02@0T02T0U@0X07X0J02Y04X0E`0002@0001/00003`000740000I00000P0005@02P1@0180
E`0002@0001S0000900006P0000`00000P0004d06P1902<0E`0002@0001I0000>P0005l000150000
0P0004H0:`1203<0E`0002@0001@0000C`0005@0001K00000P0003h0>`0k04@0E`0002@0001=0000
H`0005P0001S00000P0003T0BP1104X0E`0002@0001U0000H`000700001S00000P0004/0BP1C04X0
E`0002@0001m0000H`0008P0001S00000P0005d0BP1U04X0E`0002@0002E0000H`000:00001S0000
0P0006l0BP1g04X0E`0002@0002]0000H`000;P0001S00000P000840BP2904X0E`0002@000360000
H`000=00001S00000P0009<0BP2K04X0E`0002@0003N0000H`000><0001S00000P000:D0BP2Y04X0
600000`000000002DP0004`100040000k_ooo`000000000000000901000100000000<U@0J@1]06D0
L`0P04h0I@1g0200DP1_06d0H@1^0000k@000000003^000000000>l000000000l000000000000000
00000?8000000000l`000000003d000000000?D000000000mP000000003g000000000?P000000000
n@000000003j000000000?/000000000o0000000003m000000000?h000000000o`00000000000@00
00000000000000000P40000000030@00000000@1000000001@40000000060@00000000L100000000
204000000000000000000000000000000000000000010@410@410@41000U0000300000@0001D0000
E00008T0002>0000U0000:P0000100005l4<@[kj2d9V0000JP000040001<00000000000000000000
00000000001@0000I00000T0000U000030000080000X0000300000@0001B0000C04000@0003^oooo
0000000000000000_08000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h000000000
9P400000000W0@00000002P100000000:@400000000Z0@00000002/100000000;0400000000]0@00
000002h100000000;`400000000`0@000000034100000000<P400000000c0@00000003@100000000
=@400000000f0@00000003L100000000>0400000000i0@00000003X100000000>`400000000l0@00
000003d100000000?P400000000o0@000000040100000000@@400000000000000000000000000000
000000410@410@410@4002D0000<0000100005@0001D0000U@0008h0002M0000Z@000040000G`@a2
__X;@Vl0001Z00000@0004`000000000000000000000000000000500001b00001`0002D0000<0000
0P0002P0000<000010000580001<0@0010000>koool0000000000000002@0@000@000000039D06T0
K@1U07<0801>06D0M`0P0580K`1]0640KP0005h100000000G`400000001P0@000000064100000000
00000000001S0@00000006@100000000I@400000001V0@00000006L100000000J0400000001Y0@00
000006X100000000J`400000001/0@00000006d100000000KP400000001_0@000000070100000000
L@40000000000000000007<100000000M0400000001e0@00000007H100000000M`400000001h0@00
000007T100000000000000000000000000000000000000000@410@410@410@009@0000`000040000
E00005@0001<0000H`0005L0001m00000@0001O134:nnP]2>00004X000010000C000000000000000
0000000000000000D00006@0000900009@0000`000020000:00000`000040000DP0004`100040000
k_ooo`000000000000000;`2000100000000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000
000009L100000000V0400000002I0@00000009X100000000V`400000002L0@00000009d100000000
WP400000002O0@0000000:0100000000X@400000002R0@0000000:<100000000Y0400000002U0@00
00000:H100000000Y`400000002X0@0000000:T100000000ZP400000002[0@0000000:`100000000
[@400000002^0@0000000:l100000000/0400000002a0@0000000;81000000000000000000000000
0000000000010@410@410@41000U0000300000@0001D0000E00005P0001S0000H00007h000010000
5l4<@[kj2d910000BP000040001<0000000000000000000000000000001@0000L`0000L0000U0000
30000080000X0000300000@0001B0000C04000@0003^oooo0000000000000000T04000400000000b
E01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0003?0@0000000=0100000000d@400000003B0@00
0000000000000000e0400000003E0@0000000=H100000000e`400000003H0@0000000=T100000000
fP400000003K0@0000000=`100000000g@400000003N0@0000000=l100000000h0400000003Q0@00
00000>810000000000000000003T0@00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000410@410@410@4002D0000<0000
100005@0001D0000400002T0000K0000@`000040000G`@a2__X;@P/0000N00000@0004`000000000
000000000000000000000500001T00002@0002D0000<00000P0002P0000<000010000580001<0@00
10000>koool0000000000000002l0P000@000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640
KP000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000@410@410@410@009@0000`000040000E00005@0000L0000:@00028000140000
0@0001O134:nnP]2500001h000010000C0000000000000000000000000000000D00007@000050000
9@0000`000010000:00000`0000300009P0001`0000300001@00000000000000oooo0RD0000<0000
0`0005H0000`0000204002T0000G0@00=00000D0003@01h0b@0V0<X08@3501l0d00N02D0000<0000
0@0002P0000<00000`0002H0000L00000`000000000100000@000000008U0000300000<0001G0000
<00000P1000Y00005`4003@000050000d00N0<T09P3:0240a@0O0=007P0U000030000040000X0000
300000<0000V0000700000<0000000000P000080000000029@0000`000030000E`0002@0003J0000
;0000101001;00000P000:<0=`3:02408P0000`0003ooooo:00000`000030000:00000`000040000
:00000`000010000:00000`000020000B`000100000000001@0000h0000D100000400100003oool0
00100000P0000?l00200000P@0008800023o00100000@40004200010o`00H0000610001PP000H?l0
08000020@000P800083o002P0000X4000:20002Po`00`0000<100030P000`?l00?l0003o@000oh00
0?oo0200000P040080200200o`0P80008210020PP00P8?l084000210@00P@800843o021P000PH400
8620021Po`0PP00088100220P00PP?l08:00022P@00PX8008:3o0230000P`4008<200230o`0Po`00
8?m0023oP00Pool0@0000400@0100800@03o040P00108400@220040Po`10@000@4100410P010@?l0
@600041P@010H800@63o04200010P400@8200420o`10X000@:10042PP010X?l0@<000430@010`800
@<3o043o0010od00@?n0043oo`1P0000H0100600P01P0?l0H200060P@01P8800H23o0610001P@400
H4200610o`1PH000H610061PP01PH?l0H8000620@01PP800H83o062P001PX400H:20062Po`1P`000
H<100630P01P`?l0H?l0063o@01Poh00H?oo080000200400P0200800o`208000P210080PP0208?l0
P4000810@020@800P43o081P0020H400P620081Po`20P000P8100820P020P?l0P:00082P@020X800
P:3o08300020`400P<200830o`20o`00P?m0083oP020ool0X0000:00@02P0800X03o0:0P002P8400
X2200:0Po`2P@000X4100:10P02P@?l0X6000:1P@02PH800X63o0:20002PP400X8200:20o`2PX000
X:100:2PP02PX?l0X<000:30@02P`800X<3o0:3o002Pod00X?n00:3oo`300000`0100<00P0300?l0
`2000<0P@0308800`23o0<100030@400`4200<10o`30H000`6100<1PP030H?l0`8000<20@030P800
`83o0<2P0030X400`:200<2Po`30`000`<100<30P030`?l0`?l00<3o@030oh00`?oo0?l0003o0400
o`200?l0o`3o8000ob100?lPP03o8?l0od000?m0@03o@800od3o0?mP003oH400of200?mPo`3oP000
oh100?n0P03oP?l0oj000?nP@03oX800oj3o0?o0003o`400ol200?o0o`3oo`00oom00?ooP0000000
50@0
\>"], "Graphics",
  Editable->False,
  ImageSize->{328, 153.625},
  ImageMargins->{{290, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["\<\
The edges of the infinitesimal block of material (figure), are the vectors,\
\>", "Text"],

Cell[BoxData[
    \({d\[DoubleStruckR], d\[DoubleStruckS], d\[DoubleStruckT]}\)], "Input"],

Cell[TextData[{
  "The face on the right hand side is ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["dA", 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["l",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ l]],
                Editable->False], 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["l",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ l], ShowContents -> False]],
                Editable->False]],
            Subsuperscript[ dA, 
              SequenceForm[ 
                red[ l]], 
              SequenceForm[ 
                StyleForm[ 
                  red[ l], ShowContents -> False]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]], "Output"],
  " equal to,"
}], "Text"],

Cell[BoxData[{\(\((\(d\[DoubleStruckS]\[Cross]
                d\[DoubleStruckT] // \(LinearBreakout[
                  Cross]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]]\) // 
            CrossProductExpansion[\[DoubleStruckE], e, 
              h])\) . \[DoubleStruckE]d[red@l];\), "\[IndentingNewLine]", 
    RowBox[{\(d\[ScriptCapitalA]d[red@l_]\), "=", 
      RowBox[{"%", "//", 
        RowBox[{"EvaluateDotProducts", "[", 
          RowBox[{
            FormBox["\[DoubleStruckE]",
              "TraditionalForm"], ",", "g"}], "]"}]}]}]}], "Input"],

Cell["\<\
The difference between the forces applied on opposite faces are then given \
by,\
\>", "Text"],

Cell[BoxData[{
    \(CovariantD[
            dAd[red@l] \[Sigma]uu[red@l, red@m] \[DoubleStruckE]d[red@m], 
            red@i] dru[red@i] /. CovariantD[dAd[red@l], red@i] \[Rule] 0 // 
      CovariantDSimplify[\[DoubleStruckE], g]\), "\[IndentingNewLine]", 
    \(force1 = 
      Coefficient[% /. dAd[red@l] \[Rule] d\[ScriptCapitalA]d[red@l], 
        dru[red@i] dsu[red@j] dtu[red@k]]\)}], "Input"],

Cell["\<\
Similar expression are obtained for the two others opposite faces, and \
globally we have\
\>", "Text"],

Cell[BoxData[{
    \(force2 = 
      force1 // IndexChange[{{i, j}, {j, k}, {k, 
              i}}]\), "\[IndentingNewLine]", 
    \(force3 = force2 // IndexChange[{{i, j}, {j, k}, {k, i}}]\)}], "Input"],

Cell[BoxData[
    \(res1 = \((force1 + force2 + force3)\) dru[red@i] dsu[red@j] dtu[red@k] // 
        Factor\)], "Input"],

Cell["\<\
This expression is identical to (see also the section treating the Gauss \
theorem in three dimensions, for a similar result)\
\>", "Text"],

Cell[BoxData[
    \(res2 = 
      dru[red@i] dsu[red@j] dtu[red@k] 
        CovariantD[\[Sigma]uu[red@l, red@m], red@l] 
        eddd[red@i, red@j, red@k] \[DoubleStruckE]d[red@m]\)], "Input"],

Cell[BoxData[
    \(\((\(\(res1 // SumExpansion[red@i, red@j, red@k, red@l]\) // 
            LeviCivitaSimplify[e]\) // 
          Simplify)\) \[Equal] \((\(\(res2 // 
              SumExpansion[red@i, red@j, red@k, red@l]\) // 
            LeviCivitaSimplify[e]\) // Simplify)\)\)], "Input"],

Cell[TextData[{
  "In addition, we see that ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["dr", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ i]],
                      Editable->False]],
                  Subsuperscript[ dr, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ i]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["ds", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ j]],
                      Editable->False]],
                  Subsuperscript[ ds, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ j]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["dt", 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["k",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ k], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["k",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ k]],
                      Editable->False]],
                  Subsuperscript[ dt, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ k], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ k]]],
                  Editable->False],
                "TraditionalForm"], " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["e", 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        red[ i], 
                        red[ j], 
                        red[ k]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["k",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          red[ k], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ e, 
                    SequenceForm[ 
                      red[ i], 
                      red[ j], 
                      red[ k]], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      StyleForm[ 
                        red[ k], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]], "Output"],
  " is the volume  ",
  Cell[BoxData[
      \(TraditionalForm\`d\[ScriptCapitalV]\)], "Output"],
  " of the block, so that the resultant of all the stresses is"
}], "Text"],

Cell[BoxData[
    \(TotalStress = \((res2 /. 
            dru[red@i] dsu[red@j] dtu[red@k] 
                eddd[red@i, red@j, red@k] \[Rule] d\[ScriptCapitalV])\) // 
        IndexChange[{{m, i}, {l, j}}]\)], "Input"],

Cell["Superposed to the stress we can have an external force ", "Text"],

Cell[BoxData[
    \(ExternalForce = 
      d\[ScriptCapitalV]\ Xu[red@i] \[DoubleStruckE]d[red@i]\)], "Input"],

Cell["The system is in equilibrium if", "Text"],

Cell[BoxData[
    \(TotalStress + ExternalForce \[Equal] 0\ \ \  // FullSimplify\)], "Input"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Condition of Equilibrium :",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True}]], "Outline1"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((TotalForce = %[\([1, 
                3]\)])\) \[Equal] 0\[IndentingNewLine]]\)], "Input"],

Cell["\<\
The equilibrium of the moments is itself satisfied by the symmetry of the \
stress tensor (as shown in the above section on the stress tensor).\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamic equation ", "Subsection"],

Cell[TextData[{
  "In the limit of ",
  StyleBox["small ",
    FontSlant->"Italic"],
  "motion the Lagrangian or particle formulation and the Eulerian or field \
formulation coincide. We can associate a certain time dependent velocity to \
each particle, but since the particle always stay close to the position it \
has at rest, the same velocity is also associated with that point in space."
}], "Text"],

Cell["We define the usual notations,", "Text"],

Cell[BoxData[
    \(\[DoubleStruckU]\& .  = 
      PartialD[\[DoubleStruckU], 
          t] /. \(\(PartialD[\[DoubleStruckE]d[_], 
            t]\)\(\[Rule]\)\(0\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\)\( (*\ \ t\ is\ the\ time\ parameter\ \ \ *) \)\)\)], "Input"],

Cell[BoxData[
    \(Tensor[OverDot[u, 2], {red@i}, {Void}] \[DoubleStruckE]d[red@i] == 
        PartialD[\[DoubleStruckU]\& . , t] /. 
      PartialD[\[DoubleStruckE]d[_], t] \[Rule] 0\)], "Input"],

Cell["\<\
If  \[Rho]  is the mass density, we have the dynamic equation,\
\>", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]TotalForce[\([2]\)] \[Equal] \
\((totalforce = \[Rho]\ Tensor[OverDot[u, 2], {red@i}, {Void}] - 
              TotalForce[\([1]\)])\)\[IndentingNewLine]]\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fundamental Equations of the theory of Elasticity", "Section",
  CellTags->"Fundamental Equations"],

Cell[TextData[{
  "We have the basic equations describing the equilibrium and the small \
motions of an elastic solid :\n\n",
  StyleBox["(1) the kinematic relation\t\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[ScriptCapitalE]", 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[ScriptCapitalE], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "==", 
          RowBox[{\(1\/2\), " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["u", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ";", 
                                red[ j]],
                              Editable->False],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ i], 
                          Cov[ 
                            red[ j]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ j]],
                                  Editable->False],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            Cov[ 
                              red[ j]], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ u, 
                      SequenceForm[ 
                        red[ i], 
                        Cov[ 
                          red[ j]]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        StyleForm[ 
                          Cov[ 
                            red[ j]], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "+", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["u", 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ";", 
                                red[ i]],
                              Editable->False],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          red[ j], 
                          Cov[ 
                            red[ i]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ i]],
                                  Editable->False],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            Cov[ 
                              red[ i]], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ u, 
                      SequenceForm[ 
                        red[ j], 
                        Cov[ 
                          red[ i]]], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False], 
                        StyleForm[ 
                          Cov[ 
                            red[ i]], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], ")"}]}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\n\n(2) the equilibrium condition\t\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["X", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ X, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"], "+", " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        InterpretationBox[
                          RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ ";", 
                            red[ j]],
                          Editable->False],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      Cov[ 
                        red[ j]]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ";", 
                                red[ j]],
                              Editable->False],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ j], 
                      red[ i], 
                      StyleForm[ 
                        Cov[ 
                          red[ j]], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    Cov[ 
                      red[ j]]], 
                  SequenceForm[ 
                    red[ j], 
                    red[ i], 
                    StyleForm[ 
                      Cov[ 
                        red[ j]], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}], "==", "0", "\[InvisibleSpace]"}], 
        TraditionalForm]],
    FontSize->16],
  StyleBox["\t\tor the dynamic equation\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ";", 
                          red[ j]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    Cov[ 
                      red[ j]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ";", 
                              red[ j]],
                            Editable->False],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    red[ j], 
                    red[ i], 
                    StyleForm[ 
                      Cov[ 
                        red[ j]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ j], ShowContents -> False], 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  Cov[ 
                    red[ j]]], 
                SequenceForm[ 
                  red[ j], 
                  red[ i], 
                  StyleForm[ 
                    Cov[ 
                      red[ j]], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "==", 
          RowBox[{
            RowBox[{"\[Rho]", " ", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox[\(u\&\[DoubleDot]\), 
                    InterpretationBox[
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      SequenceForm[ 
                        red[ i]],
                      Editable->False]],
                  Subsuperscript[ 
                    OverDot[ u, 2], 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]], 
                    SequenceForm[ 
                      red[ i]]],
                  Editable->False],
                "TraditionalForm"]}], "-", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["X", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ X, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"], "\[InvisibleSpace]"}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\n\t\t\n(3) the Hooke's laws\t\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"], "\[InvisibleSpace]", "\<\" = \"\>", 
          "\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ l], 
                      red[ m]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ l], 
                    red[ m]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ m], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[DoubleStruckCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["l",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False], 
                      StyleForm[ 
                        red[ l], ShowContents -> False], 
                      StyleForm[ 
                        red[ m], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["l",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j], 
                      red[ l], 
                      red[ m]],
                    Editable->False]],
                Subsuperscript[ \[DoubleStruckCapitalE], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False], 
                    StyleForm[ 
                      red[ l], ShowContents -> False], 
                    StyleForm[ 
                      red[ m], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j], 
                    red[ l], 
                    red[ m]]],
                Editable->False],
              "TraditionalForm"]}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\n\n\tand\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ p]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ p], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ p]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ p], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            FractionBox[
              RowBox[{"\[CapitalEpsilon]", " ", 
                RowBox[{"(", 
                  RowBox[{
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["\[ScriptCapitalE]", 
                          InterpretationBox[
                            RowBox[{
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)], 
                              "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False], 
                              red[ p]],
                            Editable->False], 
                          InterpretationBox[
                            RowBox[{
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"], "\[InvisibleSpace]", 
                              TagBox[
                                StyleBox[
                                  FormBox[
                                    TagBox[
                                      StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"],
                                  ShowContents->False],
                                (StyleForm[ #, ShowContents -> False]&)]}],
                            SequenceForm[ 
                              red[ i], 
                              StyleForm[ 
                                red[ p], ShowContents -> False]],
                            Editable->False]],
                        Subsuperscript[ \[ScriptCapitalE], 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            red[ p]], 
                          SequenceForm[ 
                            red[ i], 
                            StyleForm[ 
                              red[ p], ShowContents -> False]]],
                        Editable->False],
                      "TraditionalForm"], "+", 
                    FractionBox[
                      RowBox[{"\[Nu]", " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["g", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ i], ShowContents -> False], 
                                  red[ p]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["p",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ i], 
                                  StyleForm[ 
                                    red[ p], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ g, 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ i], ShowContents -> False], 
                                red[ p]], 
                              SequenceForm[ 
                                red[ i], 
                                StyleForm[ 
                                  red[ p], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"], " ", 
                        FormBox[
                          InterpretationBox[
                            SubsuperscriptBox["\[ScriptCapitalE]", 
                              InterpretationBox[
                                RowBox[{
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (StyleForm[ #, ShowContents -> False]&)], 
                                  "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False], 
                                  red[ m]],
                                Editable->False], 
                              InterpretationBox[
                                RowBox[{
                                  FormBox[
                                    TagBox[
                                      StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"], "\[InvisibleSpace]", 
                                  TagBox[
                                    StyleBox[
                                      FormBox[
                                        TagBox[
                                        StyleBox["m",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"],
                                      ShowContents->False],
                                    (
                                    StyleForm[ #, ShowContents -> False]&)]}],
                                
                                SequenceForm[ 
                                  red[ m], 
                                  StyleForm[ 
                                    red[ m], ShowContents -> False]],
                                Editable->False]],
                            Subsuperscript[ \[ScriptCapitalE], 
                              SequenceForm[ 
                                StyleForm[ 
                                  red[ m], ShowContents -> False], 
                                red[ m]], 
                              SequenceForm[ 
                                red[ m], 
                                StyleForm[ 
                                  red[ m], ShowContents -> False]]],
                            Editable->False],
                          "TraditionalForm"]}], \(1 - 2\ \[Nu]\)]}], 
                  ")"}]}], \(\[Nu] + 1\)]}]}], TraditionalForm]],
    FontSize->16],
  StyleBox["\tor\t",
    FontSize->16],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[Sigma]", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["p",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ p]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ p], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[Sigma], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ p]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ p], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            RowBox[{
              RowBox[{"2", " ", "\[Mu]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ p]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ p], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ p]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ p], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], "+", 
              RowBox[{"\[Lambda]", " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["g", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["p",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          red[ p]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["p",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            red[ p], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ g, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        red[ p]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          red[ p], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["\[ScriptCapitalE]", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ m], ShowContents -> False], 
                          red[ m]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["m",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ m], 
                          StyleForm[ 
                            red[ m], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ \[ScriptCapitalE], 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ m], ShowContents -> False], 
                        red[ m]], 
                      SequenceForm[ 
                        red[ m], 
                        StyleForm[ 
                          red[ m], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"], "\[InvisibleSpace]"}]}]}]}], 
        TraditionalForm]],
    FontSize->16],
  "\n\t\nThey form 6+3+6 = 15 component equations, which contain 15 unknowns \
(6 ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]],
    FontSize->16],
  ", 6 ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["\[Sigma]", 
              InterpretationBox[
                RowBox[{
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)], 
                  "\[InvisibleSpace]", 
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)]}],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                RowBox[{
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"], "\[InvisibleSpace]", 
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"]}],
                SequenceForm[ 
                  red[ i], 
                  red[ j]],
                Editable->False]],
            Subsuperscript[ \[Sigma], 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                StyleForm[ 
                  red[ j], ShowContents -> False]], 
              SequenceForm[ 
                red[ i], 
                red[ j]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]],
    FontSize->16],
  ", and 3 ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["u", 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ") . "
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.833326]],

Cell[TextData[{
  "We recall first here",
  StyleBox[" the Hooke's laws",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " (equations (4.3) and (4.11)):"
}], "Text"],

Cell[BoxData[
    \(\[Sigma]\[Section]uu[i_, j_] := 
      Tensor[\[ScriptCapitalE], {Void, Void}, {l, 
            m}]\ Tensor[\[DoubleStruckCapitalE], {i, j, l, m}, {Void, Void, 
            Void, Void}]\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(\[Sigma]\[Section]\[Section]ud[i_, 
        j_] := \((\[CapitalEpsilon]*\((Tensor[\[ScriptCapitalE], {i, 
                    Void}, {Void, 
                    j}] + \((\[Nu]*Tensor[g, {i, Void}, {Void, j}]*
                      Tensor[\[ScriptCapitalE], {m, Void}, {Void, 
                          m}])\)/\((1 - 
                      2*\[Nu])\))\))\)/\((1 + \[Nu])\)\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[TextData[{
  StyleBox["If the material is anisotropic",
    FontColor->RGBColor[0, 0, 1]],
  ", we have from (2) and (3) in the cell grey box,"
}], "Text"],

Cell[BoxData[
    \(CovariantD[\((\[Sigma]\[Section]uu[i, j] // 
              ToFlavor[red])\) /. \[ScriptCapitalE]dd[red@i_, 
              red@j_] -> \[ScriptCapitalE]\[Section]dd[red@i, red@j], 
        red@j] \[Equal] totalforce\)], "Input"],

Cell[TextData[{
  StyleBox["If the material is anisotropic but homogeneous",
    FontColor->RGBColor[0, 0, 1]],
  ", the covariant derivative of the elastic modulus vanishes,"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]% /. 
        CovariantD[\[DoubleStruckCapitalE]uuuu[i_, j_, k_, l_], m_] -> 
          0\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  StyleBox["If the material is isotropic",
    FontColor->RGBColor[0, 0, 1]],
  ", we have (we first calculate ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"], "\[InvisibleSpace]"}], TraditionalForm]],
    FontSize->16],
  " as a function of the displacements),"
}], "Text"],

Cell[BoxData[
    \(\(\((\(\(\[Sigma]\[Section]\[Section]ud[i, p] guu[p, j] // 
                  ToFlavor[red]\) // Expand\) // 
              MetricSimplify[g])\) /. {\[ScriptCapitalE]uu[red@i_, 
                red@j_] -> \[ScriptCapitalE]\[Section]dd[red@p, red@q] 
                guu[red@p, red@i] guu[red@q, red@j], \[ScriptCapitalE]ud[
                red@i_, 
                red@i_] -> \[ScriptCapitalE]\[Section]dd[red@p, red@i] 
                guu[red@p, red@i]} // Expand\) // 
      MetricSimplify[g]\)], "Input"],

Cell[BoxData[
    \(\[Sigma]uu[red@i, red@j] == % /. 
        Tensor[u, {Void, Cov@\(red@p\)}, {red@p, Void}] -> 
          CovariantD[uu[red@p], red@p] // FullSimplify\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((\(\(\(\(CovariantD[%[\([2]\)], 
                      red@j] // CovariantDSimplify[\[DoubleStruckE], g]\) // 
                  MetricSimplify[g]\) // IndexChange[{{p, j}}]\) // 
              SymmetricStandardOrder[u, {2, 3}]\) // Simplify)\) \[Equal] 
        totalforce]\)], "Input"],

Cell["\<\
This fundamental equation can also be expressed using Lame moduli (equation \
(4.7)),\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(LameRule := {\[CapitalEpsilon] \[Rule] \(\[Mu]\ \((3\ \
\[Lambda] + 2\ \[Mu])\)\)\/\(\[Lambda] + \[Mu]\), \[Nu] \[Rule] \
\[Lambda]\/\(2\ \((\[Lambda] + \[Mu])\)\)}\)\)\)], "Input",
  Background->GrayLevel[0.900008]],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]\((kin = %%[\([2]\)] /. LameRule // 
            Simplify)\)\[IndentingNewLine]]\)], "Input"],

Cell["Taking the divergence of the above equation,", "Text"],

Cell[BoxData[{
    \(\(\((\(kin[\([1]\)]\ \[DoubleStruckE]d[red@i] // Expand\) // 
            TDiv[\[DoubleStruckE], g, 
              red@i])\) \[Equal] \((\(kin[\([2]\)]\ \[DoubleStruckE]d[red@i] // 
              Expand\) // TDiv[\[DoubleStruckE], g, red@i])\);\)\), "\n", 
    \(divkin = \((\(\((%[\([1, 1]\)] // 
                    IndexChange[{{i, j}, {j, i}}])\) + %[\([1, {2, 3, 4}]\)] // 
              SymmetricStandardOrder[u, {2, 4}]\) // 
            Simplify)\) \[Equal] %[\([2]\)]\)}], "Input"],

Cell["\<\
We can then introduce the Laplace operator and write using the preceding \
identification,\
\>", "Text"],

Cell[BoxData[
    RowBox[{\((\(TLaplacian[\[DoubleStruckE], g, red@i, red@h]\)[
            uud[red@j, Cov[red@j]]] // SymmetricStandardOrder[u, {2, 4}])\), 
      "->", \(\[CapitalDelta][uud[red@i, Cov[red@i]]]\), 
      "                        ", 
      RowBox[{"(*", " ", 
        RowBox[{
        "we", " ", "have", " ", "changed", " ", "the", " ", "index", " ", 
          StyleBox["j",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["  ",
            FontColor->RGBColor[1, 0, 0]], "into", 
          StyleBox[" ",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["i",
            FontSlant->"Italic",
            FontColor->RGBColor[1, 0, 0]]}], 
        StyleBox["  ",
          FontColor->RGBColor[1, 0, 0]], "*)"}]}]], "Input"],

Cell["\<\
so that the preceding equation is simply in absence of external force,\
\>", "Text"],

Cell[BoxData[{
    \(\((divkin /. 
        Xud[red@i, Cov[red@i]] \[Rule] 0)\)\), "\[IndentingNewLine]", 
    \(ResultFrame[%[\([1]\)]/\((\[Lambda] + 
                2\ \[Mu])\) == %[\([2]\)]/\((\[Lambda] + 2\ \[Mu])\) \[Equal] 
          c^2\ %[\([2]\)]/\[Rho] /. %%]\)}], "Input"],

Cell["\<\
where  c has the dimension of a velocity.
A second important equation is obtained when taking the curl of equation \
(6.8) :\
\>", "Text"],

Cell[BoxData[
    \(\(\@g[
                red]\) \((\((\(kin[\([1]\)]\ \[DoubleStruckE]d[red@i] // 
                      Expand\) // 
                    TCurl[\[DoubleStruckE], g, red /@ {k, l, m}, 
                      e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[g, red] // 
              Simplify)\) \[Equal] \(\@g[
                red]\) \((\(kin[\([2]\)]\ \[DoubleStruckE]d[red@i] // 
                Expand\) // 
              TCurl[\[DoubleStruckE], g, red /@ {k, l, m}, 
                e])\) /. \(LeviCivitaRule[e, \[Epsilon]]\)[g, red]\)], "Input"],

Cell[TextData[{
  "The second term in the parenthesis gives zero (antisymmetric combination \
of a symmetric tensor with respect to {",
  StyleBox["k",
    FontColor->RGBColor[1, 0, 0]],
  ", ",
  StyleBox["l",
    FontColor->RGBColor[1, 0, 0]],
  "})"
}], "Text"],

Cell[BoxData[
    \(curlkin = 
      Factor[Coefficient[\((%[\([1]\)] /. %[\([1, 1, 2]\)] \[Rule] 
                    0)\) - %[\([2]\)], \[DoubleStruckE]d[red@m]]] \[Equal] 
        0\)], "Input"],

Cell["and introducing the laplacian", "Text"],

Cell[BoxData[
    \(\(\((\(TLaplacian[\[DoubleStruckE], g, red@j, red@i]\)[
            udd[red@l, Cov[red@k]]] // 
          SymmetricStandardOrder[u, {2, 4}])\)\(->\)\(\[CapitalDelta][
        udd[red@l, Cov[red@k]]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\ \((res = %%[\([1]\)] /. %)\) \[Equal] 0]\)], "Input"],

Cell["\<\
An up-down swap of the indices gives an equivalent expression : \
\>", "Text"],

Cell[BoxData[
    \(\(\((UpDownSwap[
                red@k] /@ \(UpDownSwap[
                  red@l] /@ \((curlkin[\([1]\)] // 
                    Expand)\)\))\) /. \[Epsilon]ddu[i_, j_, 
              k_] :> \[Epsilon]ddd[i, j, k] // 
        SymmetricStandardOrder[u, {2, 4}]\) // Factor\)], "Input"],

Cell[BoxData[
    \(\(\((\(TLaplacian[\[DoubleStruckE], g, red@j, red@i]\)[
            uuu[red@l, Cov[red@k]]] // 
          SymmetricStandardOrder[u, {2, 4}])\)\(->\)\(\[CapitalDelta][
        uuu[red@l, Cov[red@k]]]\)\(\ \)\)\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\ \((res = %% /. %)\) \[Equal] 0]\)], "Input"],

Cell[TextData[{
  "When there is ",
  StyleBox["no force",
    FontVariations->{"Underline"->True}],
  " in equ. (6.10) "
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\((\(\(-res\)/\[Mu] /. 
                res[\([2, 1]\)] \[Rule] 0\) /. \[Rho] \[Rule] \[Mu]\ c\&~\^2 // 
            Simplify)\) \[Equal] 0]\)], "Input"],

Cell["with  ", "Text"],

Cell[BoxData[
    \(\(c\&~ == \@\(\[Rho]\/\[Mu]\);\)\)], "Input"],

Cell[TextData[{
  StyleBox["1)",
    FontWeight->"Bold"],
  " Any solution of equ. (6.8) without external force, must satisfy equ. \
(6.9) and (6.10). \n\tEquation (6.12) has a trivial solution ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["u", 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["l",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["k",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ k]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ l], 
              Cov[ 
                red[ k]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["l",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["k",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ k]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ l], ShowContents -> False], 
              StyleForm[ 
                Cov[ 
                  red[ k]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[Epsilon]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["k",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["l",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ k], ShowContents -> False], 
              StyleForm[ 
                red[ l], ShowContents -> False], 
              StyleForm[ 
                red[ m], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["k",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["l",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ k], 
              red[ l], 
              red[ m]],
            Editable->False]], TraditionalForm]]],
  "= 0, or  ",
  StyleBox["curl [\[DoubleStruckU]]",
    FontWeight->"Bold"],
  " = 0.\nA vector field which satisfies this condition derives from a \
potential ",
  StyleBox["\[Phi]",
    FontWeight->"Bold"],
  ", the displacement potential."
}], "Text"],

Cell[BoxData[{
    \(\(T\[Phi] = Tensor[\[Phi], {}, {}];\)\), "\[IndentingNewLine]", 
    \(\[DoubleStruckU] := \(TGrad[\[DoubleStruckE], red@i]\)[
        T\[Phi]]\), "\[IndentingNewLine]", 
    \(uu[red@j_] := \[DoubleStruckU] . \[DoubleStruckE]u[red@j] // 
        EvaluateDotProducts[\[DoubleStruckE], g]\)}], "Input"],

Cell[BoxData[
    \(uu[red@j]\)], "Input"],

Cell[BoxData[
    \(uuu[red@j, 
        Cov[red@k]] == \[IndentingNewLine]\((res = \((uuu[red@j, Cov[red@k]] // 
                  TensorNesting[u])\) /. 
              Tensor[u, {red[j]}, {Void}] \[RuleDelayed] uu[red@j] // 
            TensorUnNesting[\[Phi]])\) \[Equal] \ \((res // 
          IndexChange[{{k, j}, {j, k}}])\) == 
      uuu[red@k, Cov[red@j]]\)], "Input"],

Cell[TextData[{
  "If we introduce this result in (6.8) when ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["X", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ i]],
                Editable->False]],
            Subsuperscript[ X, 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]], 
              SequenceForm[ 
                red[ i]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  "= 0,"
}], "Text"],

Cell[BoxData[{
    \(\(\(\((kin /. Xu[red@i] \[Rule] 0 // SymmetricStandardOrder[u, {2}])\) /. 
            uuud[red@i, Cov[red@j], Cov[red@j]] -> \[CapitalDelta][
                Tensor[u, {red@i}, {Void}]]\) /. \[Rho] -> \((\[Lambda] + 
                  2\ \[Mu])\) c\^2 // Simplify;\)\), "\[IndentingNewLine]", 
    \(ResultFrame[%[\([1]\)]/\((\[Lambda] + 
                2\ \[Mu])\) - %[\([2]\)]/\((\[Lambda] + 2\ \[Mu])\) \[Equal] 
        0]\)}], "Input"],

Cell[TextData[{
  StyleBox["2)",
    FontWeight->"Bold"],
  " On the other hand, a solution of equ. (6.9) has a trivial solution ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["u", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ i]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              Cov[ 
                red[ i]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ i]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              StyleForm[ 
                Cov[ 
                  red[ i]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "= 0, or  ",
  StyleBox["div [\[DoubleStruckU]]",
    FontWeight->"Bold"],
  " = 0. Carried into (6.8) gives"
}], "Text"],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{\(\(\(kin /. Xu[red@i] \[Rule] 0\) /. 
              uuud[red@j, Cov[red@i], Cov[red@j]] \[Rule] 0\) /. 
            uuud[red@i, Cov[red@j], Cov[red@j]] -> \[CapitalDelta][
                Tensor[u, {red@i}, {Void}]]\), "/.", 
          RowBox[{"\[Rho]", "->", " ", 
            RowBox[{"\[Mu]", " ", 
              SuperscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["c",
                      "Text"], "~"],
                  "Text"], "2"]}]}]}], "//", "Simplify"}], 
      ";"}], "\[IndentingNewLine]", \(ResultFrame[\((%[\([1]\)]/\[Mu])\) - %[\
\([2]\)]/\[Mu] \[Equal] 0]\)}], "Input"],

Cell[TextData[{
  "The general solutions of both equations (6.13) and (6.14) is in cartesian \
coordinates (",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            RowBox[{
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["u", 
                    InterpretationBox[
                      TagBox[
                        StyleBox["i",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ i, ShowContents -> False]],
                      Editable->False], 
                    InterpretationBox["i",
                      SequenceForm[ i],
                      Editable->False]],
                  Subsuperscript[ u, 
                    SequenceForm[ 
                      StyleForm[ i, ShowContents -> False]], 
                    SequenceForm[ i]],
                  Editable->False],
                "TraditionalForm"], "==", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["u", 
                    InterpretationBox["i",
                      SequenceForm[ i],
                      Editable->False], 
                    InterpretationBox[
                      TagBox[
                        StyleBox["i",
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)],
                      SequenceForm[ 
                        StyleForm[ i, ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ u, 
                    SequenceForm[ i], 
                    SequenceForm[ 
                      StyleForm[ i, ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  "),"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\(ud[i] \[Equal] \ Ad[i]\ \(fd[i]\)[x - c\ t]\)\)\)], "Input"],

Cell[TextData[{
  "with three arbitrary functions ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["f", 
          InterpretationBox["i",
            SequenceForm[ i],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox["i",
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ i, ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  ". This represents an elastic wave propagating with the velocity ",
  StyleBox["c",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " (or ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\&~\)\)]],
  "). The solutions with ",
  StyleBox["curl [\[DoubleStruckU]]",
    FontWeight->"Bold"],
  " = 0 are dilatational waves, while those with   ",
  StyleBox["div [\[DoubleStruckU]]",
    FontWeight->"Bold"],
  " = 0 are shear waves."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Flow of Viscous Fluids", "Section",
  CellTags->"Flow of Viscous Fluid"],

Cell[TextData[{
  "We define first the operation ",
  StyleBox["Total3Dt[labs, i][T, t]",
    FontWeight->"Bold"],
  " which is the sum of the partial derivative of a tensor ",
  StyleBox["T",
    FontWeight->"Bold"],
  " with respect to time ",
  StyleBox["t",
    FontWeight->"Bold"],
  ", and of the spatial coordinates in the parameter defined by the labels ",
  StyleBox["labs",
    FontWeight->"Bold"],
  " (see the equation for ",
  StyleBox["p",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " and ",
  StyleBox["\[DoubleStruckA]",
    FontWeight->"Bold"],
  " below)."
}], "Text"],

Cell[BoxData[
    \(\(Total3Dt[labs_, i_]\)[T_, 
        t_] := \(PartialD[labs]\)[T, 
          t] + \((TotalD[T, t] // ExpandTotalD[labs, i])\)\)], "Input",
  Background->RGBColor[0, 1, 1]],

Cell[TextData[{
  "We adopt here the Eulerian formulation : coordinate system tied to the \
fluid, so that a particle of the fluid has a fixed position ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["x", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ x, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]], "Output"],
  ". In the lab frame, this position is ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["y", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ y, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " and depends generally on time. Its velocity ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["v", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ v, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " is given by,"
}], "Text"],

Cell[BoxData[
    RowBox[{\(vu[red@i]\), "==", 
      FormBox[\(TotalD[yu[red@i], t]\),
        "TraditionalForm"]}]], "Input"],

Cell["and any field quantity p is ", "Text"],

Cell[BoxData[{
    \(\(\(Total3Dt[{y, _, _, _}, red@i]\)[Tensor[p], 
        t];\)\), "\[IndentingNewLine]", 
    \(% // PartialDToDif\)}], "Input"],

Cell[TextData[{
  StyleBox["Note",
    FontColor->RGBColor[0, 0, 1]],
  " : we will use two kind of notations for scalar tensors, depending on the \
context. They are of course identical. ",
  StyleBox["Tensor[p,{},{}]",
    FontWeight->"Bold"],
  " is used when we want that its Covariant derivatives conserves a covariant \
notation (index Cov[]), while ",
  StyleBox["Tensor[p]",
    FontWeight->"Bold"],
  " is used when we want that its Covariant derivatives be written as a \
partial derivative (index Dif[])."
}], "Text"],

Cell["The acceleration is,", "Text"],

Cell[BoxData[{
    \(\(Clear[\[DoubleStruckV]];\)\), "\[IndentingNewLine]", 
    \(\(\(Total3Dt[{y, _, _, _}, red@j]\)[Tensor[\[DoubleStruckV]], 
        t];\)\), "\n", 
    \(\[DoubleStruckA] == % /. TotalD[yu[i_], t] -> vu[i] // 
      PartialDToDif\)}], "Input"],

Cell["with the components,", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]au[red@i] \[Equal] 
        PartialD[vu[red@i], t] + 
          vu[red@j] CovariantD[vu[red@i], red@j]]\)], "Input"],

Cell["where we have used the fact that,", "Text"],

Cell[BoxData[{
    \(PartialD[Tensor[\[DoubleStruckV]], red@j]\), "\[IndentingNewLine]", 
    \("\<==\>"\), "\[IndentingNewLine]", 
    \(\((\[DoubleStruckV] := vu[red@i] \[DoubleStruckE]d[red@i]; 
          PartialD[\[DoubleStruckV], red@j] // 
            ChristoffeluSymbol[\[DoubleStruckE], \[CapitalGamma], k])\) == 
        CovariantD[\[DoubleStruckV], red@j] // 
      CovariantDSimplify[\[DoubleStruckE], g]\)}], "Input"],

Cell[TextData[{
  "Result (6.15)  contains two terms, ",
  Cell[BoxData[
      FormBox[
        InterpretationBox[
          SubsuperscriptBox["v", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                FormBox[
                  InterpretationBox[\(","\[InvisibleSpace]t\),
                    SequenceForm[ ",", t],
                    Editable->False],
                  "TraditionalForm"]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False], 
                Dif[ t]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      InterpretationBox[\(","\[InvisibleSpace]t\),
                        SequenceForm[ ",", t],
                        Editable->False],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                red[ i], 
                StyleForm[ 
                  Dif[ t], ShowContents -> False]],
              Editable->False]],
          Subsuperscript[ v, 
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              Dif[ t]], 
            SequenceForm[ 
              red[ i], 
              StyleForm[ 
                Dif[ t], ShowContents -> False]]],
          Editable->False], TraditionalForm]]],
  " represents the change of velocity when the flow is non stationary, while \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["v", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ v, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"], " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["v", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ";", 
                          red[ j]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    Cov[ 
                      red[ j]]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          InterpretationBox[
                            RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                              FormBox[
                                TagBox[
                                  StyleBox["j",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"]}],
                            SequenceForm[ ";", 
                              red[ j]],
                            Editable->False],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      Cov[ 
                        red[ j]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ v, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  Cov[ 
                    red[ j]]], 
                SequenceForm[ 
                  red[ i], 
                  StyleForm[ 
                    Cov[ 
                      red[ j]], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  " represents the change of velocity when the flow moves during dt to \
another point where the velocity is different."
}], "Text"],

Cell[CellGroupData[{

Cell["Dynamic equation of the fluid flow :", "Subsection"],

Cell[TextData[{
  "We use result (6.5) derived for solids, but now ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox[\(u\&\[DoubleDot]\), 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ i]],
                Editable->False]],
            Subsuperscript[ 
              OverDot[ u, 2], 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]], 
              SequenceForm[ 
                red[ i]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " is the acceleration ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["a", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]]],
  " of the particles of fluid"
}], "Text"],

Cell[BoxData[{
    \(\(\[Sigma]uud[red@j, red@i, 
          Cov[red@j]] \[Equal] \[Rho]\ Tensor[
              OverDot[u, 2], {red[i]}, {Void}] - 
          Xu[red@i];\)\ \  (*\ \ equ . \ 
        6.5\ \ *) \), "\[IndentingNewLine]", 
    \(% /. Tensor[OverDot[u, 2], {red[i]}, {Void}] \[Rule] 
        au[red@i]\), "\[IndentingNewLine]", 
    \(ResultFrame[\[IndentingNewLine]res616 = % /. 
          au[red@i] -> 
            PartialD[vu[red@i], t] + 
              vu[red@j] CovariantD[vu[red@i], red@j]\ ]\)}], "Input"],

Cell[TextData[{
  "On the other hand, time derivative of the kinematic relation (6.2) ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["\[ScriptCapitalE]", 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      red[ i], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ \[ScriptCapitalE], 
                  SequenceForm[ 
                    red[ i], 
                    red[ j]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"], "==", 
            RowBox[{\(1\/2\), " ", 
              RowBox[{"(", 
                RowBox[{
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["u", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ ";", 
                                  red[ j]],
                                Editable->False],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ i], 
                            Cov[ 
                              red[ j]]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  InterpretationBox[
                                    
                                    RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                      
                                      FormBox[
                                        TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                    SequenceForm[ ";", 
                                      red[ j]],
                                    Editable->False],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ j]], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ u, 
                        SequenceForm[ 
                          red[ i], 
                          Cov[ 
                            red[ j]]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          StyleForm[ 
                            Cov[ 
                              red[ j]], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"], "+", 
                  FormBox[
                    InterpretationBox[
                      SubsuperscriptBox["u", 
                        InterpretationBox[
                          RowBox[{
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"], "\[InvisibleSpace]", 
                            FormBox[
                              InterpretationBox[
                                RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                  FormBox[
                                    TagBox[
                                      StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                    "TraditionalForm"]}],
                                SequenceForm[ ";", 
                                  red[ i]],
                                Editable->False],
                              "TraditionalForm"]}],
                          SequenceForm[ 
                            red[ j], 
                            Cov[ 
                              red[ i]]],
                          Editable->False], 
                        InterpretationBox[
                          RowBox[{
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)], 
                            "\[InvisibleSpace]", 
                            TagBox[
                              StyleBox[
                                FormBox[
                                  InterpretationBox[
                                    RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                      
                                      FormBox[
                                        TagBox[
                                        StyleBox["i",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                        "TraditionalForm"]}],
                                    SequenceForm[ ";", 
                                      red[ i]],
                                    Editable->False],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)]}],
                          SequenceForm[ 
                            StyleForm[ 
                              red[ j], ShowContents -> False], 
                            StyleForm[ 
                              Cov[ 
                                red[ i]], ShowContents -> False]],
                          Editable->False]],
                      Subsuperscript[ u, 
                        SequenceForm[ 
                          red[ j], 
                          Cov[ 
                            red[ i]]], 
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False], 
                          StyleForm[ 
                            Cov[ 
                              red[ i]], ShowContents -> False]]],
                      Editable->False],
                    "TraditionalForm"]}], ")"}]}]}]}], TraditionalForm]]],
  " gives, "
}], "Text"],

Cell[BoxData[
    \(TotalD[\[ScriptCapitalE]dd[red@i, red@j], 
        t] == \(1\/2\) \((vdd[red@i, Cov[red@j]] + 
            vdd[red@j, Cov[red@i]])\)\)], "Input"],

Cell[TextData[{
  "It is interesting here to split this equation into ",
  StyleBox["a rate of dilatation ",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["e",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " and ",
  StyleBox["a rate of distortion",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  " . \nIn chapter 4, we have defined the parameters ",
  StyleBox["e",
    FontWeight->"Bold"],
  " and ",
  StyleBox["s",
    FontWeight->"Bold"],
  ", and we introduce,"
}], "Text"],

Cell[BoxData[
    \(\(HyddilDEF = \ {\[Sigma]ud[i_, i_] -> 
            3  s, \[ScriptCapitalE]ud[i_, i_] -> 3  e};\)\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(ResultFrame[\((TotalD[\[ScriptCapitalE]ud[red@m, red@m], t] /. 
            HyddilDEF)\) == 
        TotalD[\[ScriptCapitalE]ud[red@m, red@m], 
          t] == \(1\/2\) \((vud[red@m, Cov[red@m]] + 
              vud[red@m, Cov[red@m]])\)]\)], "Input"],

Cell["We define,", "Text"],

Cell[BoxData[
    \(Tensor[\ 
        e\[Section], {i_, Void}, {Void, j_}] := \[ScriptCapitalE]ud[i, j] - 
        e\ \ \[Delta]ud[i, j]\)], "Input",
  Background->RGBColor[1, 1, 0]],

Cell[BoxData[
    \(ResultFrame[
      distortion = \(\(TotalD[eud[red@i, red@j], t] == 
                TotalD[Tensor[\ e\[Section], {red@i, Void}, {Void, red@j}], 
                  t] /. \((\((TotalD[\[ScriptCapitalE]ud[red@m, red@m], t] /. 
                        HyddilDEF)\)/3)\) :> vud[red@m, Cov[red@m]]/3\) /. 
            TotalD[\ \[Delta]ud[i_, j_], t] \[Rule] 0\) /. 
          TotalD[\[ScriptCapitalE]ud[red@i, red@j], 
              t] -> \(1\/2\) \((vud[red@i, Cov[red@j]] + 
                  vdu[red@j, Cov[red@i]])\)]\)], "Input"],

Cell[TextData[{
  "If the fluid is incompressible, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          FractionBox[\(\[DifferentialD]e\), \(\[DifferentialD]t\),
            MultilineFunction->None],
          FontSize->18], TraditionalForm]]],
  StyleBox[" = 0",
    FontWeight->"Bold"],
  ", or ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["v", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["m",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ m]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ m], ShowContents -> False], 
              Cov[ 
                red[ m]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ m]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ m], 
              StyleForm[ 
                Cov[ 
                  red[ m]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  StyleBox["= 0",
    FontWeight->"Bold"],
  ", so that in this case equ. (6.18) becomes,"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[
      distortion[\([1]\)] \[Equal] \((distortion[\([2]\)] /. {vud[red@m, 
                  Cov[red@m]] \[Rule] 0})\) == 
        TotalD[\[ScriptCapitalE]ud[red@i, red@j], t]]\)], "Input"],

Cell[TextData[{
  "and there is no difference between ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["e", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["\[ScriptCapitalE]", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              red[ j]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "In a fluid at rest, or also in an inviscid fluid in motion, the pressure \
is isotropic, while in a viscous fluid in motion, the volume elements are \
undergoing a deformation and the compressible stresses have different \
magnitude in different directions. If we still want to define a pressure in \
the fluid, it can be the average of normal stress, counted positive when \
compressive. From ",
  "the rule ",
  "HyddilDEF",
  " which defines the hydrostatic stress ",
  StyleBox["s",
    FontColor->RGBColor[0, 0, 1]],
  " and the cubic dilation ",
  StyleBox["e",
    FontColor->RGBColor[0, 0, 1]],
  ", we have :"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"Tensor", "[", 
        RowBox[{"p", 
          StyleBox[",",
            FontSize->14], 
          StyleBox[\({}\),
            FontSize->16], 
          StyleBox[",",
            FontSize->16], 
          StyleBox[\({}\),
            FontSize->16]}], "]"}], "\[Equal]", \(-s\), 
      "\[Equal]", \(\(-\(1\/3\)\) \[Sigma]ud[red@m, red@m]\)}]], "Input"],

Cell[TextData[{
  "Introducing the above relation in ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["s", 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ s, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ j]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " given in chapter 4"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(sud[i_, j_]\), "=", 
        RowBox[{\(\[Sigma]ud[i, j] - s\ \ \[Delta]ud[i, j]\), "/.", 
          RowBox[{"s", "\[Rule]", 
            RowBox[{"-", 
              RowBox[{"Tensor", "[", 
                RowBox[{"p", 
                  StyleBox[",",
                    FontSize->14], 
                  StyleBox[\({}\),
                    FontSize->16], 
                  StyleBox[",",
                    FontSize->16], 
                  StyleBox[\({}\),
                    FontSize->16]}], "]"}]}]}]}]}], ";"}]], "Input"],

Cell["we have,", "Text"],

Cell[BoxData[
    \(Tensor[s, {red@i, Void}, {Void, red@j}] \[Equal] 
      sud[red@i, red@j]\)], "Input"],

Cell[TextData[{
  "Finally, when we introduce the constitutive equation (4.16)  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["s", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ j]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ s, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  red[ j]], 
                SequenceForm[ 
                  red[ i], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "==", 
          RowBox[{"2", " ", "\[Mu]", " ", 
            FormBox[
              InterpretationBox[
                SubsuperscriptBox[\(e\& . \), 
                  InterpretationBox[
                    RowBox[{
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)], 
                      "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["j",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      red[ j]],
                    Editable->False], 
                  InterpretationBox[
                    RowBox[{
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"], "\[InvisibleSpace]", 
                      TagBox[
                        StyleBox[
                          FormBox[
                            TagBox[
                              StyleBox["j",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"],
                          ShowContents->False],
                        (StyleForm[ #, ShowContents -> False]&)]}],
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ 
                  OverDot[ e, 1], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    red[ j]], 
                  SequenceForm[ 
                    red[ i], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[BoxData[
    \(sud[red@i, red@j] \[Equal] 
      2  \[Mu]\ distortion[\([1]\)] \[Equal] \((2  \[Mu]\ distortion[\([2]\)] \
/. vud[i_, Cov[i_]] \[Rule] 0)\)\)], "Input"],

Cell[BoxData[
    \(ResultFrame[\((\(Solve[\((\(\(\(%[\([1]\)] guu[red@j, red@k] // 
                          Expand\) // KroneckerAbsorb[\[Delta]]\) // 
                      MetricSimplify[g]\) // 
                    IndexChange[{k, 
                        j}])\) \[Equal] \((\(\(%[\([3]\)] guu[red@j, red@k] // 
                        Expand\) // MetricSimplify[g]\) // 
                    IndexChange[{k, j}])\), \[Sigma]uu[red@i, red@j]]\)[\([1, 
              1]\)])\) // Simplify]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Navier-Stokes Equation", "Subsection",
  CellTags->"Navier-Stokes"],

Cell[TextData[{
  "The elimination of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[Sigma]", 
                InterpretationBox[
                  RowBox[{
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)], 
                    "\[InvisibleSpace]", 
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)]}],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False], 
                    StyleForm[ 
                      red[ j], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  RowBox[{
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"], "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ 
                    red[ i], 
                    red[ j]],
                  Editable->False]],
              Subsuperscript[ \[Sigma], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False], 
                  StyleForm[ 
                    red[ j], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i], 
                  red[ j]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  " between equation (6.22) and equation (6.16) leads to the important \
Navier-Stokes equation for the kinetic evolution of a viscous fluid in \
presence of external forces :"
}], "Text"],

Cell[BoxData[{
    \(CovariantD[%[\([2, 1]\)], 
          red@j] \[Equal] \((\(CovariantD[%[\([2, 2]\)], red@j] // 
              CovariantDSimplify[_, g]\) // MetricSimplify[g])\) /. 
      vuud[red@j, Cov[red@i], Cov[red@j]] -> 0\), "\[IndentingNewLine]", 
    \(res616\), "\[IndentingNewLine]", 
    \(ResultFrame[\((res621 = \((%%[\([2]\)] - %[\([2]\)] // Expand)\) /. 
              PartialD[vu[red@i], t] \[Rule] 
                Tensor[v\& . , {red@i}, {Void}])\) \[Equal] 0]\)}], "Input"],

Cell[TextData[{
  "This equation, which contains four unknown, ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["v", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ i]],
                Editable->False]],
            Subsuperscript[ v, 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]], 
              SequenceForm[ 
                red[ i]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " and ",
  StyleBox["p",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ", together with the continuity equation ",
  StyleBox[" ",
    Background->RGBColor[0, 1, 0]],
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["v", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["m",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ m]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ m], ShowContents -> False], 
              Cov[ 
                red[ m]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ m]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ m], 
              StyleForm[ 
                Cov[ 
                  red[ m]], ShowContents -> False]],
            Editable->False]], TraditionalForm]],
    Background->RGBColor[0, 1, 0]],
  StyleBox[" = 0 ",
    Background->RGBColor[0, 1, 0]],
  ", determines the flow of the fluid."
}], "Text"],

Cell[CellGroupData[{

Cell["Streamlines", "Subsubsection"],

Cell[TextData[{
  "The streamlines of the velocity field ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["v", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ i]],
                Editable->False]],
            Subsuperscript[ v, 
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]], 
              SequenceForm[ 
                red[ i]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " are the lines everywhere tangent to the vector ",
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  ". The streamlines passing through all the points of a closed curve ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", form a tube called a stream tube.\nLet us choose a coordinate system ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["y", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False]], TraditionalForm]]],
  " such that,"
}], "Text"],

Cell[BoxData[{
    StyleBox[\(vu[red@2] := 0\),
      FontWeight->"Bold"], "\[IndentingNewLine]", 
    StyleBox[\(vu[red@3] := 0\),
      FontWeight->"Bold"], "\[IndentingNewLine]", 
    RowBox[{" ", 
      RowBox[{
        StyleBox["\[DoubleStruckV]",
          FontWeight->"Bold"], 
        StyleBox[":=",
          FontWeight->"Bold"], 
        RowBox[{
          StyleBox[\(vu[red@1]\),
            FontWeight->"Bold"], \(\[DoubleStruckE]d[
            red@1]\)}]}]}], "\[IndentingNewLine]", \(d\[DoubleStruckR] := 
      dru[red@2]\ \[DoubleStruckE]d[
          red@2]\), "\[IndentingNewLine]", \(d\[DoubleStruckS] := 
      dsu[red@3] \[DoubleStruckE]d[red@3]\)}], "Input"],

Cell[TextData[{
  "where the considered curve ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is the quadrilateral defined by {",
  StyleBox["d\[DoubleStruckR], d\[DoubleStruckS]",
    FontWeight->"Bold"],
  "}. Its area is,"
}], "Text"],

Cell[BoxData[
    RowBox[{"d\[DoubleStruckCapitalA]", "=", 
      RowBox[{
        StyleBox[\(d\[DoubleStruckR]\[Cross]
              d\[DoubleStruckS] // \(LinearBreakout[
                Cross]\)[\[DoubleStruckE]d[_], \[DoubleStruckE]u[_]]\),
          FontWeight->"Bold"], 
        "//", \(CrossProductExpansion[\[DoubleStruckE], e, 1]\)}]}]], "Input"],

Cell[TextData[{
  "and the flux of fluid through ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is,"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"d\[DoubleStruckCapitalA]", ".", 
        StyleBox["\[DoubleStruckV]",
          FontWeight->"Bold"]}], "//", 
      RowBox[{"EvaluateDotProducts", "[", 
        RowBox[{
          FormBox["\[DoubleStruckE]",
            "TraditionalForm"], ",", "g"}], "]"}]}]], "Input"],

Cell[TextData[{
  "If we consider another cross section ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["y", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["1",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ 1], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["1",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ 1]],
                    Editable->False]],
                Subsuperscript[ y, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ 1], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ 1]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " = const, of the stream tube, this cross section is again ",
  StyleBox["d\[DoubleStruckCapitalA]. ",
    FontWeight->"Bold"],
  " Along the steamlines, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["dr", 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["2",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ 2], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["2",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ 2]],
            Editable->False]], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        FormBox[
          InterpretationBox[
            SubsuperscriptBox["ds", 
              InterpretationBox[
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["3",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)],
                SequenceForm[ 
                  StyleForm[ 
                    red[ 3], ShowContents -> False]],
                Editable->False], 
              InterpretationBox[
                FormBox[
                  TagBox[
                    StyleBox["3",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                SequenceForm[ 
                  red[ 3]],
                Editable->False]],
            Subsuperscript[ ds, 
              SequenceForm[ 
                StyleForm[ 
                  red[ 3], ShowContents -> False]], 
              SequenceForm[ 
                red[ 3]]],
            Editable->False],
          "TraditionalForm"], TraditionalForm]]],
  " do not vary, and"
}], "Text"],

Cell[BoxData[
    \(\((CovariantD[%, red@1] /. {CovariantD[dru[red@2], red@1] \[Rule] 0, 
              CovariantD[dsu[red@3], red@1] \[Rule] 0} // 
          LeviCivitaSimplify[e])\) \[Equal] 0\)], "Input"],

Cell[TextData[{
  "Due to the continuity equation ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["v", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["m",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ m]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ m], ShowContents -> False], 
              Cov[ 
                red[ m]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ m]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ m], 
              StyleForm[ 
                Cov[ 
                  red[ m]], ShowContents -> False]],
            Editable->False]], TraditionalForm]],
    Background->None],
  StyleBox[" = 0",
    Background->None],
  ", this is zero. ",
  StyleBox["The same amount of fluid passes through all the cross sections of \
a stream tube",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ". It is interesting to notice that this result valid in the obvious case \
of an incompressible fluid, needs only the condition ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["v", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["m",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["m",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ m]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ m], ShowContents -> False], 
              Cov[ 
                red[ m]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["m",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["m",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ m]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ m], 
              StyleForm[ 
                Cov[ 
                  red[ m]], ShowContents -> False]],
            Editable->False]], TraditionalForm]],
    Background->None],
  StyleBox[" = div ",
    Background->None],
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  StyleBox[" = 0, to be valid. We will see later a case of application which \
is not obvious. ",
    Background->None],
  "\n\tIf the fluid flow is stationary, ",
  Cell[BoxData[
      FormBox[
        InterpretationBox[
          SubsuperscriptBox[\(v\& . \), 
            InterpretationBox[
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)],
              SequenceForm[ 
                StyleForm[ 
                  red[ i], ShowContents -> False]],
              Editable->False], 
            InterpretationBox[
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"],
              SequenceForm[ 
                red[ i]],
              Editable->False]],
          Subsuperscript[ 
            OverDot[ v, 1], 
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]], 
            SequenceForm[ 
              red[ i]]],
          Editable->False], TraditionalForm]]],
  "= 0, the streamlines are the paths followed by fluid particles during \
their motion in the flow field. If the flow is not stationary, the shape of \
the streamlines changes with time. The pathlines ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["x", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ j], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["j",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ j]],
                    Editable->False]],
                Subsuperscript[ x, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ j], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ j]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " = const, are then different fromthe streamlines."
}], "Text"],

Cell[TextData[{
  StyleBox["When the fluid is at rest",
    FontVariations->{"Underline"->True}],
  ", all the velocity terms cancel in the Navier-Stokes equation. This \
determines the hydrostatic pressure,"
}], "Text"],

Cell[BoxData[{
    RowBox[{\(\((res621 /. {Tensor[v, __] \[Rule] 0, 
              Tensor[v\& . , __] \[Rule] 0})\) \[Equal] 0\), 
      " "}], "\[IndentingNewLine]", 
    RowBox[{" ", 
      RowBox[{
        RowBox[{"\"\<\!\(\*
StyleBox[\"or\",\nFontColor->RGBColor[0, 0, 1]]\)  \>\"", 
          "    ", \(CovariantD[Tensor[p, {}, {}], red@i]\)}], "\[Equal]", 
        " ", \(Xd[red@i]\)}]}]}], "Input"],

Cell[TextData[{
  "Since ",
  StyleBox["p",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " is a scalar, ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["X", 
          InterpretationBox[
            FormBox[
              TagBox[
                StyleBox["i",
                  FontColor->RGBColor[1, 0, 0]],
                (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
              "TraditionalForm"],
            SequenceForm[ 
              red[ i]],
            Editable->False], 
          InterpretationBox[
            TagBox[
              StyleBox[
                FormBox[
                  TagBox[
                    StyleBox["i",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"],
                ShowContents->False],
              (StyleForm[ #, ShowContents -> False]&)],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "must be a gradient field, and its curl is zero, otherwise, the fluid \
cannot be in equilibrium."
}], "Text"],

Cell[BoxData[
    RowBox[{" ", 
      RowBox[{\(Xd[red@i] == 
          CovariantD[Tensor[\[CapitalOmega], {}, {}], red@i]\), 
        "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"\"\<curl \!\(\*
StyleBox[\"X\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\) \[Equal] 0  \
or  \>\"", 
            "  ", \(\(\(TCurl[\[DoubleStruckE], g, red /@ {i, j, k}, e]\)[
                Xd[red@i] \[DoubleStruckE]u[red@i]]\)[\([Range[1, 2]]\)]\)}], 
          "\[Equal]", "0"}]}]}]], "Input"],

Cell["\<\
When the viscosity is negligeable (like in water or air), the Navier-Stokes \
equation reads,\
\>", "Text"],

Cell[BoxData[{
    \(\(res621 /. \[Mu] \[Rule] 0;\)\), "\[IndentingNewLine]", 
    \(\(-%[\([2]\)]\) - %[\([4]\)] == %[\([3]\)] + %[\([1]\)]\)}], "Input"],

Cell[TextData[{
  "or from (6.15)   ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[InvisibleSpace]", 
          RowBox[{
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["a", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ a, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"], "==", 
            RowBox[{
              RowBox[{
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["v", 
                      InterpretationBox[
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["j",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ j], ShowContents -> False]],
                        Editable->False], 
                      InterpretationBox[
                        FormBox[
                          TagBox[
                            StyleBox["j",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        SequenceForm[ 
                          red[ j]],
                        Editable->False]],
                    Subsuperscript[ v, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ j], ShowContents -> False]], 
                      SequenceForm[ 
                        red[ j]]],
                    Editable->False],
                  "TraditionalForm"], " ", 
                FormBox[
                  InterpretationBox[
                    SubsuperscriptBox["v", 
                      InterpretationBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              FormBox[
                                TagBox[
                                  StyleBox["i",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1.0, 0.0, 0.0]]&)],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)], 
                          "\[InvisibleSpace]", 
                          FormBox[
                            InterpretationBox[
                              RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                FormBox[
                                  TagBox[
                                    StyleBox["j",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"]}],
                              SequenceForm[ ";", 
                                red[ j]],
                              Editable->False],
                            "TraditionalForm"]}],
                        SequenceForm[ 
                          StyleForm[ 
                            red[ i], ShowContents -> False], 
                          Cov[ 
                            red[ j]]],
                        Editable->False], 
                      InterpretationBox[
                        RowBox[{
                          FormBox[
                            TagBox[
                              StyleBox["i",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"], "\[InvisibleSpace]", 
                          TagBox[
                            StyleBox[
                              FormBox[
                                InterpretationBox[
                                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                                    FormBox[
                                      TagBox[
                                        StyleBox["j",
                                        FontColor->RGBColor[1, 0, 0]],
                                        (
                                        StyleForm[ #, FontColor -> RGBColor[ 
                                        1.0, 0.0, 0.0]]&)],
                                      "TraditionalForm"]}],
                                  SequenceForm[ ";", 
                                    red[ j]],
                                  Editable->False],
                                "TraditionalForm"],
                              ShowContents->False],
                            (StyleForm[ #, ShowContents -> False]&)]}],
                        SequenceForm[ 
                          red[ i], 
                          StyleForm[ 
                            Cov[ 
                              red[ j]], ShowContents -> False]],
                        Editable->False]],
                    Subsuperscript[ v, 
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        Cov[ 
                          red[ j]]], 
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          Cov[ 
                            red[ j]], ShowContents -> False]]],
                    Editable->False],
                  "TraditionalForm"]}], "+", 
              FormBox[
                InterpretationBox[
                  SubsuperscriptBox["v", 
                    InterpretationBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)], 
                        "\[InvisibleSpace]", 
                        FormBox[
                          InterpretationBox[\(","\[InvisibleSpace]t\),
                            SequenceForm[ ",", t],
                            Editable->False],
                          "TraditionalForm"]}],
                      SequenceForm[ 
                        StyleForm[ 
                          red[ i], ShowContents -> False], 
                        Dif[ t]],
                      Editable->False], 
                    InterpretationBox[
                      RowBox[{
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"], "\[InvisibleSpace]", 
                        TagBox[
                          StyleBox[
                            FormBox[
                              InterpretationBox[\(","\[InvisibleSpace]t\),
                                SequenceForm[ ",", t],
                                Editable->False],
                              "TraditionalForm"],
                            ShowContents->False],
                          (StyleForm[ #, ShowContents -> False]&)]}],
                      SequenceForm[ 
                        red[ i], 
                        StyleForm[ 
                          Dif[ t], ShowContents -> False]],
                      Editable->False]],
                  Subsuperscript[ v, 
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False], 
                      Dif[ t]], 
                    SequenceForm[ 
                      red[ i], 
                      StyleForm[ 
                        Dif[ t], ShowContents -> False]]],
                  Editable->False],
                "TraditionalForm"]}], " ", "==", " ", 
            StyleBox[
              FractionBox[
                InterpretationBox[
                  RowBox[{"\<\"\[DifferentialD]\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      InterpretationBox[
                        SubsuperscriptBox["v", 
                          InterpretationBox[
                            TagBox[
                              StyleBox[
                                FormBox[
                                  TagBox[
                                    StyleBox["i",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1.0, 0.0, 0.0]]&)],
                                  "TraditionalForm"],
                                ShowContents->False],
                              (StyleForm[ #, ShowContents -> False]&)],
                            SequenceForm[ 
                              StyleForm[ 
                                red[ i], ShowContents -> False]],
                            Editable->False], 
                          InterpretationBox[
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"],
                            SequenceForm[ 
                              red[ i]],
                            Editable->False]],
                        Subsuperscript[ v, 
                          SequenceForm[ 
                            StyleForm[ 
                              red[ i], ShowContents -> False]], 
                          SequenceForm[ 
                            red[ i]]],
                        Editable->False],
                      "TraditionalForm"]}],
                  SequenceForm[ "\[DifferentialD]", 
                    Tensor[ v, {
                      red[ i]}, {Void}]],
                  Editable->False], 
                InterpretationBox[
                  InterpretationBox[\("\[DifferentialD]"\[InvisibleSpace]t\),
                    SequenceForm[ "\[DifferentialD]", t],
                    Editable->False],
                  SequenceForm[ 
                    SequenceForm[ "\[DifferentialD]", t]],
                  Editable->False]],
              FontSize->16]}]}], TraditionalForm]]],
  ", and lowering the indices,"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[Rho]\ TotalD[vd[red@i], t] \[Equal] 
        Xd[red@i] - CovariantD[Tensor[p, {}, {}], red@i]]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Circulation integral of the velocity on a closed \
curve, vorticity", "Subsubtitle"]], "Outline1",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[{
    \("\<\[ContourIntegral] \[DoubleStruckV].d\[DoubleStruckR] ==\>"\), "\
\[IndentingNewLine]", 
    \("\<\[ContourIntegral]\>" 
      vd[red@i]\ \ \ Tensor[dy, {red[i]}, {Void}]\), "\n", 
    \(res = \*"\"\<\!\(\[DifferentialD]\/\[DifferentialD]t\)\>\"" % \[Equal] 
        TotalD[%, t]\)}], "Input"],

Cell[BoxData[
    RowBox[{\("\<\[ContourIntegral]\>" res[\([2, 2, 1]\)]\), "==", 
      RowBox[{"\"\<\[ContourIntegral]\>\"", \(vd[red@i]\), 
        RowBox[{"d", "[", " ", 
          FormBox[\(TotalD[Tensor[y, {red[j]}, {Void}], t]\),
            "TraditionalForm"], "]"}]}], 
      "==", \("\<\[ContourIntegral]\>" vd[red@i] d[\ vu[red@i]]\), 
      "==", \(1\/2\ {vd[red@i] vu[red@i]}\_C\), " ", "\[Equal]", " ", 
      "0"}]], "Input"],

Cell["\<\
Only the second term in the integration remains, so that we have using equ. \
(6.22)\
\>", "Text"],

Cell[BoxData[
    \(res[\([1]\)] == "\<\[ContourIntegral]\>" 
        res[\([2, 2, 
            2]\)] == \(1\/\[Rho]\) "\<\[ContourIntegral]\>" \((Xd[red@i] - 
            CovariantD[Tensor[p, {}, {}], red@i])\) 
        Tensor[dy, {red@
              i}, {Void}] == \(1\/\[Rho]\) "\<\[ContourIntegral]\>" \
\((CovariantD[Tensor[\[CapitalOmega], {}, {}], red@i] - 
            CovariantD[Tensor[p, {}, {}], 
              red@i])\) == \(1\/\[Rho]\) {Tensor[\[CapitalOmega], {}, {}] - \
Tensor[p, {}, {}]}\_C \[Equal] 0\)], "Input"],

Cell[TextData[{
  "Finally, we see that ",
  StyleBox["for an inviscid fluid moving in a conservative force field",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ","
}], "Text"],

Cell[BoxData[
    \(ResultFrame["\<\[ContourIntegral]\>" vd[red@i] 
          Tensor[dy, {red@i}, {Void}] \[Equal] const]\)], "Input"],

Cell[TextData[{
  "for any closed curve moving with the particles of fluid. In particular, \
this is true for an infinitesimal curve bounding an area ",
  StyleBox["d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  ". From Stokes theorem, (equ.5.8), we deduce that,"
}], "Text"],

Cell[BoxData[{
    StyleBox[\(\[DoubleStruckV] =. ; d\[DoubleStruckCapitalA] =. ;\),
      FontWeight->"Bold"], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        RowBox[{"curl", "[", 
          StyleBox["\[DoubleStruckV]",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontWeight->"Bold"]}], ".", 
        StyleBox["d\[DoubleStruckCapitalA]",
          FontWeight->"Bold"]}], 
      StyleBox[" ",
        FontWeight->"Bold"], 
      StyleBox["==",
        FontWeight->"Bold"], 
      StyleBox[" ",
        FontWeight->"Bold"], 
      StyleBox["const",
        FontWeight->"Bold"]}], "\[IndentingNewLine]", 
    RowBox[{"\"\<\!\(\*
StyleBox[\"or\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"introducing\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"the\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"vorticity\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\",\n\
FontColor->RGBColor[0, 0, 1]]\)\!\(\*
StyleBox[\"   \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[0, 0, \
1]]\)\>\"", "           "}], "\[IndentingNewLine]", 
    RowBox[{"ResultFrame", "[", 
      RowBox[{\("\<              \>" \[Omega]\), "==", 
        RowBox[{"curl", "[", 
          StyleBox["\[DoubleStruckV]",
            FontWeight->"Bold"], 
          StyleBox["]",
            FontWeight->"Bold"]}]}], 
      StyleBox["]",
        FontWeight->"Bold"]}], "\[IndentingNewLine]", 
    RowBox[{"ResultFrame", "[", 
      RowBox[{
        RowBox[{"\"\<and          \>\"", "   ", 
          RowBox[{"\[Omega]", ".", 
            StyleBox["d\[DoubleStruckCapitalA]",
              FontWeight->"Bold"]}]}], 
        StyleBox[" ",
          FontWeight->"Bold"], 
        StyleBox["==",
          FontWeight->"Bold"], 
        StyleBox[" ",
          FontWeight->"Bold"], 
        StyleBox["const",
          FontWeight->"Bold"]}], 
      StyleBox[" ",
        FontWeight->"Bold"], 
      StyleBox["]",
        FontWeight->"Bold"]}]}], "Input"],

Cell[TextData[{
  "Similarly to the velocity field and streamlines of the flow,  we can \
define the vorticity field and the vorticity lines or vortex filaments.\nThe \
product ",
  StyleBox["\[Omega].d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  " is the flux of vorticity through the cross section ",
  StyleBox["d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  " of a vortex tube passing through all the points of the perimeter ",
  StyleBox["C",
    FontSlant->"Italic"],
  " of ",
  StyleBox["d\[DoubleStruckCapitalA]",
    FontWeight->"Bold"],
  ". This flux is constant.\n\tUnsteady flows frequently start at rest; \
steady flows frequently approach from infinity with a uniform velocity toward \
an obstacle. In both case ",
  StyleBox["curl(\[DoubleStruckV])",
    FontWeight->"Bold"],
  " = 0, and from equ.(6.25) valid for any area, ",
  StyleBox["curl(\[DoubleStruckV])",
    FontWeight->"Bold"],
  " remains throughout zero : the flow field is a gradient field"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]vd[red@i] \[Equal] 
        CovariantD[Tensor[\[CapitalPhi], {}, {}], red@i] \[Equal] 
        CovariantD[Tensor[\[CapitalPhi]], red@i]]\)], "Input"],

Cell[TextData[{
  "This kind of velocity field is called a ",
  StyleBox["potential flow",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  ". Using the continuity equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubsuperscriptBox["v", 
            InterpretationBox[
              RowBox[{
                TagBox[
                  StyleBox[
                    FormBox[
                      TagBox[
                        StyleBox["m",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)], 
                "\[InvisibleSpace]", 
                FormBox[
                  InterpretationBox[
                    RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                      FormBox[
                        TagBox[
                          StyleBox["m",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"]}],
                    SequenceForm[ ";", 
                      red[ m]],
                    Editable->False],
                  "TraditionalForm"]}],
              SequenceForm[ 
                StyleForm[ 
                  red[ m], ShowContents -> False], 
                Cov[ 
                  red[ m]]],
              Editable->False], 
            InterpretationBox[
              RowBox[{
                FormBox[
                  TagBox[
                    StyleBox["m",
                      FontColor->RGBColor[1, 0, 0]],
                    (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                  "TraditionalForm"], "\[InvisibleSpace]", 
                TagBox[
                  StyleBox[
                    FormBox[
                      InterpretationBox[
                        RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                          FormBox[
                            TagBox[
                              StyleBox["m",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1.0, 0.0, 0.0]]&)],
                            "TraditionalForm"]}],
                        SequenceForm[ ";", 
                          red[ m]],
                        Editable->False],
                      "TraditionalForm"],
                    ShowContents->False],
                  (StyleForm[ #, ShowContents -> False]&)]}],
              SequenceForm[ 
                red[ m], 
                StyleForm[ 
                  Cov[ 
                    red[ m]], ShowContents -> False]],
              Editable->False]], " ", "=", " ", "0"}], TraditionalForm]],
    Background->RGBColor[0, 1, 0]],
  " leads to "
}], "Text"],

Cell[BoxData[
    \(\(TLaplacian[\[DoubleStruckE], g, red@i, red@j]\)[
        Tensor[\[CapitalPhi], {}, {}]] \[Equal] 0\)], "Input"],

Cell["Introducing (6.26) into (6.22) gives", "Text"],

Cell[BoxData[
    \(\((\((\(\((res621 /. \[Mu] \[Rule] 0 // TensorNesting[v])\) /. 
                vu[i_] \[Rule] Tensor[\[CapitalPhi], {Cov[i]}, {Void}]\) /. 
              Tensor[v\& . , {red@i}, {Void}] -> 
                Tensor[\[CapitalPhi]\& . , {Cov[red@i]}, {Void}])\) // 
          TensorUnNesting[\[CapitalPhi]])\) \[Equal] 0\)], "Input"],

Cell[BoxData[
    \(\((res1 = \(\(%[\([1]\)] gdd[red@i, red@k] // Expand\) // 
              MetricSimplify[g]\) // 
            SymmetricStandardOrder[\[CapitalPhi]])\) \[Equal] 0\)], "Input"],

Cell[BoxData[{
    \(res2 = \((\ 
        Tensor[\[CapitalPhi]\& . , {}, {}] + \(1\/2\) \[CapitalPhi]u[
              Cov[red@j]] \[CapitalPhi]d[
              Cov[red@j]])\)\), "\[IndentingNewLine]", 
    \(Xd[red@k] - \[Rho]\ CovariantD[res2, red@k]\), "\[IndentingNewLine]", 
    \(MapAt[UpDownSwap[red@j], %, {2, 3, 1, 2, 2}]\)}], "Input"],

Cell[TextData[{
  "This leads to an equation for the pressure ",
  StyleBox["p ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " \nNotice that the notation involving res2 is not standard ! Only \
graphically convenient. \nTo explicit the expression we have to apply the \
rule ",
  StyleBox["CovariantD[Tensor[res2,{},{}],red@k] ",
    FontWeight->"Bold"],
  "\[Rule]",
  StyleBox[" CovariantD[res2,red@k]",
    FontWeight->"Bold"],
  "  :"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[
      pd[Cov[red@k]] == 
        Xd[red@k] - \[Rho]\ CovariantD[Tensor[res2, {}, {}], 
              red@k]]\)], "Input"],

Cell[TextData[{
  "The boundary condition for (6.27) concerns the velocity component normal \
to the boundary ",
  StyleBox["S",
    FontSlant->"Italic"],
  " of the domain of the fluid flow. If ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["n", 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False], 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False]],
                Subsuperscript[ n, 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]], 
                  SequenceForm[ 
                    red[ i]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " is the unit normal to ",
  StyleBox["S",
    FontSlant->"Italic"],
  ", the normal component of ",
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  " is"
}], "Text"],

Cell[BoxData[
    \(vd[red@i] nu[red@i] \[Equal] \[CapitalOmega]d[Cov@\(red@i\)] 
        nu[red@i]\)], "Input"],

Cell[TextData[{
  "This is subject to an integrability condition by the divergence theorem, \
equ.(5.7)  so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["n", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False]],
              Subsuperscript[ n, 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i]]],
              Editable->False],
            "TraditionalForm"], " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["v", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ v, 
                SequenceForm[ 
                  red[ i]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  " must be chosen such that,"
}], "Text"],

Cell[BoxData[
    \(ResultFrame[\*"\"\<\!\(\[Integral]\_\(\(\\\ \)\(S\)\)\)\>\""\ vu[red@i] 
          dAd[red@i] \[Equal] 0]\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Seepage Flow", "Section",
  CellTags->"Seepage Flow"],

Cell[TextData[{
  "This section is concerned by the seepage flow through a porous medium. It \
is a randomly multiconnected medium whose channels are randomly obstructed. \
The quantity that measures how \"holed\" the medium is due to the presence of \
these channels is called the ",
  StyleBox["porosity",
    FontSlant->"Italic"],
  " of the medium. Another important quantity, analogous to the conductivity \
of a network of resistors, is the ",
  StyleBox["Darcy permeability",
    FontSlant->"Italic"],
  ": it decreases continuously as the porosity decreases, until a critical \
porosity reached when it vanishes. Close to this critical porosity, the \
regime is fractal (see ",
  StyleBox["Physics and Fractal Structures",
    FontSlant->"Italic"],
  ", Jean-Fran\[CCedilla]ois Gouyet, Springer-Verlag, Berlin, New York, and \
Masson, 1996), and the seepage flow is described by the model of ",
  StyleBox[" invasion percolation",
    FontSlant->"Italic"],
  ". All the present studies are supposed to take place far from the critacal \
region, so that the mean-field approaches remain valid.\nThe flow in the \
channels are mostly dominated by viscous friction, and its velocity is \
proportional to the pressure gradient.\nLet ",
  Cell[BoxData[
      FormBox[
        TagBox[
          StyleBox[
            FormBox[
              InterpretationBox[
                SubsuperscriptBox["X", 
                  InterpretationBox[
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"],
                    SequenceForm[ 
                      red[ i]],
                    Editable->False], 
                  InterpretationBox[
                    TagBox[
                      StyleBox[
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"],
                        ShowContents->False],
                      (StyleForm[ #, ShowContents -> False]&)],
                    SequenceForm[ 
                      StyleForm[ 
                        red[ i], ShowContents -> False]],
                    Editable->False]],
                Subsuperscript[ X, 
                  SequenceForm[ 
                    red[ i]], 
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]]],
                Editable->False],
              "TraditionalForm"],
            FontFamily->"Courier",
            FontSize->16],
          (StyleForm[ #, FontSize -> 16, FontFamily -> "Courier"]&)], 
        TraditionalForm]]],
  " be the force ",
  StyleBox["acting on a unit of the fluid volume",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  " the mean velocity (",
  StyleBox["filter velocity) ",
    FontSlant->"Italic"],
  "of the fluid flow with respect to an infinitesimal bulk cross section. To \
make the fluid move, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["X", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ X, 
                SequenceForm[ 
                  red[ i]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "-", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["p", 
                InterpretationBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ i]],
                      Editable->False],
                    "TraditionalForm"],
                  SequenceForm[ 
                    Cov[ 
                      red[ i]]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        InterpretationBox[
                          RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ ";", 
                            red[ i]],
                          Editable->False],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      Cov[ 
                        red[ i]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ p, 
                SequenceForm[ 
                  Cov[ 
                    red[ i]]], 
                SequenceForm[ 
                  StyleForm[ 
                    Cov[ 
                      red[ i]], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  " must be different from zero. If the pore geometry has no preferential \
direction, ",
  StyleBox["\[DoubleStruckV]",
    FontWeight->"Bold"],
  " follow the direction of the force field ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["X", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ X, 
                SequenceForm[ 
                  red[ i]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], "-", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["p", 
                InterpretationBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ i]],
                      Editable->False],
                    "TraditionalForm"],
                  SequenceForm[ 
                    Cov[ 
                      red[ i]]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        InterpretationBox[
                          RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                            FormBox[
                              TagBox[
                                StyleBox["i",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1.0, 0.0, 0.0]]&)],
                              "TraditionalForm"]}],
                          SequenceForm[ ";", 
                            red[ i]],
                          Editable->False],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      Cov[ 
                        red[ i]], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ p, 
                SequenceForm[ 
                  Cov[ 
                    red[ i]]], 
                SequenceForm[ 
                  StyleForm[ 
                    Cov[ 
                      red[ i]], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  ".",
  " "
}], "Text"],

Cell[CellGroupData[{

Cell["Darcy's law", "Subsection"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]vd[red@i] \[Equal] 
        k \((Xd[red@i] - pd[Cov@\(red@i\)])\) == 
        k \((Tensor[\[CapitalOmega] - 
                p, {Void}, {Cov@\(red@i\)}])\)\ ]\)], "Input"],

Cell["\<\
Some porous media are anisotropic (linear channels, layers,...) and the \
Darcy's law takes the more general expression\
\>", "Text"],

Cell[BoxData[
    \(ResultFrame[\[IndentingNewLine]vu[red@i] \[Equal] 
        kuu[red@i, red@j] \((Xd[red@j] - pd[Cov@\(red@j\)])\) == 
        kuu[red@i, 
            red@j] \((Tensor[\[CapitalOmega] - 
                p, {Void}, {Cov@\(red@j\)}])\)\ \ ]\)], "Input"],

Cell["and the velocity field satisfies the continuity equation,", "Text"],

Cell[BoxData[{
    RowBox[{
      StyleBox["\[DoubleStruckV]",
        FontWeight->"Bold"], 
      StyleBox[":=",
        FontWeight->"Bold"], \(vu[red@i] \[DoubleStruckE]d[
          red@i]\)}], "\[IndentingNewLine]", 
    RowBox[{"ResultFrame", "[", "\[IndentingNewLine]", 
      RowBox[{
        RowBox[{\(TDiv[\[DoubleStruckE], g, red@i]\), "[", 
          StyleBox["\[DoubleStruckV]",
            FontWeight->"Bold"], "]"}], "\[Equal]", "0"}], "  ", 
      "]"}]}], "Input"],

Cell["Combining this condition with equ.(6.30) gives,", "Text"],

Cell[BoxData[
    \(res = \(TDiv[\[DoubleStruckE], g, red@i]\)[
          kuu[red@h, 
              red@j] \((Xd[red@j] - pd[Cov@\(red@j\)])\) \[DoubleStruckE]d[
              red@h]] \[Equal] 0\)], "Input"],

Cell[TextData[{
  "But in an homogeneous medium, the Darcy coefficient do not vary in space \
and ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["k", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              FormBox[
                InterpretationBox[
                  RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                    FormBox[
                      TagBox[
                        StyleBox["i",
                          FontColor->RGBColor[1, 0, 0]],
                        (
                        StyleForm[ #, FontColor -> RGBColor[ 
                          1.0, 0.0, 0.0]]&)],
                      "TraditionalForm"]}],
                  SequenceForm[ ";", 
                    red[ i]],
                  Editable->False],
                "TraditionalForm"]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False], 
              Cov[ 
                red[ i]]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              TagBox[
                StyleBox[
                  FormBox[
                    InterpretationBox[
                      RowBox[{"\<\";\"\>", "\[InvisibleSpace]", 
                        FormBox[
                          TagBox[
                            StyleBox["i",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1.0, 0.0, 0.0]]&)],
                          "TraditionalForm"]}],
                      SequenceForm[ ";", 
                        red[ i]],
                      Editable->False],
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              red[ i], 
              red[ j], 
              StyleForm[ 
                Cov[ 
                  red[ i]], ShowContents -> False]],
            Editable->False]], TraditionalForm]]],
  "=0."
}], "Text"],

Cell[BoxData[
    \(\((\(-res[\([1, 2]\)]\) // Expand)\)[\([1]\)] == \((res[\([1, 2]\)] // 
            Expand)\)[\([2]\)]\)], "Input"],

Cell[TextData[{
  "and finally in the",
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["isotropic case",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ","
}], "Text"],

Cell[BoxData[{
    \(ResultFrame[
      rule = kuu[red@i_, red@j_] -> 
          k\ guu[red@i, red@j]]\), "\[IndentingNewLine]", 
    \(\(\((%% // IndexChange[{{i, k}, {j, i}}])\) /. rule // 
        MetricSimplify[g];\)\)}], "Input"],

Cell[TextData[{
  "This gives the ",
  StyleBox["Poisson equation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ","
}], "Text"],

Cell[BoxData[
    \(ResultFrame[Map[\((#/k)\) &, %]]\)], "Input"],

Cell[TextData[{
  "or in absence of local force, the",
  StyleBox[" Laplace equation",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  ","
}], "Text"],

Cell[BoxData[
    \(ResultFrame[%[\([2, 1]\)] \[Equal] 0]\)], "Input"],

Cell[TextData[{
  "Fl\[UDoubleDot]gge discusses here the fact that ",
  Cell[BoxData[
      FormBox[
        SubsuperscriptBox["k", 
          InterpretationBox[
            RowBox[{
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)], "\[InvisibleSpace]",
               
              TagBox[
                StyleBox[
                  FormBox[
                    TagBox[
                      StyleBox["j",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  ShowContents->False],
                (StyleForm[ #, ShowContents -> False]&)]}],
            SequenceForm[ 
              StyleForm[ 
                red[ i], ShowContents -> False], 
              StyleForm[ 
                red[ j], ShowContents -> False]],
            Editable->False], 
          InterpretationBox[
            RowBox[{
              FormBox[
                TagBox[
                  StyleBox["i",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"], "\[InvisibleSpace]", 
              FormBox[
                TagBox[
                  StyleBox["j",
                    FontColor->RGBColor[1, 0, 0]],
                  (StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                "TraditionalForm"]}],
            SequenceForm[ 
              red[ i], 
              red[ j]],
            Editable->False]], TraditionalForm]]],
  " is  always found symmetricon practicle examples, but emphasizes that \
there is a lack of convincing general proof.\nWe will admit the symmetry of \
",
  StyleBox["k",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[BoxData[
    \(ResultFrame[kuu[red@i, red@j] == kuu[red@j, red@i]]\)], "Input"],

Cell[CellGroupData[{

Cell["\<\
Action of the fluid moving in a porous medium, on the solid matrix.\
\>", "Subsubsection"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000FK40@0005P0000?00003@0007<1002X0000
00000000003f9`00BQ<00215CDH00040a6H108T1000600000000000000000@0000@00003000>0@00
b`0004H0002PYP00TZH004M4BD<1002000<00:1=7?P00000NZH000402@000ceC00070>Xj000000D0
000;0_ooool5000030:=02<1100000810@0300007P080000nP8000400@000002100002d100070000
o0800?ooo`0000@0000]0@4070000?/200000000001N0@000000004P000000000000000000000000
000000000000000000040000;@4200P0003j0P000@01000000840000;@4300L0003l0P00oooo0000
100002d1100L0000n`800000000005h1000000000B00000000000000000000000000000000000000
000000@0000]0@D0100000@13@040000104700<0000N00D2003g0003007oool000100000P0000?l0
0200000P@0008800023o00100000@40004200010o`00H0000610001PP000H?l008000020@000P800
083o002P0000X4000:20002Po`00`0000<100030P000`?l00?l0003o@000oh000?oo0200000P0400
80200200o`0P80008210020PP00P8?l084000210@00P@800843o021P000PH4008620021Po`0PP000
88100220P00PP?l08:00022P@00PX8008:3o0230000P`4008<200230o`0Po`008?m0023oP00Pool0
@0000400@0100800@03o040P00108400@220040Po`10@000@4100410P010@?l0@600041P@010H800
@63o04200010P400@8200420o`10X000@:10042PP010X?l0@<000430@010`800@<3o043o0010od00
@?n0043oo`1P0000H0100600P01P0?l0H200060P@01P8800H23o0610001P@400H4200610o`1PH000
H610061PP01PH?l0H8000620@01PP800H83o062P001PX400H:20062Po`1P`000H<100630P01P`?l0
H?l0063o@01Poh00H?oo080000200400P0200800o`208000P210080PP0208?l0P4000810@020@800
P43o081P0020H400P620081Po`20P000P8100820P020P?l0P:00082P@020X800P:3o08300020`400
P<200830o`20o`00P?m0083oP020ool0X0000:00@02P0800X03o0:0P002P8400X2200:0Po`2P@000
X4100:10P02P@?l0X6000:1P@02PH800X63o0:20002PP400X8200:20o`2PX000X:100:2PP02PX?l0
X<000:30@02P`800X<3o0:3o002Pod00X?n00:3oo`300000`0100<00P0300?l0`2000<0P@0308800
`23o0<100030@400`4200<10o`30H000`6100<1PP030H?l0`8000<20@030P800`83o0<2P0030X400
`:200<2Po`30`000`<100<30P030`?l0`?l00<3o@030oh00`?oo0?l0003o0400o`200?l0o`3o8000
ob100?lPP03o8?l0od000?m0@03o@800od3o0?mP003oH400of200?mPo`3oP000oh100?n0P03oP?l0
oj000?nP@03oX800oj3o0?o0003o`400ol200?o0o`3oo`00oom00?ooP0000000100003@21P030000
=@0400001`430>Xj00133b00c00004l0KP4000004`1402P0bP0X0000KP4004l0000100P00000091a
000000000000000000000000oooo040000200000o`00000P00108000P2000?lP0000@000@4000810
003o@0000600041P0020H000of0000200010P000P8000?n00000X000@:00082P003oX0000<000430
0020`000ol00003o0010o`00P?l00?oo00000200@00P0800803o0200020P040P80208200ob0P0010
8010@200P40P0?m08000H200@60P081P803oH200080P04208020P200oh0P002P8010X200P:0P0?nP
8000`200@<0P0830803o`2000?lP043o8020ob00oolP0000@0100400P0100?l0@0008400@210080P
@03o840004100410@020@400od10001P@010H400P6100?mP@000P400@8100820@03oP4000:10042P
@020X400oj100030@010`400P<100?o0@000od00@?m0083o@03ood00001P0400H0200600o`1P000P
H0108600P21P0?lPH000@600@41P0810H03o@600061P041PH020H600of1P0020H010P600P81P0?n0
H000X600@:1P082PH03oX6000<1P0430H020`600ol1P003oH010of00P?mP0?ooH0000800@0200800
P03o08000220040PP0208800ob200010P010@800P4200?m0P000H800@620081PP03oH80008200420
P020P800oh20002PP010X800P:200?nPP000`800@<200830P03o`8000?n0043oP020oh00oon00000
X0100:00P02P0?l0X0008:00@22P080PX03o8:00042P0410X020@:00od2P001PX010H:00P62P0?mP
X000P:00@82P0820X03oP:000:2P042PX020X:00oj2P0030X010`:00P<2P0?o0X000oj00@?nP083o
X03ooj0000300400`0200<00o`30000P`0108<00P2300?lP`000@<00@4300810`03o@<000630041P
`020H<00of300020`010P<00P8300?n0`000X<00@:30082P`03oX<000<300430`020`<00ol30003o
`010ol00P?o00?oo`0000?l0@03o0800o`3o0?l0023o040Po`208?l0ob3o0010o`10@?l0P43o0?m0
o`00H?l0@63o081Po`3oH?l0083o0420o`20P?l0oh3o002Po`10X?l0P:3o0?nPo`00`?l0@<3o0830
o`3o`?l00?oo043oo`20ool000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3P0000h>3P
h>3Ph>00003Ph>3Ph>3Ph00000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>3Ph>3P
h>3Ph03Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3P000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>3Ph000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P
00000000h>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P0000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P0000
0000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003Ph>3Ph0000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000h>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003Ph>3Ph0000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P0000
0000h>3Ph>0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000>3Ph>3P00000000000000000000000000000000000000000000
000000000000000000000?ooooooooooool000000000000000000000000000000>3Ph>3P00000000
h>3Ph>3P0000003Ph>3Ph000000000000000000000000000000000000000000000000000oooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooool0000000000000003o
ooooooooooooooooool000000000000000000000h>3Ph>0000000000000000000000000000000000
0000000000000000000000000000ooooooooooooooooooooool0000000000000000000000000h>3P
h>3Ph000003Ph>3Ph>3P00000>3Ph>3P000000000000000000000000000000000000000000000000
oooooooooooooooooooo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooooooooooooooooooool0oooooooooooooooooooooooooooooooooooooooo0000
00000000oooooooooooooooooooooooo0000000000000000003Ph>3Ph00000000000000000000000
000000000000000000000000000000000000ooooooooooooooooooooooooooooo`00000000000000
003Ph>3Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000h>3Ph>3P000000000000000000000000000000000000
00000000ooooooooooooooooooooooooool000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000003ooooooooooooooooooooooooo0000000000000000003Ph>3Ph00000000000
000000000000000000000000000000000000000000000?oooooooooo00000000003ooooooooooooo
000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000
00000000000000000?ooooooooooooooooooooooooooool000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0000000000?ooooooooooooooooooooooool000000000000000000>3Ph>3P
0000000000000000000000000000000000000000000000000000003ooooooooo0000000000000000
003oooooooooool00000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000000000000000
0000000000000000000000000000oooooooooooooooooooooooooooooooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000ooooooooooooooooooooooooo`00000000000000
0000h>3Ph>0000000000000000000000000000000000000000000000000000000?oooooooooo0000
0000000000000000003oooooo`0000000>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000
0000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooo0000
000000000000003Ph>3Ph000000000000000000000000000000000000000000000000000003ooooo
ooooool0000000000000000000000000ool000000000003Ph>3Ph>3Ph000h>3Ph>3Ph000h>3Ph>3P
h>3P00000000000000000000000000000000000000000000ooooooooooooo`0000000000oooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000ooooooooooooool000000000
003oooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooooooooooo
ooooo`0000000000000000000>3Ph>3P000000000000000000000000000000000000000000000000
00000?ooool0ooooo`000000000000000000000000000000000000000000000000000000h>3Ph>00
00000>3Ph>3Ph0000000000000000000000000000000000000000000003oooooooooo`0000000000
0000003oooooooooo`00000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003oooooooooool0
0000000000000000oooooooooooooooo00000000003oooooooooo`00000000000000000000000000
ooooooooool00000000000000000000000000>3Ph>3P000000000000000000000000000000000000
000000000000003oooooo`3oooooo`00000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?ooooooool0
0000000000000000003oooooooooo`00000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooooooo000000000000000000000?ooooooooooool0000000000?oooooooooo0000000000000000
00000000003ooooooooo0000000000000000000000000000h>3Ph>00000000000000000000000000
0000000000000000000000000?oooooo003ooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
oooooooo000000000000000000000000ooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003oooooooooo`00000000000000000000000?ooooooooooo`00000000000?oooooooooo0000
000000000000000000000?ooooooool0000000000000000000000000003Ph>3Ph000000000000000
000000000000000000000000000000000000ooooo`000?ooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooool0000000000000000000000000ooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?ooooooool00000000000000000000000000?oooooooooo0000000000000?oo
oooooooo000000000000000000000000ooooooooo`000000000000000000000000000>3Ph>3P0000
00000000000000000000000000000000000000000000003ooooo0000ooooool00000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooooooo`00000000000000000000000000oooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000ooooooooo`000000000000000000000000000?oooooooooo0000
00000000ooooooooool000000000000000000000003ooooooooo0000000000000000003Ph>3Ph>3P
h>3Ph>000000000000000000000000000000000000000000000000000?ooool00000ooooo`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooo0000000000000000000000000000oooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooo00000000000000000000000000000?oo
ooooool0000000000000ooooooooooooooooooooooooooooooooooooooooool00000000000000000
h>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000000000000000000000000000ooooo`00003o
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooool00000000000000000000000000000
oooooooo000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?ooooooool000000000000000000000
00000000ooooooooo`00000000000000oooooooooooooooooooooooooooooooooooooooo00000000
00000000003Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000000000000000
ooooo`000?oooooo0000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003oooooool00000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000ooooooooo`0000000000
0000000000000000003ooooooooo000000000000003ooooooooooooooooooooooooooooooooooooo
ool000000000000000000>3Ph>3Ph>3Ph>3Ph>3P0000000000000000000000000000000000000000
00000000003ooooo00000?ooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooo`000000
00000000000000000000003oooooool0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000oooooooo
0000000000000000000000000000003oooooool0000000000000003ooooooooooooooooooooooooo
ooooooooooooo`000000000000000000003Ph>3Ph>3Ph>3Ph>000000000000000000000000000000
000000000000000000000?ooool00000ooooooooooooooooooooooooooooooooool0000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooo00000000000000000000000000000?ooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003ooooooooo00000000000000000000000000000?ooooooool00000000000000?oooooooooooooo
oooooooooooooooooooooooo00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool0003oooooooooooooooooooooooooooooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000oooooooo0000000000000000000000000000oooooooo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?ooooooool00000000000000000000000000000ooooooooo`000000000000000?oo
ooooooooooooooooooooooooooooooooool000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000ooooo`00003ooooooooooooooooooooooooo
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003oooooool00000000000000000000000000000oooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooool0000000000000000000000000003ooooooooo00000000
000000000?oooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000oooo00000?ooool000000000
0000000000000000oooo000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooool0000000000000000000000000003oooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000ooooooooool0000000000000000000000000oooooooo
ool00000000000000000ooooooooool00000000000000?ooooooool0000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003ooooo0000oooo
ool000000000000000000000003ooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000?ooooooool00000000000000000000000000?oo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000ooooooooo`0000000000000000000000
003oooooooooool00000000000000000ooooooooool0000000000000ooooooooo`00000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
oooo0000ooooo`00000000000000000000000?ooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?ooooooool00000000000000000
00000000oooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003oooooooooo`0000000000
000000000000ooooooooooooo`000000000000000000ooooooooool000000000003ooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oool0003ooooo000000000000000000000000ooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooool00000
0000000000000000003oooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
ool00000000000000000003ooooooooooooo0000000000000000003oooooooooo`0000000000oooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooool00?oooooo00000000000000000000003ooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000?oo
ooooool0000000000000000000000?ooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003oooooooooool0000000000000003oooooooooooooool00000000000000000003oooooooooo`00
0000003ooooooooo0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool00?ooool000000000000000000000ooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooool00000000000000000003ooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?ooooooooooooooo`000000003oooooooooooooooooool00000000000000000003o
oooooooo000000000?ooooooool00000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooool0ooooo`000000000000000000003o
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooooooo00000000000000000?ooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooooooooooooooooooooooooooooooooooo`0000000000
000000000?oooooooooo00000000ooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003oooooooooo`0000000000
00000000ooooool00000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooooooooooool0000000000?ooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
000000000000000000000?oooooooooo0000003ooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
0000000000000000oooooooo00000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooo
ooooooooool000000000000000000000ooooooooool00000ooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003oooooooooo`0000000000ooooooooo`0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000?oooooooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003ooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000ooooooooool0003ooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000ooooooooooooooooooooooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
ooooooooooooooooooooooooooooooooo`000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000003P
h>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>3Ph00000000000000000000000000000000000oooo
ooooooooooooooooooooo`00ooooooooo`0000000000000000000000ooooooooool00?ooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000?ooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000oooooooooooooooooooooooooooooooooooooooo00000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph000h>3Ph>3Ph>3Ph>3Ph03Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00000000000000000000000000
000000000?ooooooooooooooooooo`00003ooooooooo00000000000000000000003oooooooooo`00
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooo0000003Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000000000000000
0000000000000000000000000?oooooooooo000000000?ooooooool000000000000000000000003o
ooooooooo`3ooooooooo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooooooooooooooooooooooooooooooool000000>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P0000
00000000000000000000000000000000000000000000000000000000ooooooooo`00000000000000
00000000003oooooooooooooooooool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P0000003Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3P
h>3Ph00000000000000000000000000000000000000000000000000000000000003oooooooooo`00
000000000000000000000?oooooooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph000
00000>3Ph>3P0000000000000000000000000000000000000000000000000000000000000000003o
oooooooo0000000000000?ooooooooooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph0000000
0>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000000000000000
000000000?ooooooool000000000003oooooooooooooooooooooooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000003P
h>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000ooooooooo`00000000000?oooooooooooooooooooooooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000>3Ph>3P000000000000
000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000003oooooooooooooooooo`0000000000oooooooooooooooooooooooooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000h>3Ph>00
00000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooo00000000003ooooooooooooooooo
oooooooooooo00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003Ph>3Ph0000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>00000000000000
0000000000000000000000000000000000000000003oooooooooooooooooool000000000003ooooo
ooooooooooooooooooooool000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3P000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph000
00000000000000000000000000000000000000000000000000000?ooooooooooooooooooo`000000
00000000ooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>00000000000000000000000>3Ph>3P00000000h>3Ph>000000
003Ph>3Ph0000000000000000000000000000000000000000000000000000000oooooooooooooooo
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003P
h>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000000000000000oooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3P
h00000000>3Ph>3P00000000h>3Ph>00000000000000000000000000000000000000000000000000
000000000?ooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000>3Ph>3P0000000000000000
00000>3Ph>3P00000000h>3Ph>3P0000003Ph>3Ph000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
0000000000000000h>3Ph>3Ph000003Ph>3Ph>3P00000>3Ph>3P0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph000000000000000003Ph>3Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000h>3Ph>3P0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003Ph>3Ph000000000000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000>3Ph>3P000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3P0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000h>3Ph>000000000000000>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003Ph>3Ph000000000000000003Ph>3Ph>3Ph000
h>3Ph>3Ph000h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000
000000000000h>3Ph>0000000>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000>3Ph>3P00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000h>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003Ph>3Ph0000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000h>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3P000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000100002L1
ool40000l04600@000040@d0100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000@0
000]0@@010000?010@070000o0800000000000@0000]0@403P0002@31@2@06T0QP1]08T0J@2606D0
T01Y00@0000]0@<010000?0100080000nP8000400@000002100002d1000>00009@<50900J@2606d0
R@1Y08H0I@2@06T0100002d10`040000l04000P0003j0P000P02000000840000;@4000P0000U0`80
7P1Y08T0J@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@003P0002@31@0N02X0
8P0d01h0<@0J03@07P0Z00@0000]0@<010000?0100080000nP8000400@000002100002d1000>0000
9@<501h0:P0R03@07P0a01X0=00N02X0100002d10`040000l04000P0003j0P000P02000000840000
;@4000P0000U0`807P1Y01h0<@040000;@4300@0003`0@0020000?X20001004000000P@0000]0@00
200002D30P1<00X0_@0;00P0000U0`80_@1:0;d02@0800009@<208d0:P2l00`03P0002D31@1=00/0
7@0Z08h0:P2>06T0_01;00D000090P0000840000;P4000@0000]0@D010000?010P0L0000n`;^o`00
000009010@000000039DJFeULb1>IGLPDVm]HFh00000000000000000000000@0000]0@801`000245
0@1TofT0C`0500002@800002100002h100040000;@4500@0003`0@8070000?/2k_l00000002l0P40
0000000bE6U]IG<PCVEg859_KF5^0000000000000000000000040000;@4200L0000Q1@40L_mY05P0
1@0000T200000P@0000^0@00100002d11@040000l04201`0003k0^ko00000000T04100000000<UAY
KFEc84iUMb1BKfeQKP0000000000000000000000100002d10P0700008@D106CoF02T00D000090P00
00840000;P4000@0000]0@D010000?010P0L0000n`;^o`0000000;`20@000000039DJFeULb1>IGLP
DVm]HFh00000000000000000000000@0000]0@801`0002450@1coeP0[@0500002@800002100002h1
00040000;@4500@0003`0@8070000?/2k_l00000002@0@400000000bE6U]IG<PCVEg859_KF5^0000
000000000000000000040000;@4200L0000Q1@40I?lk00X01@0000T200000P@0000^0@00100002d1
1@040000l04201`0003k0^ko00000000_08100000000<UAYKFEc84iUMb1BKfeQKP00000000000000
00000000100002d10P0700008@D107Co>`0C00@0000]0@<010000?0100080000nP850000003oool2
100002d1000>000090<50=L07`3B02H0d`0Q0<h07`3G01l0100002d10`040000l04000P0003j0P00
0@01000000840000;@4000h0000U0`D0e`0O0=809P3C0240cP0O0=L07`0800009@<20:X0>@3C0240
100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000@0000]0@@010000?010@070000
o0800??cl`0000@0000]0@401`0001P4E`1f0540K0040000;@4300@0003`0@0020000?X200010040
00000P@0000]0@00100002d110040000l04100L0003l0P4000000000100002d10@07000060AG07H0
D@1/00@0000]0@<010000?0100080000nP850000003oool2100002d100040000;@4400@0003`0@40
1`000?`2003clo<000040000;@4100L0000H1600>`1D02d0100002d10`040000l04000P0003j0P00
0@01000000840000;@4000@0000]0@@010000?010@070000o0810000000000@0000]0@401`0001P4
H00k05@0;@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00100002d110040000
l04100L0003l0P00lo?c0000100002d10@1:000090<S03`0B@0k04T0>P1903T0B@0h04P0=`1803H0
A`0e04H0=01503<0@`0b0480<@100340?`0`03h0<00m0300?00`03/0<00j0340>@0b03T0<`0j03@0
>P0e03/0=P0l03L0?@0h03h0>@0o03X0@@0k0480>`1303`0A@0l04H0?01703`0B00l04T0100002d1
0`040000l04000P0003j0P000@01000000840000;@4004X0000U0b<0?01903/0B@0j04T0>@1903P0
B00g04P0=P1703D0AP0d04D0<`130380@P0a0400<@0o0300?P0`03d0<00l0300>`0`03X0<@0i0380
>@0c03X0=00j03D0>`0f03`0=`0m03P0?P0i03l0>P1103/0@P0k04<0?01503`0AP0l04L0?01803`0
B@040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00BP0002@38`1?0540CP1B04d0
D`1=05@0C01E04/0EP1:05H0B@1F04P0EP1705H0AP1E04H0E01505@0A@1C04D0DP150500A@1?04H0
CP1604d0A`1<04L0B`1804X0B@1:04X0B@1;04T0C01904d0BP1>04X0CP1;04l0C01?04d0C`1>04l0
C`1?0500C`1A00@0000]0@<010000?0100080000nP8000400@000002100002d1001:00009@<S04l0
D@1>0580C@1C04d0E01<05D0B`1F04X0EP1905H0B01F04L0EP1605D0AP1D04D0E01505<0A@1B04D0
D01504l0AP1>04H0C@1704`0A`1;04P0BP1904X0BP1904/0B@1<04T0C@1:04h0BP1>04/0C`1<04l0
C@1?04h0C`1?04l0D01?0540100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000L0
000H13/0L`0f06/0100002d10`040000l04000P0003j0P000@01000000840000;@4000@0000]0@@0
10000?010@070000o0810000000000@0000]0@401`0001P4>`1c03H0J`040000;@4300@0003`0@00
20000?X21@000000oooo0P@0000]0@00100002d110040000l04100L0003l0P00lo?c0000100002d1
0@18000090<R0640>@1Q03X0HP0k0680?01R03d0HP0n0680?`1Q0400H01105l0@@1N0440G@1105`0
@01K0400FP0o05X0?P1I03d0F00l05P0>`1H03X0F00i05P0>01H03L0F@0f05T0=@1J03D0F`0e05`0
=@1M03D0GP0e05l0=P1P03L0H00h0640>@040000;@4300@0003`0@0020000?X20001004000000P@0
000]0@00B00002D38P1Q03T0H@0j0680>`1R03`0HP0m0680?P1R03l0H@100600@@1O0440GP1105d0
@@1L0400F`1005X0?`1J03h0F@0m05P0?01H03/0F00j05P0>@1H03P0F00g05T0=P1I03D0FP0e05/0
=@1L03D0G@0e05h0=@1O03H0H00g0600>01Q03T0100002d10`040000l04000P0003j0PD000000?oo
o`840000;@400480000T0al0H01H0600F@1P05X0G`1J05h0F`1N05`0G@1L05`0G@1J05d0F@1N05P0
GP1G05l0EP1O05D0G`1D05l0D`1O05<0GP1C05d0D`1L05@0F`1E05X0EP1J05L0F@1H05P0F@1H05X0
F01L05L0G@1G05h0E`1O05L0H01H00@0000]0@<010000?0100080000nP8000400@000002100002d1
001200009@<O0600F01P05T0H01J05l0FP1N05/0GP1L05d0G01L05d0FP1M05T0GP1H05h0E`1O05H0
G`1E05l0E01O05<0G`1C05h0D`1M05<0G01D05/0E@1J05H0FP1G05T0F01H05T0F01J05P0G01G05d0
E`1N05L0G`1G0600F0040000;@4300@0003`0@0020000?X21@000000oooo0P@0000]0@00CP0002@3
9@2604H0QP1808H0B@2604/0QP1=08H0CP2504l0Q@1@08@0D@230540PP1A0840D@200500O`1@07h0
C`1n04d0O@1<07`0BP1l04P0N`1607/0A@1k04<0N`1107`0@01l03l0O@0n07d0?@1n03d0O`0m0800
?@2103h0PP0n08<0?`240440Q@1208D0A02604H0100002d10`040000l04000P0003j0P000@010000
00840000;@4004h0000U0bD0QP1608H0B02604T0QP1;08H0C@2604h0Q@1?08D0D0240540P`1A0880
D@210540P01@07l0D01n04l0OP1=07d0C01l04X0O01807/0AP1k04D0N`1307/0@@1l0400O00o07d0
?P1m03d0OP0m07l0?@2003d0P@0n0880?P2303l0Q01108D0@P2504@0QP1600@0000]0@<010000?01
00080000nP850000003oool2100002d100040000;@4400@0003`0@401`000?`2003Vi^H000040000
;@4100L0000H1240^00K0;@0100002d10`040000l04000P0003j0P000@01000000840000;@4000@0
000]0@@010000?010@070000o0810000000000@0000]0@401`0001P48@2h01/0]0040000;@4300@0
003`0@0020000?X21@000000oooo0P@0000]0@00100002d110040000l04100L0003l0P00i^KV0000
100002d10@18000090<R0:T0:02Z02T0ZP0Z0:X0:`2Z02`0ZP0]0:X0;P2Y02l0Z00`0:L0<02V02l0
Y@0_0:@0;P2T02d0X`0]0:80:`2R02X0X@0Y0:40:02Q02L0X@0V0:409@2R02@0XP0S0:808P2S0280
Y00R0:D08P2V02<0Y`0S0:P0902X02D0Z@0V0:T0:0040000;@4300@0003`0@0020000?X200010040
00000P@0000]0@00B00002D38P2Y02P0ZP0Y0:X0:P2Z02/0ZP0/0:X0;@2Z02h0Z@0_0:P0<02W0300
YP0_0:D0;`2T02h0Y00]0:<0;@2R02/0XP0Z0:40:@2Q02P0X@0W0:409P2Q02D0XP0T0:808`2R0280
X`0R0:@08P2U0280YP0S0:L08`2X02@0Z00U0:T09P2Y02P0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4003H0000T0aT0WP1309d0@`2L04<0V`1309X0@`2I0480V01209L0@@2F0400
U@0o09D0?P2E03d0UP0m09L0?@2H03d0V@0m09X0?P2K03h0V`0o09`0?`2M0400WP1109h0@P2O0480
WP1300@0000]0@<010000?0100080000nP8000400@000002100002d1000f00009@<I09h0@`2M04<0
W01309/0@`2J04<0V@1209P0@P2G0440UP1009D0?`2E03h0U@0m09H0?@2G03d0V00m09T0?@2J03h0
V`0n09/0?`2L03l0W@1009h0@@2N0480W`1209h0@`040000;@4300@0003`0@0020000?X21@000000
oooo0P@0000]0@001`0001P4B02h03h0[@040000;@4300@0003`0@0020000?X20001004000000P@0
000]0@00100002d110040000l04100L0003l0P4000000000100002d10@07000060A80;P0?P2]00@0
000]0@<010000?0100080000nP850000003oool2100002d100040000;@4400@0003`0@401`000?`2
003Vi^H000040000;@4104P0000T0b80WP1G09h0F02M05T0W@1J09`0F`2K05/0VP1L09T0G02H05`0
V01K09L0F`2G05X0U`1I09L0F02G05L0U`1F09L0E@2H05@0V01C09T0DP2J0540VP1@09/0D02L04l0
W@1?09h0C`2O0500W`1A0:00DP2P05<0X01D09l0E@2O05H0WP1G00@0000]0@<010000?0100080000
nP8000400@000002100002d1001800009@<R09h0E`2N05P0W@1I09d0FP2L05/0V`1K09X0G02I05`0
V01L09P0F`2G05/0U`1J09L0F@2G05P0U`1G09L0EP2G05D0V01D09P0D`2I0580VP1A09X0D02K0500
W01?09d0C`2N04l0W`1@09l0D@2P0580X01C0:00E02O05D0W`1F09h0E`040000;@4300@0003`0@00
20000?X21@000000oooo0P@0000]0@00100002d110040000l04100L0003l0P00/k>c0000100002d1
0@10000090<N05`0501L01D0F`0E05/05P1J01H0F@0G05P05`1G01L0EP0G05@05`1C01L0DP0G0540
5`1@01L0C`0F04l05@1?01@0D00D05404`1B01<0D`0C05@04P1E0180EP0B05L04P1H0180F@0B05X0
4`1K01<0G00D00@0000]0@<010000?0100080000nP8000400@000002100002d1001000009@<N05`0
501L01D0F`0E05/05P1J01H0F@0G05P05`1G01L0EP0G05@05`1C01L0DP0G05405`1@01L0C`0F04l0
5@1?01@0D00D05404`1B01<0D`0C05@04P1E0180EP0B05L04P1H0180F@0B05X04`1K01<0G00D00@0
000]0@<010000?0100080000nP850000003oool2100002d10014000090<P06l08`1_02@0KP0T06d0
901/02<0J`0S06X08`1Y0280J00Q06L0801V0200I@0O06@07P1S01d0H`0L06<06`1S01X0I00J06D0
6P1V01X0I`0J06P06P1Y01/0JP0L06/0701/01d0K@0N06h07`1_0200L00Q07008P1_02<0100002d1
0`040000l04000P0003j0P000@01000000840000;@4004@0000U0b00K`0S06l0901^02@0K@0T06`0
8`1[02<0JP0S06T08P1X0240I`0P06H0801U01l0I00N06<07@1S01`0H`0K06<06P1T01X0I@0J06H0
6P1W01X0J00J06T06`1Z01`0J`0L06`07@1]01h0KP0O06l0801`0240L00R06l08`040000;@4300@0
003`0@0020000?X21@000000oooo0P@0000]0@00BP0002@38`2801@0R@0E08T05P2:01L0RP0I08X0
6P2:01/0R@0L08P07@2701h0QP0N08D07P2301d0PP0M0840702001/0P00J07l06@1n01P0OP0G07h0
5@1n01@0OP0C07h04P1o0180P00A080040210100PP0@08<040240140Q@0A08H04P2701<0R00D00@0
000]0@<010000?0100080000nP8000400@000002100002d1001:00009@<S08P0502901D0R@0F08X0
5`2:01T0RP0J08X06`2901`0R00M08L07P2601h0Q@0N08<07@2201d0P@0L08006`2001X0O`0I07h0
601n01L0OP0E07h0501n01<0OP0B07l04P200140P00@084040220100P`0@08@04@250140QP0B08L0
4`2801@0100002d10`040000l04000P0003j0PD000000?ooo`840000;@4000L0000H12P0@@0S03D0
100002d10`040000l04000P0003j0P000@01000000840000;@4000@0000]0@@010000?010@070000
o0810000000000@0000]0@401`0001P4:01102<0=@040000;@4300@0003`0@0020000?X21@000000
oooo0P@0000]0@00100002d110040000l04100L0003l0P00/k>c0000100002d10@07000060@I0:P0
4@2N00@0000]0@<010000?0100080000nP8000400@000002100002d100040000;@4400@0003`0@40
1`000?`20@00000000040000;@4100L0000H11T0Z00A09h0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000@0000]0@@010000?010@070000o0800000000000@0000]0@403P0002@3
1@2m04/0]`1D0;L0C`2b04d0_@1;00@0000]0@<010000?0100080000nP8000400@000002100002d1
000>00009@<50;d0B`2g05@0]`1?0;80C@2m04/0100002d10`040000l04000P0003j0P000P020000
00840000;@4000P0000U0`80T01Y0;L0C`0300007P050P00m`000`01oooo0000@0000800003o000P
000084000220000Po`00@00004100010P000@?l00600001P@000H800063o00200000P40008200020
o`00X0000:10002PP000X?l00<000030@000`8000<3o003o0000od000?n0003oo`0P000080100200
P00P0?l08200020P@00P8800823o0210000P@40084200210o`0PH0008610021PP00PH?l088000220
@00PP800883o022P000PX4008:20022Po`0P`0008<100230P00P`?l08?l0023o@00Poh008?oo0400
00100400@0200400o`108000@210040PP0108?l0@4000410@010@800@43o041P0010H400@620041P
o`10P000@8100420P010P?l0@:00042P@010X800@:3o04300010`400@<200430o`10o`00@?m0043o
P010ool0H0000600@01P0800H03o060P001P8400H220060Po`1P@000H4100610P01P@?l0H600061P
@01PH800H63o0620001PP400H8200620o`1PX000H:10062PP01PX?l0H<000630@01P`800H<3o063o
001Pod00H?n0063oo`200000P0100800P0200?l0P200080P@0208800P23o08100020@400P4200810
o`20H000P610081PP020H?l0P8000820@020P800P83o082P0020X400P:20082Po`20`000P<100830
P020`?l0P?l0083o@020oh00P?oo0:00002P0400X0200:00o`2P8000X2100:0PP02P8?l0X4000:10
@02P@800X43o0:1P002PH400X6200:1Po`2PP000X8100:20P02PP?l0X:000:2P@02PX800X:3o0:30
002P`400X<200:30o`2Po`00X?m00:3oP02Pool0`0000<00@0300800`03o0<0P00308400`2200<0P
o`30@000`4100<10P030@?l0`6000<1P@030H800`63o0<200030P400`8200<20o`30X000`:100<2P
P030X?l0`<000<30@030`800`<3o0<3o0030od00`?n00<3oo`3o0000o`100?l0P03o0?l0ob000?lP
@03o8800ob3o0?m0003o@400od200?m0o`3oH000of100?mPP03oH?l0oh000?n0@03oP800oh3o0?nP
003oX400oj200?nPo`3o`000ol100?o0P03o`?l0ool00?oo@03ooh00000000@0000d0PH00`0003D0
100000L10`1Z1@00@`lP0<`0000D058000000180@@0l0=D0:0000580000D00000@080000002@1P00
000000000000000000000?ooo`100000P0000?l000008000@200080P003o8000040004100020@000
od00001P0010H000P6000?mP0000P000@8000820003oP0000:00042P0020X000oj0000300010`000
P<000?o00000o`00@?l0083o003oo`00000P040080200200o`0P000P80108200P20P0?lP8000@200
@40P0810803o@200060P041P8020H200of0P00208010P200P80P0?n08000X200@:0P082P803oX200
0<0P04308020`200ol0P003o8010ob00P?lP0?oo80000400@0100800@03o04000210040P@0208400
ob100010@010@400P4100?m0@000H400@610081P@03oH40008100420@020P400oh10002P@010X400
P:100?nP@000`400@<100830@03o`4000?m0043o@020od00oom00000H0100600P01P0?l0H0008600
@21P080PH03o8600041P0410H020@600od1P001PH010H600P61P0?mPH000P600@81P0820H03oP600
0:1P042PH020X600oj1P0030H010`600P<1P0?o0H000of00@?mP083oH03oof0000200400P0200800
o`20000PP0108800P2200?lPP000@800@4200810P03o@8000620041PP020H800of200020P010P800
P8200?n0P000X800@:20082PP03oX8000<200430P020`800ol20003oP010oh00P?n00?ooP0000:00
@02P0800X03o0:00022P040PX0208:00ob2P0010X010@:00P42P0?m0X000H:00@62P081PX03oH:00
082P0420X020P:00oh2P002PX010X:00P:2P0?nPX000`:00@<2P0830X03o`:000?nP043oX020oj00
oonP0000`0100<00P0300?l0`0008<00@230080P`03o8<0004300410`020@<00od30001P`010H<00
P6300?mP`000P<00@8300820`03oP<000:30042P`020X<00oj300030`010`<00P<300?o0`000ol00
@?o0083o`03ool00003o0400o`200?l0o`3o000Po`108?l0P23o0?lPo`00@?l0@43o0810o`3o@?l0
063o041Po`20H?l0of3o0020o`10P?l0P83o0?n0o`00X?l0@:3o082Po`3oX?l00<3o0430o`20`?l0
ol3o003oo`10ool0P?oo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooo00000000000000000000000000000000000000000000000000000000003P
h>3Ph>00000000000000000000000000000000000000003oo`000000000000000000o`0000000000
000000000000000000000000000000000>3P0000000000000000000000000000000000000000003o
o`000000000000000000o`0000000000000000000000000000000000000000000>3P000000000000
0000000000000000000000000000003oo`3oool000000000003oooooo`00000000000?ooo`3oool0
ooooo`00ooooo`00003Ph00000000000oooooooo00000000000000000000003oool00?oo00000000
0?oo0?l0ool000000000ool00?ooo`000?oo00000?oo0000h>3Ph0000000003oo`00000000000000
0000000000000000ool0003oo`0000000?oo0?l00?oo0000003oo`00003oo`000?oo00000?oo0000
0000000000000?ooo`000000000000000000000000000000ool0003oo`0000000?oo0?l00?oo0000
003oo`00003oo`00003oooooool00000003Ph00000000?oooooooooo000000000000000000000000
ool0003oo`0000000?oo003o0?oo0000003oo`00003oo`00003oo`00ool000000000000000000?oo
o`000?oo000000000000000000000000oooo003oo`000000003oo`3o0?oo00000000ool00?ooo`00
003oo`00ool00000000000000000003oo`000?oo00000000000000000000003oool0oooo00000000
0000ooooool0000000000?ooo`3oo`000000o`00o`0000000000000000000000ooooool000000000
000000000000000000000000000000000000003o0000000000000000003oo`000000ooooo`000000
0000000000000000000000000000h>3Ph>3P000000000000000000000000000000000000o`000000
00000000003oo`000?ooooooo`0000000000000000000000000000000000003Ph000000000000000
000000000000000000000000o`000000000000000?ooo`0000000000000000000000000000000000
000000000000003Ph000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000h>000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000>3P
h>000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000h>00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000400009`7oo`@0003`0@H0100002d10`040000l04000P0003j0PD0
00000?ooo`840000;@4000h0000T0`D0]0140;h0@@2k04D0_P190;@0A0040000;@4300@0003`0@00
20000?X20001004000000P@0000]0@003P0002D31@2d04@0_P110;/0A@2n04T0]01400@0000]0@<0
10000?0100080000nP850000003oool2100002d1000>000090<50=D0AP3?04H0c@170=<0A`3E04H0
3P0002@31@3;04H0a@150<<0AP3904L0b`1600h0000T0`D0`@150;`0A@2j04H0_`160<40A@040000
9`7oo`@0003`0@0010000?010@040000l04200@0003`0@<010000?0110040000l04500<0000008/3
4@0000`0000800002`00010000240@00^`0000T0000@0000Q0400;/0000:000040000?oooooooooo
2@000100000S0@00S@000180000<00000@00024000080000500000`0000700009P0001`000010000
000000400001000000000RD0000<00000@0002D0000<00000000P580001<0@000P00000000000000
00000000001N0@00000000000B0008T1jaJ;A@R;C@R;02CW30B90N/6RdD8P23SRdD8RddD`N45R`0c
b87Qh?l103?8RdD8R@R;A@R0B201R`00000PR`R0hN>0b@:928]568]E28]818U:58/0RD8@ReD8P4Y@
0H]528]e78?0D8/8P>7SP<T2R@R;C@R;APB9@DB;5XUA@>Q<1000SDd8DFX1JP1GoaE0HJ/1RdD8Pl08
mP0@M0>08okf00Qd0h0SnoH017@3P2?gmP02M0>08nl0005d0h0Sgh]528/0Pn03M163n05d4X?h0W@I
PoP3M23[8X1S0O?[78/3P>CgP<`4R@?[48/3P>CkP<`8R@?[00000000000000000000000000000000
0@410@410@410H3T9@0000`0000200008@0000P0000a000040@000<000000`01oooo0000@0000800
003o000P000084000220000Po`00@00004100010P000@?l00600001P@000H800063o00200000P400
08200020o`00X0000:10002PP000X?l00<000030@000`8000<3o003o0000od000?n0003oo`0P0000
80100200P00P0?l08200020P@00P8800823o0210000P@40084200210o`0PH0008610021PP00PH?l0
88000220@00PP800883o022P000PX4008:20022Po`0P`0008<100230P00P`?l08?l0023o@00Poh00
8?oo040000100400@0200400o`108000@210040PP0108?l0@4000410@010@800@43o041P0010H400
@620041Po`10P000@8100420P010P?l0@:00042P@010X800@:3o04300010`400@<200430o`10o`00
@?m0043oP010ool0H0000600@01P0800H03o060P001P8400H220060Po`1P@000H4100610P01P@?l0
H600061P@01PH800H63o0620001PP400H8200620o`1PX000H:10062PP01PX?l0H<000630@01P`800
H<3o063o001Pod00H?n0063oo`200000P0100800P0200?l0P200080P@0208800P23o08100020@400
P4200810o`20H000P610081PP020H?l0P8000820@020P800P83o082P0020X400P:20082Po`20`000
P<100830P020`?l0P?l0083o@020oh00P?oo0:00002P0400X0200:00o`2P8000X2100:0PP02P8?l0
X4000:10@02P@800X43o0:1P002PH400X6200:1Po`2PP000X8100:20P02PP?l0X:000:2P@02PX800
X:3o0:30002P`400X<200:30o`2Po`00X?m00:3oP02Pool0`0000<00@0300800`03o0<0P00308400
`2200<0Po`30@000`4100<10P030@?l0`6000<1P@030H800`63o0<200030P400`8200<20o`30X000
`:100<2PP030X?l0`<000<30@030`800`<3o0<3o0030od00`?n00<3oo`3o0000o`100?l0P03o0?l0
ob000?lP@03o8800ob3o0?m0003o@400od200?m0o`3oH000of100?mPP03oH?l0oh000?n0@03oP800
oh3o0?nP003oX400oj200?nPo`3o`000ol100?o0P03o`?l0ool00?oo@03ooh0000000300000<0000
0`0003@0000800005@0000`000030000D@0000ag000?0@00=P0006P1001?0000bP0002P000000000
000006h1001?0000D00002`5001l1@00T7400000000P0<`0A00001<0000X0000KP4004l0000100P0
0000091a000000000000000000000000oooo040000200000o`00000P00108000P2000?lP0000@000
@4000810003o@0000600041P0020H000of0000200010P000P8000?n00000X000@:00082P003oX000
0<0004300020`000ol00003o0010o`00P?l00?oo00000200@00P0800803o0200020P040P80208200
ob0P00108010@200P40P0?m08000H200@60P081P803oH200080P04208020P200oh0P002P8010X200
P:0P0?nP8000`200@<0P0830803o`2000?lP043o8020ob00oolP0000@0100400P0100?l0@0008400
@210080P@03o840004100410@020@400od10001P@010H400P6100?mP@000P400@8100820@03oP400
0:10042P@020X400oj100030@010`400P<100?o0@000od00@?m0083o@03ood00001P0400H0200600
o`1P000PH0108600P21P0?lPH000@600@41P0810H03o@600061P041PH020H600of1P0020H010P600
P81P0?n0H000X600@:1P082PH03oX6000<1P0430H020`600ol1P003oH010of00P?mP0?ooH0000800
@0200800P03o08000220040PP0208800ob200010P010@800P4200?m0P000H800@620081PP03oH800
08200420P020P800oh20002PP010X800P:200?nPP000`800@<200830P03o`8000?n0043oP020oh00
oon00000X0100:00P02P0?l0X0008:00@22P080PX03o8:00042P0410X020@:00od2P001PX010H:00
P62P0?mPX000P:00@82P0820X03oP:000:2P042PX020X:00oj2P0030X010`:00P<2P0?o0X000oj00
@?nP083oX03ooj0000300400`0200<00o`30000P`0108<00P2300?lP`000@<00@4300810`03o@<00
0630041P`020H<00of300020`010P<00P8300?n0`000X<00@:30082P`03oX<000<300430`020`<00
ol30003o`010ol00P?o00?oo`0000?l0@03o0800o`3o0?l0023o040Po`208?l0ob3o0010o`10@?l0
P43o0?m0o`00H?l0@63o081Po`3oH?l0083o0420o`20P?l0oh3o002Po`10X?l0P:3o0?nPo`00`?l0
@<3o0830o`3o`?l00?oo043oo`20ool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00h>3Ph>3Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000h>3Ph>3Ph>3Ph>3Ph000h>3Ph>3Ph>3P003P
h>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>00003Ph>3P
h>3Ph0000>3Ph>3Ph>3P000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph000
00000>3Ph>3P00000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0>3Ph>3P00000000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph0000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3P0000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3P
h0000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000003Ph>3Ph000
00000>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000h>3Ph>000000
003Ph>3Ph00000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003Ph>3Ph0000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003P
h>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3P00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000ooooooooooooo`00000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000h>3Ph>0000000000
00000000000000000000000000000000000000000000000000000000ooooooooooooo`0000000000
00000000000000000000h>3Ph>000000003Ph>3Ph>0000000>3Ph>3P000000000000000000000000
000000000000000000000000003ooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003ooooooooooooooooooooo0000oooooooooooooooooooo
ooooooooooooooooo`000000000000000?ooooooooooooooooooo`000000000000000000003Ph>3P
h00000000000000000000000000000000000000000000000000000000000003ooooooooooooooooo
ooooo`0000000000000000000000003Ph>3Ph>3P00000>3Ph>3Ph>000000h>3Ph>00000000000000
00000000000000000000000000000000003oooooooooooooooooool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooooooooooooooooooooooo`3ooooooooo
ooooooooooooooooooooooooooooool000000000003oooooooooooooooooooooool0000000000000
00000>3Ph>3P00000000000000000000000000000000000000000000000000000000003ooooooooo
oooooooooooooooooooo00000000000000000>3Ph>3Ph>3Ph>3P0000h>3Ph>3Ph>00003Ph>3Ph>00
0000000000000000000000000000000000000000003oooooooooooooooooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000?ooooooooooooooooooooooool0
00000000000000000>3Ph>3P00000000000000000000000000000000000000000000000000000000
ooooooooool0000000000?ooooooooooool000000000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph0000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
o`000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000oooooooooooooooo
ooooooooo`000000000000000000h>3Ph>0000000000000000000000000000000000000000000000
000000000?ooooooool000000000000000000?ooooooooooo`0000000>3Ph>3Ph>3Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000003ooooooooooooooooo
ooooooooooooool00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000003ooooo
oooooooooooooooooooo0000000000000000003Ph>3Ph00000000000000000000000000000000000
00000000000000000000ooooooooool0000000000000000000000?oooooo00000000h>3Ph>3Ph>3P
h03Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph0000000000000000000000000000000000000000000oooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
0000003oooooooooooooooooooooool000000000000000000>3Ph>3P000000000000000000000000
00000000000000000000000000000?ooooooooooo`0000000000000000000000003oo`0000000000
0>3Ph>3Ph>3P003Ph>3Ph>3P003Ph>3Ph>3Ph>000000000000000000000000000000000000000000
003ooooooooooooo00000000003ooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooo
oooo0000000000000000oooooooooooooooooooo00000000000000000000h>3Ph>00000000000000
0000000000000000000000000000000000000000ooooo`3ooooo0000000000000000000000000000
000000000000000000000000003Ph>3Ph0000000h>3Ph>3P00000000000000000000000000000000
0000000000000?oooooooooo00000000000000000?oooooooooo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooooooooooo`00000000000000003oooooooooooooool0000000000?oo
oooooooo000000000000000000000000003oooooooooo`00000000000000000000000000h>3Ph>00
0000000000000000000000000000000000000000000000000?oooooo0?oooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000ooooooooo`0000000000000000000?oooooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooooooool000000000000000000000ooooooooooooo`00
00000000ooooooooool00000000000000000000000000?ooooooool0000000000000000000000000
003Ph>3Ph000000000000000000000000000000000000000000000000000ooooool00?ooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000003oooooool000000000000000000000003ooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000?oooooooooo000000000000000000000000oooo
oooooooo000000000000ooooooooool0000000000000000000000000ooooooooo`00000000000000
0000000000000>3Ph>3P000000000000000000000000000000000000000000000000003ooooo0000
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooooooo`0000000000000000000000003o
oooooooo000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000ooooooooo`000000000000000000
00000000ooooooooool0000000000000ooooooooool000000000000000000000003ooooooooo0000
000000000000000000000000h>3Ph>00000000000000000000000000000000000000000000000000
0?ooool0003oooooo`00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000oooooooo0000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003ooooooooo00000000
00000000000000000000ooooooooool000000000003oooooooooo`00000000000000000000000?oo
ooooool000000000000000000>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000
000000000000ooooo`00003ooooo0000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003oooooool00000
00000000000000000000003oooooool0000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ool00000000000000000000000000000ooooooooo`0000000000003ooooooooooooooooooooooooo
ooooooooooooooooo`00000000000000003Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000
00000000000000000000003ooooo00000?ooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000?oo
ooooo`00000000000000000000000000003oooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000ooooooooo`00000000000000000000000000003ooooooooo000000000000003ooooooooooooo
ooooooooooooooooooooooooool000000000000000000>3Ph>3Ph>3Ph>3Ph>3P0000000000000000
00000000000000000000000000000000003ooooo0000ooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000?ooooooo`000000000000000000000000000?ooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003ooooooooo00000000000000000000000000000?ooooooool00000000000000?oo
ooooooooooooooooooooooooooooooooooooo`000000000000000000h>3Ph>3Ph>3Ph>3Ph>000000
000000000000000000000000000000000000000000000?ooool00000ooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooo00000000000000000000000000000?ooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003oooooool000000000000000000000000000000?ooooooo`000000
000000000?oooooooooooooooooooooooooooooooooooooo000000000000000000000>3Ph>3Ph>3P
h>3Ph000000000000000000000000000000000000000000000000000ooooo`00003ooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooool00000000000000000000000000000oooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?ooooooool00000000000000000000000000000oooo
ooooo`00000000000000ooooooooooooooooooooooooooooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000ooooo`000?oo
ooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooool0000000000000000000000000003o
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000ooooooooo`0000000000000000000000
0000003ooooooooo0000000000000000ooooooooooooooooooooooooooooooooooooo`0000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
oooo00000?oooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?ooooooo`000000000000000000
00000000003oooooool0000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000ooooooooo`0000000000
00000000000000000?ooooooool00000000000000000ooooooooooooooooooooooooooooooooool0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oool00000ooooo`0000000000000000000000003oool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?ooooooo`000000
000000000000000000000?ooooooo`00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
o`0000000000000000000000003oooooooooo`00000000000000003oooooooooo`00000000000000
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooool0003oooooo`00000000000000000000000?ooool0000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
ooooo`00000000000000000000000000oooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003ooooooooo0000000000000000000000000?ooooooooooo`00000000000000003oooooooooo`00
00000000003ooooooooo000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?ooool0003ooooo000000000000000000000000ooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000ooooooooo`0000000000000000000000003oooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooooooo00000000000000000000003ooooooooooooo0000000000000000003o
ooooooooo`00000000000?ooooooool0000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?ooo`000?ooool000000000000000000000
003ooooo000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000ooooooooo`00000000000000000000000?ooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooo`0000000000000000000?ooooooooooool000000000
000000000?oooooooooo00000000003oooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000ooooo`00ooooool000000000
0000000000000?ooool0000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000ooooooooo`0000000000000000000000oooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?ooooooooooo`000000000000000?oooooooooooooo
o`0000000000000000000?oooooooooo000000000?ooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000ooooo`00oooo
o`000000000000000000003oooooo`00000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003oooooooooo`0000000000000000000?oooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000oooooooooooooooo000000000?oooooo
ooooooooooooo`0000000000000000000?ooooooool000000000ooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooo`3ooooo000000000000000000000?ooool00000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003oooooooooool0000000000000
0000ooooooooo`000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooo00000000000000000000ooooooooool00000003ooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooooooo0000000000000000003oooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
o`0000000000oooooooooooo00000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooooooooooooooooooooooooooooooool000000000000000000000ooooooooool000000?oooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooool0000000000000003oooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?ooooooooooooooooooooooooooooooooooooooo`000000000000000000003oooooooooo`00
003oooooooooo`000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?oooooooooo00000000003ooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooo00000000000000000000003o
ooooooooo`000?ooooooool000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000003oooooooooooooooooooooooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo000000000>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>0000000>3Ph>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000
0000000000000000000000000000003ooooooooooooooooooooooooo003ooooooooo000000000000
00000000003oooooooooo`00ooooooooo`0000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000oooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003oooooooooooooooooooooooooooooooooooooool0
0000003Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3P003Ph>3Ph>3Ph>3Ph>3P0>3Ph>3Ph>3Ph>00h>3P
h>3Ph>3Ph00000000000000000000000000000000000oooooooooooooooooooo00000?ooooooool0
000000000000000000000?oooooooooo003ooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
ooooooooooooo`000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
ooooooooool000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000>3Ph>3Ph>3Ph>3Ph>000>3Ph>3P
h>3Ph000h>3Ph>3Ph>3P0000000000000000000000000000000000000000ooooooooool000000000
ooooooooo`00000000000000000000000?oooooooooo0?ooooooool0000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
ooooooooooooooooooooo`000000h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph000h>3Ph>3Ph>3Ph>3P
h000h>3Ph>3Ph>3P003Ph>3Ph>3Ph>00000000000000000000000000000000000000000000000000
00000000003ooooooooo0000000000000000000000000?ooooooooooooooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>0000000>3P
h>3Ph>3Ph>00003Ph>3Ph>3Ph0000>3Ph>3Ph>3P0000000000000000000000000000000000000000
000000000000000000000?oooooooooo000000000000000000000000ooooooooooooooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph00000000000
00000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>0000000000000000000000000000000000
000000000000000000000000000000000?ooooooool0000000000000oooooooooooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P
000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000000000000000
00000000000000000000000000000000000000000000ooooooooo`00000000000?oooooooooooooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000h>3Ph>00000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph00000000000
0000000000000000000000000000000000000000000000000000003ooooooooo000000000000oooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P
000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo0000
0000003oooooooooooooooooooooooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph00000000>3Ph>3P0000
0000h>3Ph>000000000000000000000000000000000000000000000000000000003ooooooooooooo
ooooool0000000000?ooooooooooooooooooooooooooool000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000>3Ph>3P000000000000000000000>3Ph>3P00000000
h>3Ph>000000003Ph>3Ph00000000000000000000000000000000000000000000000000000000?oo
ooooooooooooooooo`00000000000?ooooooooooooooooooooooooooo`0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000h>3Ph>0000000000000000000000h>3P
h>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000000000000000000000000000
00000000oooooooooooooooooooo000000000000003ooooooooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003Ph>3Ph000000000000000
00000000h>3Ph>000000003Ph>3Ph00000000>3Ph>3P000000000000000000000000000000000000
0000000000000000003oooooooooooooooooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph000
0000000000000000003Ph>3Ph00000000>3Ph>3P00000000h>3Ph>00000000000000000000000000
0000000000000000000000000000003oooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0>3Ph>3P000000000000000000000>3Ph>3P00000000h>3Ph>000000003Ph>3Ph000000000000000
00000000000000000000000000000000000000000000ooooooooooooooooo`000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000h>3Ph>0000000000000000000000h>3Ph>000000003Ph>3Ph>0000000>3Ph>3P0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003Ph>3Ph0000000000000000000003Ph>3Ph>3P00000>3Ph>3Ph>000000
h>3Ph>00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000>3Ph>3P00000000000000000>3Ph>3Ph>3Ph>3P0000h>3P
h>3Ph>00003Ph>3Ph>00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000>3Ph>3P000000000000003Ph>3Ph>3Ph>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph>000000000000000>3P
h>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003Ph>3Ph0000000
00000000h>3Ph>3Ph>3Ph03Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph0000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000>3P
h>3P00000000000000000>3Ph>3Ph>3P003Ph>3Ph>3P003Ph>3Ph>3Ph>0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000h>3Ph>000000000000000000000000000000003Ph>3Ph0000000h>3Ph>3P000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000h>3Ph>000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003Ph>3Ph0000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000>3Ph>3P00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000h>3Ph>0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000>3Ph>3Ph>3Ph>3Ph00000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003Ph>3Ph>3Ph>3Ph>3P
h0000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000>3Ph>3P
h>3Ph>3Ph>3P00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000h>3Ph>3Ph>3Ph>3Ph>0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000>3Ph>3Ph>3Ph>3Ph00000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000R000030000?oooolX0000300000<0000D0000300000d0000V0000
700000<00005000000000000003oool29@0000`0000300009@0000`000040020EP000300002d0000
Q`000<40002B00001@000900J@2606d0R@1Y08H0I@2@06T09@0000`000010000:00000`000030000
9P0001`000030000000000400001000000000RD0000<00000`0005L0000`0000]00008L000310000
TP0000D0002@06T0QP1]08T0J@2606D0T01Y02D0000<00000@0002P0000<00000`0002H0000L0000
0`000000000200000P000000008U0000300000<0001G0000900002P0002<0000^@0008h000020000
7P1Y08T0J@0U000030000040000X0000300000<0000V0000700000<00005000000000000003oool2
9@0000`000030000EP000300000T0000>@0002l0001600001@0001h0:P0R03@07P0a01X0=00N02X0
9@0000`000010000:00000`0000300009P0001`000030000000000400001000000000RD0000<0000
0`0005L0000`0000900003T0000_0000AP0000D0000N02X08P0d01h0<@0J03@07P0Z02D0000<0000
0@0002P0000<00000`0002H0000L00000`000000000200000P000000008U0000300000<0001G0000
900002P000110000:P0008h0000200007P1Y01h0<@0U000030000040000X0000300000<0000V0000
700000<0000000000@000040000000029@0000`000030000E`0002@0001W00003`000?d0000@0000
0P0004`02P2m00/0E`0002@0003m00003@000?d0001S00000P000;d0BP2m00T0E`0002@0002m0000
4@000?`0000i00000P0008d0:P2l00`0E`000300000X000040000?`0002=00001@0004d02`0M02X0
SP0Z08h0J@2l04/0600000`000000002DP0004`100040000k_ooo`00000000000000090100010000
0000<U@0J@1]06D0L`0P04h0I@1g0200DP1_06d0H@1^0000JP2QT_jZ0E2Q_?nZ0E3XnKKnoh?43:=h
kZX1Pceh000000n43P0006K7QFCooolE0>TF0P00Pcg4ojX100n44@000>ST3000IXV5I?ooonWh0@00
JP4c`6JQX_jZ0H_80l0[`OOHD:6lojX1D>RJ]_koPl@<XgS^ZP63?GS^ZP403h@>0000I/N5I?oooaD0
jKL1001VahE/oooo003Y1`0006KoQFcoool?_`FhoZX13kn=K?oooc_13hj<0@00XJCnZP5@<l1VXK83
Z`5@JP5X/>jZ0NRa]OkoPl@@XgP0000000000000000000000000000000010@410@410@410E0U0000
300000@0001D0000E00006/0002=0000MP000:L0000100000:0<@^dh349?0000J@000040001<0000
000000000000000000000000001@0000I023?@T0000U000030000080000X0000300000@0001B0000
C04000@0003^oooo0000000000000000_08000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0
K@1Q06h000000021hOoo000[`@n_QF3oool[d_LeM?nZ0H/=V0L00000RIX00021hOoo0003`FJ9QEco
ool?_hELoooo3kl=O>jZ0C_13h@g0000IX^5G?ooofJSO>jZ0FJQO>jZ0E2QV0N[0Om@36J9QFCoool?
_hETooooQL0?Q0D0003Y1@000>UGo_ooPcflojX100n43P000:6lojX1D>QX[Oko0004IX^5I?ooonT0
0000GeiKbL?<c<c<EH_/Pn`HDeIGI/M5m000I/M5n000XD`4Z`6;@2jSP>jZ0H<mP>jZ0@0000000000
0000000000000000000000410@410@410@6Q02D0000<0000100005@0001D0000M`0008d0001o0000
Z00000400000X0a2kCP<@UP0001Y00000@0004`000000000000000000000000000000500001b0000
1`0002D0000<00000P0002P0000<000010000580001<0@0010000>koool0000000000000002@0@00
0@000000039D06T0K@1U07<0801>06D0M`0P0580K`1]0640KP00000?Q0h0003X>0D006J9AOCYC`40
0:74oZX10DG`IP000000j@@0001VodGh3kl5^?jZ0@noCOPk`@n>9@4003?0<lUVR`fRoZX1:l7gf2U5
l:6ToZX1D3?0IZ6b0j/1D6X1J5S_ZP7XV;;noh?44:=hkZX1PcehkZX100n?2`0006K7AO@80>WH0000
<l1VXK83Z`5@J5S_ZP6;AO1@j=D00023a0b3?IP7Z`403hB/0000XIP7Z`63N0`03hBM0000XJCnZP5@
j;Nco_n3a0B9ANbQV0N[0FJ;P9P0000U000000000000000000000000000000000@410@410@410OnZ
9@0000`000040000E00005@0003L0000MP000>L0002@00000@00002P34;]>0a2Y00005P000010000
C0000000000000000000000000000000D00006@00>T900009@0000`000020000:00000`000040000
DP0004`100040000k_ooo`000000000000000;`2000100000000<U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^0000XgS^ZP63?GS^ZP403h@;040@Rdd8:d48@6JSa>VZ00000:X1D6X1JP9Xa>VZ0NS]
d_ooPl@@Xn3WZP63?N3WZP403hl>0000I/L5k>NZ0@d0jM@2002;A@R;@0aVXlCYZP6Qf?jZ0E1Z0FX2
J<CYZP7XZ];ooh?44:?PijX1PcgPijX100n?3P0006K71NcWZP4=0>VA0P00RdD8Rd08IP00jJX1XMSn
ZP5@JP5Z0VS4jJX1j6OBoon3a12Sh>NZ0H<mh>NZ0@0?S`h0001Va`G/ijX13@3YCP800:7HijX00000
00000000000000000000000000010@410@410@41oolU0000300000@0001D0000E0000>P0001f0000
l0000940000100000:0<@^dh34:]0000F0000040001<0000000000000000000000000000001@0000
L`3oo`L0000U000030000080000X0000300000@0001B0000C04000@0003^oooo0000000000000000
T04000400000000bE01Y06d0I@1c0200CP1U07L0801B06l0K@1Q06h0001f0@23a0AVXncWZP7YE@40
0:74oZX1RDGhPggh00l0000000no1OSYZP6;COPk`@n20P0008_1IZ?hjJX1XF0]Z`5@3kl5n>VZ0E1Z
0H]5m53X9/oooh?448U5i8=mi00?Q`h0001Va`G/ijX1203YlP000:7HoZX1D8]5i51Z0H]5m53Xdm3o
oh?448U5h8=mh00?Q`h0001Va`G/ijX1003Y_`0003?03kl=n>VZ0B_1mmPYAOSYGOooonTe0000XMSn
ZP5@XLCnZP5@JP6;ANa@j8C@oon3a129AOR3O@00000000000000000000000000000000410@410@41
0@7o02D0000<0000100005@0001D00003`000500000J0000JP0000400000X0a2kCP<@PX0000k0000
0@0004`000000000000000000000000000000500001T00002@0002D0000<00000P0002P0000<0000
10000580001<0@0010000>koool0000000000000002l0P000@000000039D06T0K@1U07<0801>06D0
M`0P0580K`1]0640KP000000J23YZP7XG;4108?418]528=h;P0?Q1T0002;A@00001@j2Jc0@23a0B;
A@S7@2h00000IZ7/ijX1j@00001OGU_9`lc<c5F;k5=FEfK71NcWZP4006J;A@QVXj3XZP5Va`D0jJX1
105VX@3YZP5@j9;Ooon3a0BS=>RZ0J7HoZX1D6X1JPAX=>RZ0NP6coooPl@@Xn3WZP63?N3WZP4008l>
0000I/L5k>NZ0@d0jFh0002Qf?jZ0E1Z0FX2J03YZP7Xclkooh?44:?PijX1PcgPijX100n?3P0006K7
000000000000000000000000000000000@410@410@410A2S9@0000`000040000E00005@0000K0000
D0000240001[00000@00002P34;]>0a24`0003/000010000C0000000000000000000000000000000
D00007@0RdD500009@0000`000010000:00000`0000300009P0001`0000300001@00000000000000
oooo0RD0000<00000`0005H0000`0000504002X0000P0@00=00000D0003G01l0dP0V0=<08@3>01l0
e`0O02D0000<00000@0002P0000<00000`0002H0000L00000`000000000100000@000000008U0000
300000<0001G0000<00001@1000Z0000804003@000050000e`0O0=809P3C0240cP0O0=L07`1G0000
90000>@0000]00006`4004d000020000ZP0i0=<08@0U000030000040000X0000300000<0000V0000
700000<00005000000000000003oool29@0000`0000300009`0001P00005000000000??cl`000000
9@0000`000050000:P0001P0001/0000D@0007H0001F00009@0000`000010000:00000`000030000
9@0000`000000020:00000`0000500009P0001`000050000000000400001000000000RD0000<0000
1@0002L0000H00000`00004000000000000002D0000<00000`0002X0000H0000K0000540001f0000
EP0002D0000<00000@0002P0000<00001@0002D0000<00000000P2P0000<00000`0002H0000L0000
0`0000D00000000000000?ooo`8U0000300000<0000W0000600000D000000000lo?c0000000U0000
300000D0000Z0000600002d0001D0000>P000600000U000030000040000X0000300000<0000U0000
30000000080X0000300000D0000V0000700000D0000000000@000040000000029@0000`000050000
9`0001P0000300000@000000000000009@0000`000030000:P0001P0000]0000E00003X0001P0000
9@0000`000010000:00000`0000500009@0000`000000020:00000`0000300009P0001`000030000
1@00000000000000oooo0RD0000<00000`0002L0000H00001@000000003clo<0000002D0000<0000
1@0005H0002X0000@@0004d0001A0000HP0002<0000l04T0>`1903X0B@0i04T0>01803L0B00f04L0
=@1603@0A@0c04<0<P120340@00a03l0<00n0300?@0`03`0<00k0300>P0a03T0<P0i03<0>P0d03X0
=@0k03H0?00g03d0>00n03T0?`0j0440>`1203/0@`0l04D0?01603`0A`0l04P0?01902D0000<0000
0@0002P0000<00000`0002H0000L00000`000000000100000@000000008U0000300000<0001G0000
Z0000440001=0000D@000680000S0000?01903/0B@0j04T0>@1903P0B00g04P0=P1703D0AP0d04D0
<`130380@P0a0400<@0o0300?P0`03d0<00l0300>`0`03X0<@0i0380>@0c03X0=00j03D0>`0f03`0
=`0m03P0?P0i03l0>P1103/0@P0k04<0?01503`0AP0l04L0?01803`0B@0U000030000040000X0000
300000<0000V0000700000<00005000000000000003oool29@0000`000030000EP000:P0001M0000
HP0006/0001c00008`0004l0D@1>0580C@1C04d0E01<05D0B`1F04X0EP1905H0B01F04L0EP1605D0
AP1D04D0E01505<0A@1B04D0D01504l0AP1>04H0C@1704`0A`1;04P0BP1904X0BP1904/0B@1<04T0
C@1:04h0BP1>04/0C`1<04l0C@1?04h0C`1?04l0D01?05409@0000`000010000:00000`000030000
9P0001`000030000000000400001000000000RD0000<00000`0005L0002X0000G@000680001[0000
L`0002<0001?0540CP1B04d0D`1=05@0C01E04/0EP1:05H0B@1F04P0EP1705H0AP1E04H0E01505@0
A@1C04D0DP150500A@1?04H0CP1604d0A`1<04L0B`1804X0B@1:04X0B@1;04T0C01904d0BP1>04X0
CP1;04l0C01?04d0C`1>04l0C`1?0500C`1A02D0000<00000@0002P0000<00000`0002H0000L0000
0`0000D00000000000000?ooo`8U0000300000<0000Z0000600006/0000f0000L`0003/0000U0000
30000040000X0000300000<0000U000030000000080X0000300000D0000V0000700000D000000000
0@000040000000029@0000`0000500009`0001P0000300000@000000000000009@0000`000030000
:P0001P0001[0000=P0007<0000k00009@0000`000010000:00000`0000500009@0000`000000020
:00000`0000300009P0001`0000300001@00000000000000oooo0RD0000<00000`0002L0000H0000
1@000000003clo<0000002D0000<00001@0005H0002T0000M`0004P000240000F0000280001Q03T0
H@0j0680>`1R03`0HP0m0680?P1R03l0H@100600@@1O0440GP1105d0@@1L0400F`1005X0?`1J03h0
F@0m05P0?01H03/0F00j05P0>@1H03P0F00g05T0=P1I03D0FP0e05/0=@1L03D0G@0e05h0=@1O03H0
H00g0600>01Q03T09@0000`000010000:00000`0000300009P0001`0000300000000004000010000
00000RD0000<00000`0005L0002T0000M`0004P000240000F0000280001Q03T0H@0j0680>`1R03`0
HP0m0680?P1R03l0H@100600@@1O0440GP1105d0@@1L0400F`1005X0?`1J03h0F@0m05P0?01H03/0
F00j05P0>@1H03P0F00g05T0=P1I03D0FP0e05/0=@1L03D0G@0e05h0=@1O03H0H00g0600>01Q03T0
9@0000`000010000:00000`0000300009P0001`0000300001@00000000000000oooo0RD0000<0000
0`0005H0002H0000L00007D000210000O`0001l0001P05P0H01I0600FP1O05X0GP1K05h0G01M05`0
G01M05X0G@1I05h0F01N05L0G`1F05l0E@1O05@0G`1C05l0D`1N05<0G@1C05`0E01K05D0FP1F05X0
E`1I05P0F01I05P0FP1H05`0E`1M05L0GP1G05l0E`1P05P09@0000`000010000:00000`000030000
9P0001`000030000000000400001000000000RD0000<00000`0005L0002H0000L00007D000210000
O`0001l0001P05P0H01I0600FP1O05X0GP1K05h0G01M05`0G01M05X0G@1I05h0F01N05L0G`1F05l0
E@1O05@0G`1C05l0D`1N05<0G@1C05`0E01K05D0FP1F05X0E`1I05P0F01I05P0FP1H05`0E`1M05L0
GP1G05l0E`1P05P09@0000`000010000:00000`0000300009P0001`0000300001@00000000000000
oooo0RD0000<00000`0005H0002`0000Y@000580002d0000K@0002D0002604H0QP1808H0B@2604/0
QP1=08H0CP2504l0Q@1@08@0D@230540PP1A0840D@200500O`1@07h0C`1n04d0O@1<07`0BP1l04P0
N`1607/0A@1k04<0N`1107`0@01l03l0O@0n07d0?@1n03d0O`0m0800?@2103h0PP0n08<0?`240440
Q@1208D0A02604H09@0000`000010000:00000`0000300009P0001`0000300000000004000010000
00000RD0000<00000`0005L0002`0000Y@000580002d0000K@0002D0002604H0QP1808H0B@2604/0
QP1=08H0CP2504l0Q@1@08@0D@230540PP1A0840D@200500O`1@07h0C`1n04d0O@1<07`0BP1l04P0
N`1607/0A@1k04<0N`1107`0@01l03l0O@0n07d0?@1n03d0O`0m0800?@2103h0PP0n08<0?`240440
Q@1208D0A02604H09@0000`000010000:00000`0000300009@0000`000000020:00000`000050000
9P0001`0000500001@00000000000000oooo0RD0000<00001@0002L0000H00000`000000003Vi^H0
000002D0000<00000`0002X0000H0000]00001/0002h0000800002D0000<00000@0002P0000<0000
1@0002D0000<00000000P2P0000<00000`0002H0000L00000`000000000100000@000000008U0000
300000<0000W0000600000D00001000000000000000U0000300000D0000Z000060000;@0000K0000
^0000200000U000030000040000X0000300000<0000U000030000000080X0000300000D0000V0000
700000D00005000000000000003oool29@0000`0000500009`0001P00003000000000>KViP000000
9@0000`000030000EP000:@0003H0000;P000>@0001100008P000:T0:02Z02T0ZP0Z0:X0:`2Z02`0
ZP0]0:X0;P2Y02l0Z00`0:L0<02V02l0Y@0_0:@0;P2T02d0X`0]0:80:`2R02X0X@0Y0:40:02Q02L0
X@0V0:409@2R02@0XP0S0:808P2S0280Y00R0:D08P2V02<0Y`0S0:P0902X02D0Z@0V0:T0:00U0000
30000040000X0000300000D0000V0000700000D0000000000@000040000000029@0000`000050000
E`000:@0003H0000;P000>@0001100008P000:T0:02Z02T0ZP0Z0:X0:`2Z02`0ZP0]0:X0;P2Y02l0
Z00`0:L0<02V02l0Y@0_0:@0;P2T02d0X`0]0:80:`2R02X0X@0Y0:40:02Q02L0X@0V0:409@2R02@0
XP0S0:808P2S0280Y00R0:D08P2V02<0Y`0S0:P0902X02D0Z@0V0:T0:00U000030000040000X0000
300000D0000V0000700000D00005000000000000003oool29@0000`000050000EP00080000380000
DP000=D0001J00006@0009h0@`2M04<0W01309/0@`2J04<0V@1209P0@P2G0440UP1009D0?`2E03h0
U@0m09H0?@2G03d0V00m09T0?@2J03h0V`0n09/0?`2L03l0W@1009h0@@2N0480W`1209h0@`0U0000
30000040000X0000300000D0000V0000700000D0000000000@000040000000029@0000`000050000
E`00080000380000DP000=D0001J00006@0009h0@`2M04<0W01309/0@`2J04<0V@1209P0@P2G0440
UP1009D0?`2E03h0U@0m09H0?@2G03d0V00m09T0?@2J03h0V`0n09/0?`2L03l0W@1009h0@@2N0480
W`1209h0@`0U000030000040000X0000300000D0000V0000700000D00005000000000000003oool2
9@0000`000050000:P0001P0002]0000?P000;P0001700009@0000`000010000:00000`000050000
9@0000`000000020:00000`0000300009P0001`000030000000000400001000000000RD0000<0000
0`0002L0000H00001@00004000000000000002D0000<00001@0002X0000H0000[@0003h0002h0000
A`0002D0000<00000@0002P0000<00000`0002D0000<00000000P2P0000<00001@0002H0000L0000
1@0000D00000000000000?ooo`8U0000300000D0000W0000600000<000000000i^KV0000000U0000
300000<0001F0000Y0000</0001Z0000e`0007/0000R0000WP1G09h0F02M05T0W@1J09`0F`2K05/0
VP1L09T0G02H05`0V01K09L0F`2G05X0U`1I09L0F02G05L0U`1F09L0E@2H05@0V01C09T0DP2J0540
VP1@09/0D02L04l0W@1?09h0C`2O0500W`1A0:00DP2P05<0X01D09l0E@2O05H0WP1G02D0000<0000
0@0002P0000<00001@0002H0000L00001@000000000100000@000000008U0000300000D0001G0000
Y0000</0001Z0000e`0007/0000R0000WP1G09h0F02M05T0W@1J09`0F`2K05/0VP1L09T0G02H05`0
V01K09L0F`2G05X0U`1I09L0F02G05L0U`1F09L0E@2H05@0V01C09T0DP2J0540VP1@09/0D02L04l0
W@1?09h0C`2O0500W`1A0:00DP2P05<0X01D09l0E@2O05H0WP1G02D0000<00000@0002P0000<0000
1@0002D0000<00000000P2P0000<00000`0002H0000L00000`0000D00000000000000?ooo`8U0000
300000<0000W0000600000D000000000/k>c0000000U0000300000D0001F0000U00006/0000I0000
O0000200000N0000G00D05`05@1K01D0F`0F05X05P1I01L0F00G05L05`1F01L0E00G05<05`1B01L0
D@0G05005`1?01H0C`0E04l0501@01@0D@0C05804`1C01<0E00B05D04P1F0180E`0B05P04P1I0180
FP0C05/04`1L01@09@0000`000010000:00000`0000300009P0001`0000300000000004000010000
00000RD0000<00000`0005L0002D0000J`0001T0001l0000800001h0001L01@0G00E05/05@1K01H0
FP0F05T05`1H01L0E`0G05H05`1D01L0D`0G05805`1A01L0D00G04l05P1?01D0C`0D0500501A01<0
DP0C05<04`1D0180E@0B05H04P1G0180F00B05T04P1J01<0F`0C05`0500U000030000040000X0000
300000<0000V0000700000<00005000000000000003oool29@0000`000030000EP0009`000250000
900009L0000a0000800006l08`1_02@0KP0T06d0901/02<0J`0S06X08`1Y0280J00Q06L0801V0200
I@0O06@07P1S01d0H`0L06<06`1S01X0I00J06D06P1V01X0I`0J06P06P1Y01/0JP0L06/0701/01d0
K@0N06h07`1_0200L00Q07008P1_02<09@0000`000010000:00000`0000300009P0001`000030000
000000400001000000000RD0000<00000`0005L0002L0000Q@0002@0002G0000<@000200001_02<0
K`0T06h0901]02@0K00S06/08`1Z02<0J@0R06P08@1W0200IP0P06D07`1T01h0H`0M06<0701S01/0
H`0J06@06P1U01X0IP0J06L06P1X01X0J@0K06X0701[01`0K00M06d07P1^01l0K`0P07008@1`0280
K`0S02D0000<00000@0002P0000<00000`0002H0000L00000`0000D00000000000000?ooo`8U0000
300000<0001F0000Z0000:T0000G0000^@0002T0000S0000R00D08T05@2901H0RP0G08X06@2:01X0
RP0K08T0702801d0Q`0N08H07P2501h0P`0M08807@2101`0P00K08006P1o01T0OP0H07h05`1n01D0
OP0D07h04`1n0180O`0B08004@200100P@0@088040230100Q00A08D04@260180Q`0C08P0500U0000
30000040000X0000300000<0000V0000700000<0000000000@000040000000029@0000`000030000
E`000:P0002Y00005`000;T0000Y00008`0008P0502901D0R@0F08X05`2:01T0RP0J08X06`2901`0
R00M08L07P2601h0Q@0N08<07@2201d0P@0L08006`2001X0O`0I07h0601n01L0OP0E07h0501n01<0
OP0B07l04P200140P00@084040220100P`0@08@04@250140QP0B08L04`2801@09@0000`000010000
:00000`0000300009P0001`0000300001@00000000000000oooo0RD0000<00000`0002X0000H0000
=@0002<0001000009`0002D0000<00000@0002P0000<00000`0002D0000<00000000P2P0000<0000
1@0002H0000L00001@000000000100000@000000008U0000300000D0000W0000600000<000010000
00000000000U0000300000<0000Z0000600003D0000S0000@00002L0000U000030000040000X0000
300000D0000U000030000000080X0000300000<0000V0000700000<00005000000000000003oool2
9@0000`0000300009`0001P00005000000000;>c/`0000009@0000`000050000:P0001P0002N0000
4@000:L0000H00009@0000`000010000:00000`0000300009@0000`000000020:00000`000050000
9P0001`000050000000000400001000000000RD0000<00001@0002L0000H00000`00004000000000
000002D0000<00000`0002X0000H0000WP000140002W0000600002D0000<00000@0002P0000<0000
1@0002D0000<00000000P2P0000<00000`0002H0000L00000`0000D00000000000000?ooo`8U0000
300000<0000U0000300000@0081F0000<0000>l0001U0000o@00074000050000_@1;0;L0E02g04l0
/P1=0;d0B`0U000030000040000X0000300000<0000V0000700000<0000000000@00004000000002
9@0000`000030000E`000300003_0000I@000?d0001a00001@000;d0B`2g05@0]`1?0;80C@2m04/0
9@0000`000010000:00000`0000300009P0001`000030000000000800002000000000RD0000<0000
0`0005L0000T0000`00006T0003f0000SP000080002@06T0]`1?024000080000<@00010400050000
00<00Oooo`00040000200000o`0080000210000PP0008?l004000010@000@800043o001P0000H400
0620001Po`00P00008100020P000P?l00:00002P@000X8000:3o00300000`4000<200030o`00o`00
0?m0003oP000ool080000200@00P0800803o020P000P84008220020Po`0P@00084100210P00P@?l0
8600021P@00PH800863o0220000PP40088200220o`0PX0008:10022PP00PX?l08<000230@00P`800
8<3o023o000Pod008?n0023oo`100000@0100400P0100?l0@200040P@0108800@23o04100010@400
@4200410o`10H000@610041PP010H?l0@8000420@010P800@83o042P0010X400@:20042Po`10`000
@<100430P010`?l0@?l0043o@010oh00@?oo0600001P0400H0200600o`1P8000H210060PP01P8?l0
H4000610@01P@800H43o061P001PH400H620061Po`1PP000H8100620P01PP?l0H:00062P@01PX800
H:3o0630001P`400H<200630o`1Po`00H?m0063oP01Pool0P0000800@0200800P03o080P00208400
P220080Po`20@000P4100810P020@?l0P600081P@020H800P63o08200020P400P8200820o`20X000
P:10082PP020X?l0P<000830@020`800P<3o083o0020od00P?n0083oo`2P0000X0100:00P02P0?l0
X2000:0P@02P8800X23o0:10002P@400X4200:10o`2PH000X6100:1PP02PH?l0X8000:20@02PP800
X83o0:2P002PX400X:200:2Po`2P`000X<100:30P02P`?l0X?l00:3o@02Poh00X?oo0<0000300400
`0200<00o`308000`2100<0PP0308?l0`4000<10@030@800`43o0<1P0030H400`6200<1Po`30P000
`8100<20P030P?l0`:000<2P@030X800`:3o0<300030`400`<200<30o`30o`00`?m00<3oP030ool0
o`000?l0@03o0800o`3o0?lP003o8400ob200?lPo`3o@000od100?m0P03o@?l0of000?mP@03oH800
of3o0?n0003oP400oh200?n0o`3oX000oj100?nPP03oX?l0ol000?o0@03o`800ol3o0?oo003ood00
oon00000000`0000300000D0000d0000200001D0000<00000`000540000<30007@400540001c0@00
J0000=D0000l000000000000001B000050000500000/1@00O0D0090600000000803<0440000B0000
:0000580000D00000@080000002@1P00000000000000000000000?ooo`100000P0000?l000008000
@200080P003o8000040004100020@000od00001P0010H000P6000?mP0000P000@8000820003oP000
0:00042P0020X000oj0000300010`000P<000?o00000o`00@?l0083o003oo`00000P040080200200
o`0P000P80108200P20P0?lP8000@200@40P0810803o@200060P041P8020H200of0P00208010P200
P80P0?n08000X200@:0P082P803oX2000<0P04308020`200ol0P003o8010ob00P?lP0?oo80000400
@0100800@03o04000210040P@0208400ob100010@010@400P4100?m0@000H400@610081P@03oH400
08100420@020P400oh10002P@010X400P:100?nP@000`400@<100830@03o`4000?m0043o@020od00
oom00000H0100600P01P0?l0H0008600@21P080PH03o8600041P0410H020@600od1P001PH010H600
P61P0?mPH000P600@81P0820H03oP6000:1P042PH020X600oj1P0030H010`600P<1P0?o0H000of00
@?mP083oH03oof0000200400P0200800o`20000PP0108800P2200?lPP000@800@4200810P03o@800
0620041PP020H800of200020P010P800P8200?n0P000X800@:20082PP03oX8000<200430P020`800
ol20003oP010oh00P?n00?ooP0000:00@02P0800X03o0:00022P040PX0208:00ob2P0010X010@:00
P42P0?m0X000H:00@62P081PX03oH:00082P0420X020P:00oh2P002PX010X:00P:2P0?nPX000`:00
@<2P0830X03o`:000?nP043oX020oj00oonP0000`0100<00P0300?l0`0008<00@230080P`03o8<00
04300410`020@<00od30001P`010H<00P6300?mP`000P<00@8300820`03oP<000:30042P`020X<00
oj300030`010`<00P<300?o0`000ol00@?o0083o`03ool00003o0400o`200?l0o`3o000Po`108?l0
P23o0?lPo`00@?l0@43o0810o`3o@?l0063o041Po`20H?l0of3o0020o`10P?l0P83o0?n0o`00X?l0
@:3o082Po`3oX?l00<3o0430o`20`?l0ol3o003oo`10ool0P?oo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000ooooool0
000000000000000000000000000000000000000000000000000000000>3Ph>3Ph000000000000000
0000000000000000000000000?oo0000000000000000003o00000000000000000000000000000000
000000000000h>0000000000000000000000000000000000000000000?oo0000000000000000003o
00000000000000000000000000000000000000000000h>0000000000000000000000000000000000
000000000?oo0?ooo`00000000000?oooooo000000000000oooo0?ooo`3ooooo003ooooo00000>3P
00000000003oooooool0000000000000000000000?ooo`00ool000000000ool0o`3oo`000000003o
o`00oooo0000ool00000ool0003Ph>3P000000000?oo0000000000000000000000000000003oo`00
0?oo00000000ool0o`00ool000000?oo00000?oo0000ool00000ool00000000000000000oooo0000
000000000000000000000000003oo`000?oo00000000ool0o`00ool000000?oo00000?oo00000?oo
ooooo`0000000>3P00000000ooooooooool000000000000000000000003oo`000?oo00000000ool0
0?l0ool000000?oo00000?oo00000?oo003oo`000000000000000000oooo0000ool0000000000000
00000000003oool00?oo000000000?oo0?l0ool00000003oo`00oooo00000?oo003oo`0000000000
000000000?oo0000ool0000000000000000000000?ooo`3oool000000000003oooooo`0000000000
oooo0?oo0000003o003o00000000000000000000003oooooo`000000000000000000000000000000
00000000000000000?l000000000000000000?oo0000003ooooo0000000000000000000000000000
0000003Ph>3Ph>0000000000000000000000000000000000003o00000000000000000?oo0000oooo
oooo0000000000000000000000000000000000000>3P000000000000000000000000000000000000
003o0000000000000000oooo0000000000000000000000000000000000000000000000000>3P0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003Ph000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000h>3Ph0000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003Ph00000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000280000<0000ooooobP0000<00001@0002D0000<00000@0002P0000<00000`0002H0000L0000
0`0000D00000000000000?ooo`8U0000300000<0001F0000<0000?40001H0000o`00068000050000
]0140;h0@@2k04D0_P190;@0A00U000030000040000X0000300000<0000V0000700000<000000000
0@000040000000029@0000`000030000E`000300003a0000F0000?l0001R00001@000;@0A02n0440
^`150;h0B@2d04@09@0000`000010000:00000`0000300009P0001`0000300001@00000000000000
oooo0RD0000<00000`0005H0000`00004`4005h0000M0@00G`0000D0003E04H0c`160<d0A`3C04L0
e@1605H0000`00001@4005d0000@0@00G`0000D0003;04H0a@150<<0AP3904L0b`1605H0000`0000
n@0005d000030@00GP0000D0003104D0_0150;X0AP2o04H0`@150280000<0000ooooobP0000<0000
0`0002P0000<0000100002P0000<00000@0002P0000<00000P0004/0000@0000000000D0000>0000
50@00001000@0000oooo0000@0000800003o000P000084000220000Po`00@00004100010P000@?l0
0600001P@000H800063o00200000P40008200020o`00X0000:10002PP000X?l00<000030@000`800
0<3o003o0000od000?n0003oo`0P000080100200P00P0?l08200020P@00P8800823o0210000P@400
84200210o`0PH0008610021PP00PH?l088000220@00PP800883o022P000PX4008:20022Po`0P`000
8<100230P00P`?l08?l0023o@00Poh008?oo040000100400@0200400o`108000@210040PP0108?l0
@4000410@010@800@43o041P0010H400@620041Po`10P000@8100420P010P?l0@:00042P@010X800
@:3o04300010`400@<200430o`10o`00@?m0043oP010ool0H0000600@01P0800H03o060P001P8400
H220060Po`1P@000H4100610P01P@?l0H600061P@01PH800H63o0620001PP400H8200620o`1PX000
H:10062PP01PX?l0H<000630@01P`800H<3o063o001Pod00H?n0063oo`200000P0100800P0200?l0
P200080P@0208800P23o08100020@400P4200810o`20H000P610081PP020H?l0P8000820@020P800
P83o082P0020X400P:20082Po`20`000P<100830P020`?l0P?l0083o@020oh00P?oo0:00002P0400
X0200:00o`2P8000X2100:0PP02P8?l0X4000:10@02P@800X43o0:1P002PH400X6200:1Po`2PP000
X8100:20P02PP?l0X:000:2P@02PX800X:3o0:30002P`400X<200:30o`2Po`00X?m00:3oP02Pool0
`0000<00@0300800`03o0<0P00308400`2200<0Po`30@000`4100<10P030@?l0`6000<1P@030H800
`63o0<200030P400`8200<20o`30X000`:100<2PP030X?l0`<000<30@030`800`<3o0<3o0030od00
`?n00<3oo`3o0000o`100?l0P03o0?l0ob000?lP@03o8800ob3o0?m0003o@400od200?m0o`3oH000
of100?mPP03oH?l0oh000?n0@03oP800oh3o0?nP003oX400oj200?nPo`3o`000ol100?o0P03o`?l0
ool00?oo@03ooh00000001@4
\>"], "Graphics",
  Editable->False,
  ImageSize->{356, 155},
  ImageMargins->{{324, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "The volume in the above figure is supposed infinitesimal, but its \
dimension must be much larger than the size of the pores. This allows, far \
from the critical porosity, to make an effective field approximation. The \
surface of pores in the section {",
  StyleBox["d\[DoubleStruckS], d\[DoubleStruckT]",
    FontWeight->"Bold"],
  "} is  \[Phi] \[VerticalSeparator]\[VerticalSeparator] ",
  StyleBox["d\[DoubleStruckS]",
    FontWeight->"Bold"],
  "\[Cross]",
  StyleBox["d\[DoubleStruckT] ",
    FontWeight->"Bold"],
  "\[VerticalSeparator]\[VerticalSeparator]. From equation (4.1), the force \
due to the the stress acting on the cross section {",
  StyleBox["d\[DoubleStruckS], d\[DoubleStruckT]",
    FontWeight->"Bold"],
  "} is,"
}], "Text"],

Cell[BoxData[
    \(\[Sigma]uu[red@l, red@m] dAd[red@l] \[DoubleStruckE]d[red@m]\)], "Input"],

Cell[TextData[{
  "the force due to the fluid pressure and acting on the cross section ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["dA", 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False], 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False]],
              Subsuperscript[ dA, 
                SequenceForm[ 
                  red[ i]], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]]],
              Editable->False],
            "TraditionalForm"], " ", 
          FormBox[
            InterpretationBox[
              SubsuperscriptBox["\[DoubleStruckE]", 
                InterpretationBox[
                  TagBox[
                    StyleBox[
                      FormBox[
                        TagBox[
                          StyleBox["i",
                            FontColor->RGBColor[1, 0, 0]],
                          (
                          StyleForm[ #, FontColor -> RGBColor[ 
                            1.0, 0.0, 0.0]]&)],
                        "TraditionalForm"],
                      ShowContents->False],
                    (StyleForm[ #, ShowContents -> False]&)],
                  SequenceForm[ 
                    StyleForm[ 
                      red[ i], ShowContents -> False]],
                  Editable->False], 
                InterpretationBox[
                  FormBox[
                    TagBox[
                      StyleBox["i",
                        FontColor->RGBColor[1, 0, 0]],
                      (
                      StyleForm[ #, FontColor -> RGBColor[ 1.0, 0.0, 0.0]]&)],
                    
                    "TraditionalForm"],
                  SequenceForm[ 
                    red[ i]],
                  Editable->False]],
              Subsuperscript[ \[DoubleStruckE], 
                SequenceForm[ 
                  StyleForm[ 
                    red[ i], ShowContents -> False]], 
                SequenceForm[ 
                  red[ i]]],
              Editable->False],
            "TraditionalForm"]}], TraditionalForm]]],
  " is,"
}], "Text"],

Cell[BoxData[
    \(p\ \[Phi]\ dAd[red@i] \[DoubleStruckE]u[red@i]\)], "Input"],

Cell[TextData[{
  "so that the total force acting on the face {",
  StyleBox["d\[DoubleStruckS], d\[DoubleStruckT]",
    FontWeight->"Bold"],
  "} is,"
}], "Text"],

Cell[BoxData[
    \(d\[DoubleStruckCapitalF] \[Equal] \((\[Sigma]uu[red@j, red@i] 
              dAd[red@j] \[DoubleStruckE]d[red@i] - 
            Tensor[p\ \[Phi]\ , {}, {}] dAd[red@j] 
              guu[red@j, red@i] \[DoubleStruckE]d[red@i] // 
          Factor)\)\)], "Input"],

Cell["Comparing with equation (6.4) allows to write,", "Text"],

Cell[BoxData[{
    \(\((TotalForce // TensorNesting[\[Sigma]])\) /. \[Sigma]uu[red@j, 
          red@i] \[Rule] \((\[Sigma]\[Section]ji = %[\([2, 3]\)])\) \[Equal] 
          0\), "\[IndentingNewLine]", 
    \(\((\(%[\([1]\)] + CovariantD[\[Sigma]\[Section]ji, red@j] // 
            CovariantDSimplify[\[DoubleStruckE], g]\) // 
          MetricSimplify[g])\) \[Equal] 0\)}], "Input"],

Cell[BoxData[
    \(ResultFrame[
      CovariantD[\[Sigma]uu[red@j, red@i], 
          red@j] \[Equal] \((CovariantD[\[Sigma]uu[red@j, red@i], 
              red@j] /. \(Solve[%, 
                CovariantD[\[Sigma]uu[red@j, red@i], 
                  red@j]]\)[\([1]\)])\)]\)], "Input"],

Cell[TextData[{
  "Note this equation shows that a constant pressure produces a stress if the \
porosity ",
  StyleBox["\[Phi]",
    FontWeight->"Bold"],
  " is variable. \nTo study a stress problem in presence of seepage flow, we \
have to consider the three equations, (4.11), (6.2), and (6.36)."
}], "Text"],

Cell[BoxData[
    \(\(DefineTensorShortcuts[{{\[DoubleStruckE], x, y, u, 
            v, \[Omega], \[ScriptCapitalE], dr, ds, dt, dA, X, a, A, 
            f, \[CapitalPhi], \[CapitalOmega], p, n}, 
          1}, {{g, \[ScriptCapitalE], \[Gamma], \[Sigma], \[Delta], u, v, s, 
            e, \[CapitalPhi], k}, 2}, {{e, \[Sigma], \[Epsilon], u, v}, 
          3}, {{\[DoubleStruckCapitalE]}, 4}];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"], None, Cell[ 
      "J.-F. Gouyet", "Header"]}, {
    Cell[ "Continuum Mechanics", "Header"], None, Cell[ 
        TextData[ 
          CounterBox[ "Page"]], "Header"]}},
PageFooters->{{None, None, None}, {None, None, None}},
PageHeaderLines->{True, True},
PageFooterLines->{False, False},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintSelectionHighlighting"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FirstPageFooter"->True,
"RestPagesHeader"->True,
"RestPagesFooter"->True,
"FacingPages"->True,
"FirstPageFace"->Right,
"GraphicsPrintingFormat"->"Automatic",
"IncludeSpecialFonts"->True,
"IncludePostScriptResourceDirectives"->True,
"PostScriptOutputFile":>"Automatic",
"UsePostScriptOutputFile"->False,
"UnixShellPrintingCommand"->Automatic,
"UseUnixShellPrintingCommand"->False,
"Magnification"->1,
"CellBackgroundHalftoneDensity"->Automatic,
"CellBackgroundHalftoneAngle"->Automatic},
ShowCellLabel->False,
CellLabelAutoDelete->True,
InputAliases->{"note"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "note<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnote"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwrap"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswrap"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
Magnification->1,
StyleDefinitions -> "TensorialStyle.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Kinematic Relations"->{
    Cell[5303, 156, 73, 1, 41, "Section",
      CellTags->"Kinematic Relations"]},
  "Condition of Equilibrium and Equation of Motion"->{
    Cell[28347, 695, 129, 1, 41, "Section",
      CellTags->"Condition of Equilibrium and Equation of Motion"]},
  "Fundamental Equations"->{
    Cell[146892, 2408, 105, 1, 41, "Section",
      CellTags->"Fundamental Equations"]},
  "Flow of Viscous Fluid"->{
    Cell[244542, 4773, 78, 1, 41, "Section",
      CellTags->"Flow of Viscous Fluid"]},
  "Navier-Stokes"->{
    Cell[296892, 6128, 77, 1, 49, "Subsection",
      CellTags->"Navier-Stokes"]},
  "Seepage Flow"->{
    Cell[356367, 7708, 59, 1, 41, "Section",
      CellTags->"Seepage Flow"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Kinematic Relations", 510833, 10076},
  {"Condition of Equilibrium and Equation of Motion", 510971, 10079},
  {"Fundamental Equations", 511113, 10082},
  {"Flow of Viscous Fluid", 511231, 10085},
  {"Navier-Stokes", 511340, 10088},
  {"Seepage Flow", 511443, 10091}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 77, 3, 131, "Title"],

Cell[CellGroupData[{
Cell[1878, 60, 64, 1, 49, "Subsection",
  InitializationCell->True],
Cell[1945, 63, 448, 10, 146, "Input",
  InitializationCell->True],
Cell[2396, 75, 498, 9, 166, "Input",
  InitializationCell->True],
Cell[2897, 86, 439, 7, 66, "Input",
  InitializationCell->True],
Cell[3339, 95, 93, 2, 34, "Text"],
Cell[3435, 99, 1069, 29, 159, "Input",
  InitializationCell->True],
Cell[4507, 130, 61, 1, 46, "Input"],
Cell[4571, 133, 287, 5, 86, "Input"],
Cell[4861, 140, 69, 1, 34, "Text",
  InitializationCell->True],
Cell[4933, 143, 211, 4, 46, "Input",
  InitializationCell->True],
Cell[5147, 149, 119, 2, 46, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5303, 156, 73, 1, 41, "Section",
  CellTags->"Kinematic Relations"],
Cell[5379, 159, 503, 9, 75, "Text"],
Cell[5885, 170, 334, 6, 142, "Input"],
Cell[6222, 178, 88, 2, 34, "Text"],
Cell[6313, 182, 323, 5, 102, "Input"],
Cell[6639, 189, 9652, 195, 56, "Text"],
Cell[16294, 386, 107, 2, 58, "Input"],
Cell[16404, 390, 42, 0, 34, "Text"],
Cell[16449, 392, 199, 3, 58, "Input"],
Cell[16651, 397, 31, 0, 34, "Text"],
Cell[16685, 399, 205, 3, 102, "Input"],
Cell[16893, 404, 41, 0, 34, "Text"],
Cell[16937, 406, 237, 4, 66, "Input"],
Cell[17177, 412, 1168, 32, 34, "Text"],

Cell[CellGroupData[{
Cell[18370, 448, 46, 0, 49, "Subsection"],
Cell[18419, 450, 5961, 161, 35, "Text"],
Cell[24383, 613, 762, 12, 181, "Input"],
Cell[25148, 627, 209, 6, 35, "Text"],
Cell[25360, 635, 1087, 19, 286, "Input"],
Cell[26450, 656, 218, 4, 34, "Text"],
Cell[26671, 662, 696, 10, 113, "Input"],
Cell[27370, 674, 61, 0, 34, "Text"],
Cell[27434, 676, 864, 13, 134, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[28347, 695, 129, 1, 41, "Section",
  CellTags->"Condition of Equilibrium and Equation of Motion"],

Cell[CellGroupData[{
Cell[28501, 700, 5526, 87, 126, 5413, 83, "GraphicsData", "PICT", \
"Graphics"],
Cell[34030, 789, 96726, 1198, 162, 96609, 1194, "GraphicsData", "Metafile", \
"Graphics"]
}, Open  ]],
Cell[130771, 1990, 99, 2, 34, "Text"],
Cell[130873, 1994, 90, 1, 46, "Input"],
Cell[130966, 1997, 1534, 43, 34, "Text"],
Cell[132503, 2042, 558, 10, 66, "Input"],
Cell[133064, 2054, 104, 3, 34, "Text"],
Cell[133171, 2059, 400, 7, 86, "Input"],
Cell[133574, 2068, 113, 3, 34, "Text"],
Cell[133690, 2073, 203, 4, 66, "Input"],
Cell[133896, 2079, 122, 2, 46, "Input"],
Cell[134021, 2083, 149, 3, 34, "Text"],
Cell[134173, 2088, 192, 4, 46, "Input"],
Cell[134368, 2094, 293, 5, 66, "Input"],
Cell[134664, 2101, 9828, 231, 35, "Text"],
Cell[144495, 2334, 218, 4, 66, "Input"],
Cell[144716, 2340, 71, 0, 34, "Text"],
Cell[144790, 2342, 110, 2, 46, "Input"],
Cell[144903, 2346, 47, 0, 34, "Text"],
Cell[144953, 2348, 93, 1, 46, "Input"],

Cell[CellGroupData[{
Cell[145071, 2353, 137, 2, 36, "Outline1"],
Cell[145211, 2357, 144, 2, 86, "Input"],
Cell[145358, 2361, 167, 3, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145562, 2369, 39, 0, 49, "Subsection"],
Cell[145604, 2371, 405, 8, 54, "Text"],
Cell[146012, 2381, 46, 0, 34, "Text"],
Cell[146061, 2383, 273, 5, 46, "Input"],
Cell[146337, 2390, 197, 3, 46, "Input"],
Cell[146537, 2395, 86, 2, 34, "Text"],
Cell[146626, 2399, 217, 3, 86, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[146892, 2408, 105, 1, 41, "Section",
  CellTags->"Fundamental Equations"],
Cell[147000, 2411, 71141, 1632, 314, "Text"],
Cell[218144, 4045, 179, 6, 35, "Text"],
Cell[218326, 4053, 253, 5, 46, "Input"],
Cell[218582, 4060, 439, 8, 86, "Input"],
Cell[219024, 4070, 160, 4, 34, "Text"],
Cell[219187, 4076, 246, 4, 66, "Input"],
Cell[219436, 4082, 187, 4, 34, "Text"],
Cell[219626, 4088, 173, 3, 86, "Input"],
Cell[219802, 4093, 3073, 78, 37, "Text"],
Cell[222878, 4173, 528, 9, 86, "Input"],
Cell[223409, 4184, 181, 3, 66, "Input"],
Cell[223593, 4189, 340, 5, 86, "Input"],
Cell[223936, 4196, 109, 3, 34, "Text"],
Cell[224048, 4201, 246, 4, 60, "Input"],
Cell[224297, 4207, 144, 2, 86, "Input"],
Cell[224444, 4211, 60, 0, 34, "Text"],
Cell[224507, 4213, 511, 8, 106, "Input"],
Cell[225021, 4223, 114, 3, 34, "Text"],
Cell[225138, 4228, 801, 19, 66, "Input"],
Cell[225942, 4249, 94, 2, 34, "Text"],
Cell[226039, 4253, 283, 5, 66, "Input"],
Cell[226325, 4260, 148, 4, 54, "Text"],
Cell[226476, 4266, 560, 10, 90, "Input"],
Cell[227039, 4278, 264, 9, 34, "Text"],
Cell[227306, 4289, 197, 4, 46, "Input"],
Cell[227506, 4295, 45, 0, 34, "Text"],
Cell[227554, 4297, 241, 4, 66, "Input"],
Cell[227798, 4303, 87, 1, 46, "Input"],
Cell[227888, 4306, 88, 2, 34, "Text"],
Cell[227979, 4310, 304, 6, 66, "Input"],
Cell[228286, 4318, 241, 4, 66, "Input"],
Cell[228530, 4324, 78, 1, 46, "Input"],
Cell[228611, 4327, 133, 5, 34, "Text"],
Cell[228747, 4334, 185, 3, 46, "Input"],
Cell[228935, 4339, 22, 0, 34, "Text"],
Cell[228960, 4341, 65, 1, 69, "Input"],
Cell[229028, 4344, 5972, 161, 78, "Text"],
Cell[235003, 4507, 322, 5, 86, "Input"],
Cell[235328, 4514, 42, 1, 46, "Input"],
Cell[235373, 4517, 375, 7, 86, "Input"],
Cell[235751, 4526, 1523, 43, 34, "Text"],
Cell[237277, 4571, 463, 7, 86, "Input"],
Cell[237743, 4580, 2951, 80, 36, "Text"],
Cell[240697, 4662, 700, 16, 86, "Input"],
Cell[241400, 4680, 2051, 53, 34, "Text"],
Cell[243454, 4735, 90, 1, 46, "Input"],
Cell[243547, 4738, 958, 30, 57, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[244542, 4773, 78, 1, 41, "Section",
  CellTags->"Flow of Viscous Fluid"],
Cell[244623, 4776, 595, 21, 57, "Text"],
Cell[245221, 4799, 191, 4, 46, "Input"],
Cell[245415, 4805, 5748, 150, 54, "Text"],
Cell[251166, 4957, 127, 3, 46, "Input"],
Cell[251296, 4962, 44, 0, 34, "Text"],
Cell[251343, 4964, 148, 3, 66, "Input"],
Cell[251494, 4969, 528, 13, 76, "Text"],
Cell[252025, 4984, 36, 0, 34, "Text"],
Cell[252064, 4986, 265, 5, 86, "Input"],
Cell[252332, 4993, 36, 0, 34, "Text"],
Cell[252371, 4995, 167, 3, 66, "Input"],
Cell[252541, 5000, 49, 0, 34, "Text"],
Cell[252593, 5002, 429, 7, 106, "Input"],
Cell[253025, 5011, 7729, 197, 55, "Text"],

Cell[CellGroupData[{
Cell[260779, 5212, 58, 0, 49, "Subsection"],
Cell[260840, 5214, 2601, 73, 34, "Text"],
Cell[263444, 5289, 523, 11, 106, "Input"],
Cell[263970, 5302, 11939, 255, 37, "Text"],
Cell[275912, 5559, 165, 3, 58, "Input"],
Cell[276080, 5564, 607, 20, 56, "Text"],
Cell[276690, 5586, 163, 3, 46, "Input"],
Cell[276856, 5591, 271, 5, 80, "Input"],
Cell[277130, 5598, 26, 0, 34, "Text"],
Cell[277159, 5600, 182, 4, 46, "Input"],
Cell[277344, 5606, 549, 9, 140, "Input"],
Cell[277896, 5617, 3107, 86, 41, "Text"],
Cell[281006, 5705, 221, 4, 46, "Input"],
Cell[281230, 5711, 4017, 112, 35, "Text"],
Cell[285250, 5825, 649, 16, 74, "Text"],
Cell[285902, 5843, 395, 12, 58, "Input"],
Cell[286300, 5857, 3224, 80, 35, "Text"],
Cell[289527, 5939, 572, 15, 46, "Input"],
Cell[290102, 5956, 24, 0, 34, "Text"],
Cell[290129, 5958, 106, 2, 46, "Input"],
Cell[290238, 5962, 5933, 146, 35, "Text"],
Cell[296174, 6110, 173, 3, 46, "Input"],
Cell[296350, 6115, 505, 8, 106, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[296892, 6128, 77, 1, 49, "Subsection",
  CellTags->"Navier-Stokes"],
Cell[296972, 6131, 3101, 77, 55, "Text"],
Cell[300076, 6210, 496, 8, 106, "Input"],
Cell[300575, 6220, 4518, 125, 35, "Text"],

Cell[CellGroupData[{
Cell[305118, 6349, 36, 0, 43, "Subsubsection"],
Cell[305157, 6351, 2807, 78, 75, "Text"],
Cell[307967, 6431, 679, 17, 126, "Input"],
Cell[308649, 6450, 238, 8, 35, "Text"],
Cell[308890, 6460, 355, 7, 46, "Input"],
Cell[309248, 6469, 114, 5, 34, "Text"],
Cell[309365, 6476, 312, 8, 46, "Input"],
Cell[309680, 6486, 4503, 124, 35, "Text"],
Cell[314186, 6612, 207, 3, 66, "Input"],
Cell[314396, 6617, 9563, 256, 118, "Text"],
Cell[323962, 6875, 220, 5, 34, "Text"],
Cell[324185, 6882, 405, 9, 66, "Input"],
Cell[324593, 6893, 1205, 36, 35, "Text"],
Cell[325801, 6931, 498, 11, 66, "Input"],
Cell[326302, 6944, 117, 3, 34, "Text"],
Cell[326422, 6949, 154, 2, 66, "Input"],
Cell[326579, 6953, 13160, 295, 46, "Text"],
Cell[339742, 7250, 141, 2, 46, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[339920, 7257, 154, 2, 32, "Outline1"],
Cell[340077, 7261, 317, 6, 99, "Input"],
Cell[340397, 7269, 439, 8, 79, "Input"],
Cell[340839, 7279, 108, 3, 34, "Text"],
Cell[340950, 7284, 531, 10, 152, "Input"],
Cell[341484, 7296, 209, 6, 34, "Text"],
Cell[341696, 7304, 134, 2, 47, "Input"],
Cell[341833, 7308, 282, 6, 55, "Text"],
Cell[342118, 7316, 2422, 63, 126, "Input"],
Cell[344543, 7381, 999, 24, 117, "Text"],
Cell[345545, 7407, 200, 3, 66, "Input"],
Cell[345748, 7412, 3145, 81, 35, "Text"],
Cell[348896, 7495, 133, 2, 46, "Input"],
Cell[349032, 7499, 52, 0, 34, "Text"],
Cell[349087, 7501, 350, 5, 68, "Input"],
Cell[349440, 7508, 193, 3, 46, "Input"],
Cell[349636, 7513, 343, 6, 99, "Input"],
Cell[349982, 7521, 459, 14, 76, "Text"],
Cell[350444, 7537, 154, 4, 46, "Input"],
Cell[350601, 7543, 2196, 61, 55, "Text"],
Cell[352800, 7606, 112, 2, 46, "Input"],
Cell[352915, 7610, 3250, 87, 34, "Text"],
Cell[356168, 7699, 138, 2, 60, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[356367, 7708, 59, 1, 41, "Section",
  CellTags->"Seepage Flow"],
Cell[356429, 7711, 11457, 292, 197, "Text"],

Cell[CellGroupData[{
Cell[367911, 8007, 33, 0, 49, "Subsection"],
Cell[367947, 8009, 222, 4, 66, "Input"],
Cell[368172, 8015, 143, 3, 34, "Text"],
Cell[368318, 8020, 269, 5, 86, "Input"],
Cell[368590, 8027, 73, 0, 34, "Text"],
Cell[368666, 8029, 479, 12, 86, "Input"],
Cell[369148, 8043, 63, 0, 34, "Text"],
Cell[369214, 8045, 207, 4, 46, "Input"],
Cell[369424, 8051, 3673, 98, 35, "Text"],
Cell[373100, 8151, 135, 2, 46, "Input"],
Cell[373238, 8155, 196, 8, 35, "Text"],
Cell[373437, 8165, 234, 5, 66, "Input"],
Cell[373674, 8172, 144, 6, 35, "Text"],
Cell[373821, 8180, 65, 1, 46, "Input"],
Cell[373889, 8183, 163, 6, 35, "Text"],
Cell[374055, 8191, 70, 1, 46, "Input"],
Cell[374128, 8194, 2267, 63, 56, "Text"],
Cell[376398, 8259, 84, 1, 46, "Input"],

Cell[CellGroupData[{
Cell[376507, 8264, 100, 2, 43, "Subsubsection"],
Cell[376610, 8268, 124201, 1537, 163, 124088, 1533, "GraphicsData", \
"Metafile", "Graphics"],
Cell[500814, 9807, 770, 18, 76, "Text"],
Cell[501587, 9827, 93, 1, 46, "Input"],
Cell[501683, 9830, 3249, 86, 34, "Text"],
Cell[504935, 9918, 79, 1, 46, "Input"],
Cell[505017, 9921, 163, 5, 35, "Text"],
Cell[505183, 9928, 281, 5, 46, "Input"],
Cell[505467, 9935, 62, 0, 34, "Text"],
Cell[505532, 9937, 385, 6, 66, "Input"],
Cell[505920, 9945, 287, 6, 66, "Input"],
Cell[506210, 9953, 310, 7, 55, "Text"],
Cell[506523, 9962, 411, 6, 66, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

