(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6535,        183]*)
(*NotebookOutlinePosition[      7523,        217]*)
(*  CellTagsIndexPosition[      7449,        211]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["DifToCov", "ObjectName",
  CellTags->"Function?"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"\<\"DifToCov[\\!\\(\\* \
StyleBox[\\\"\[CapitalGamma]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"m\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)][\\!\\(\\* \
StyleBox[\\\"{\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"u\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"i\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"}\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\",\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"j\\\",\\nFontSlant->\\\"Italic\\\"]\\)]\"\>", 
        StyleBox["[",
          "MR"], 
        StyleBox["expr",
          "TI"], 
        StyleBox["]",
          "MR"]}]]],
  "expresses the partial derivative with respect to index j, of a tensor u \
present in expr, into a combination of covariant derivative and components of \
u. The coefficients contain Christoffel symbols \[CapitalGamma] with m as a \
dummy index.  \n\[FilledSmallSquare] ",
  Cell[BoxData[
      RowBox[{"DifToCov", "[", 
        RowBox[{"\<\"\\!\\(\\* \
StyleBox[\\\"\[CapitalGamma]\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"m\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"h\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)][\\!\\(\\* \
StyleBox[\\\"{\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"u\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"i\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"}\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\",\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"{\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"j\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\",\\\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* StyleBox[\\\"k\\\
\",\\nFontSlant->\\\"Italic\\\"]\\)\\!\\(\\* \
StyleBox[\\\"}\\\",\\nFontSlant->\\\"Italic\\\"]\\)]\"\>", 
          StyleBox["[",
            "MR"], 
          StyleBox["expr",
            "TI"], 
          StyleBox["]",
            "MR"]}]}]]],
  "  do the same kind of expansion for second partial derivatives."
}], "Usage",
  CellTags->"Function?"],

Cell[TextData[{
  "See also: ",
  ButtonBox["PartialD",
    ButtonData:>{"PartialD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["CovariantD",
    ButtonData:>{"CovariantD"},
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["ChristoffeluSymbol",
    ButtonData:>{"ChristoffeluSymbol"},
    ButtonStyle->"AddOnsLink"],
  "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell["Examples  ", "ExampleSection"],

Cell[BoxData[{
    \(Needs["\<TensorCalculus3`Tensorial`\>"]\), "\n", 
    \(Needs["\<TContinuumMechanics1`TContinuumMechanics`\>"]\)}], "Input",
  CellLabel->"In[1]:="],

Cell["Save old settings and declare a flavor...", "Text"],

Cell[BoxData[{
    \(\(oldflavors = IndexFlavors;\)\), "\n", 
    \(\(ClearIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(DeclareIndexFlavor[{red, Red}]\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    \(DefineTensorShortcuts[{u, 1}]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[{
    \(PartialD[ud[red@i], 
        red@j] == \((PartialD[ud[red@i], 
            red@j] // \(DifToCov[\[CapitalGamma], red@m]\)[{u, red@i}, 
            red@j])\)\), "\[IndentingNewLine]", 
    \(PartialD[uu[red@i], 
        red@j] == \((PartialD[uu[red@i], 
            red@j] // \(DifToCov[\[CapitalGamma], red@m]\)[{u, red@i}, 
            red@j])\)\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[{
    \(PartialD[
        uu[red@i], {red@j, 
          red@k}] == \((PartialD[
            uu[red@i], {red@j, red@k}] // \(DifToCov[\[CapitalGamma], red@p, 
              red@q]\)[{u, red@i}, {red@j, 
              red@k}])\)\), "\[IndentingNewLine]", 
    \(PartialD[
        ud[red@i], {red@j, 
          red@k}] == \((PartialD[
            ud[red@i], {red@j, red@k}] // \(DifToCov[\[CapitalGamma], red@p, 
              red@q]\)[{u, red@i}, {red@j, red@k}])\)\)}], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(ClearTensorShortcuts[{u, 1}]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[{
    \(\(ClearIndexFlavor /@ IndexFlavors;\)\), "\[IndentingNewLine]", 
    \(\(DeclareIndexFlavor /@ oldflavors;\)\), "\[IndentingNewLine]", 
    \(Clear[oldflavors]\)}], "Input",
  CellLabel->"In[12]:="]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{696, 613},
WindowMargins->{{Automatic, 10}, {5, Automatic}},
CommonDefaultFormatTypes->{"Output"->TraditionalForm},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Function?"->{
    Cell[1776, 53, 55, 1, 31, "ObjectName",
      CellTags->"Function?"],
    Cell[1834, 56, 2490, 51, 72, "Usage",
      CellTags->"Function?"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Function?", 7277, 202}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 55, 1, 31, "ObjectName",
  CellTags->"Function?"],
Cell[1834, 56, 2490, 51, 72, "Usage",
  CellTags->"Function?"],
Cell[4327, 109, 354, 14, 31, "MathCaption"],

Cell[CellGroupData[{
Cell[4706, 127, 36, 0, 40, "ExampleSection"],
Cell[4745, 129, 169, 3, 70, "Input"],
Cell[4917, 134, 57, 0, 70, "Text"],
Cell[4977, 136, 205, 4, 70, "Input"],
Cell[5185, 142, 86, 2, 70, "Input"],
Cell[5274, 146, 405, 9, 70, "Input"],
Cell[5682, 157, 514, 12, 70, "Input"],
Cell[6199, 171, 86, 2, 70, "Input"],
Cell[6288, 175, 219, 4, 70, "Input"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

